/* ----------------------------------------------------------------------------
 * This file was automatically generated by SWIG (http://www.swig.org).
 * Version 1.3.40
 *
 * Do not make changes to this file unless you know what you are doing--modify
 * the SWIG interface file instead.
 * ----------------------------------------------------------------------------- */

package zxidjava;

public class zxidjni implements zxidjniConstants {
  public static void zx_ns_s_n_set(SWIGTYPE_p_zx_ns_s self, SWIGTYPE_p_zx_ns_s value) {
    zxidjniJNI.zx_ns_s_n_set(SWIGTYPE_p_zx_ns_s.getCPtr(self), SWIGTYPE_p_zx_ns_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_ns_s zx_ns_s_n_get(SWIGTYPE_p_zx_ns_s self) {
    long cPtr = zxidjniJNI.zx_ns_s_n_get(SWIGTYPE_p_zx_ns_s.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_ns_s(cPtr, false);
  }

  public static void zx_ns_s_m_set(SWIGTYPE_p_zx_ns_s self, SWIGTYPE_p_zx_ns_s value) {
    zxidjniJNI.zx_ns_s_m_set(SWIGTYPE_p_zx_ns_s.getCPtr(self), SWIGTYPE_p_zx_ns_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_ns_s zx_ns_s_m_get(SWIGTYPE_p_zx_ns_s self) {
    long cPtr = zxidjniJNI.zx_ns_s_m_get(SWIGTYPE_p_zx_ns_s.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_ns_s(cPtr, false);
  }

  public static void zx_ns_s_seen_set(SWIGTYPE_p_zx_ns_s self, SWIGTYPE_p_zx_ns_s value) {
    zxidjniJNI.zx_ns_s_seen_set(SWIGTYPE_p_zx_ns_s.getCPtr(self), SWIGTYPE_p_zx_ns_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_ns_s zx_ns_s_seen_get(SWIGTYPE_p_zx_ns_s self) {
    long cPtr = zxidjniJNI.zx_ns_s_seen_get(SWIGTYPE_p_zx_ns_s.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_ns_s(cPtr, false);
  }

  public static void zx_ns_s_seen_n_set(SWIGTYPE_p_zx_ns_s self, SWIGTYPE_p_zx_ns_s value) {
    zxidjniJNI.zx_ns_s_seen_n_set(SWIGTYPE_p_zx_ns_s.getCPtr(self), SWIGTYPE_p_zx_ns_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_ns_s zx_ns_s_seen_n_get(SWIGTYPE_p_zx_ns_s self) {
    long cPtr = zxidjniJNI.zx_ns_s_seen_n_get(SWIGTYPE_p_zx_ns_s.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_ns_s(cPtr, false);
  }

  public static void zx_ns_s_seen_p_set(SWIGTYPE_p_zx_ns_s self, SWIGTYPE_p_zx_ns_s value) {
    zxidjniJNI.zx_ns_s_seen_p_set(SWIGTYPE_p_zx_ns_s.getCPtr(self), SWIGTYPE_p_zx_ns_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_ns_s zx_ns_s_seen_p_get(SWIGTYPE_p_zx_ns_s self) {
    long cPtr = zxidjniJNI.zx_ns_s_seen_p_get(SWIGTYPE_p_zx_ns_s.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_ns_s(cPtr, false);
  }

  public static void zx_ns_s_seen_pop_set(SWIGTYPE_p_zx_ns_s self, SWIGTYPE_p_zx_ns_s value) {
    zxidjniJNI.zx_ns_s_seen_pop_set(SWIGTYPE_p_zx_ns_s.getCPtr(self), SWIGTYPE_p_zx_ns_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_ns_s zx_ns_s_seen_pop_get(SWIGTYPE_p_zx_ns_s self) {
    long cPtr = zxidjniJNI.zx_ns_s_seen_pop_get(SWIGTYPE_p_zx_ns_s.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_ns_s(cPtr, false);
  }

  public static void zx_ns_s_inc_n_set(SWIGTYPE_p_zx_ns_s self, SWIGTYPE_p_zx_ns_s value) {
    zxidjniJNI.zx_ns_s_inc_n_set(SWIGTYPE_p_zx_ns_s.getCPtr(self), SWIGTYPE_p_zx_ns_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_ns_s zx_ns_s_inc_n_get(SWIGTYPE_p_zx_ns_s self) {
    long cPtr = zxidjniJNI.zx_ns_s_inc_n_get(SWIGTYPE_p_zx_ns_s.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_ns_s(cPtr, false);
  }

  public static void zx_ns_s_prefix_len_set(SWIGTYPE_p_zx_ns_s self, int value) {
    zxidjniJNI.zx_ns_s_prefix_len_set(SWIGTYPE_p_zx_ns_s.getCPtr(self), value);
  }

  public static int zx_ns_s_prefix_len_get(SWIGTYPE_p_zx_ns_s self) {
    return zxidjniJNI.zx_ns_s_prefix_len_get(SWIGTYPE_p_zx_ns_s.getCPtr(self));
  }

  public static void zx_ns_s_prefix_set(SWIGTYPE_p_zx_ns_s self, String value) {
    zxidjniJNI.zx_ns_s_prefix_set(SWIGTYPE_p_zx_ns_s.getCPtr(self), value);
  }

  public static String zx_ns_s_prefix_get(SWIGTYPE_p_zx_ns_s self) {
    return zxidjniJNI.zx_ns_s_prefix_get(SWIGTYPE_p_zx_ns_s.getCPtr(self));
  }

  public static void zx_ns_s_url_len_set(SWIGTYPE_p_zx_ns_s self, int value) {
    zxidjniJNI.zx_ns_s_url_len_set(SWIGTYPE_p_zx_ns_s.getCPtr(self), value);
  }

  public static int zx_ns_s_url_len_get(SWIGTYPE_p_zx_ns_s self) {
    return zxidjniJNI.zx_ns_s_url_len_get(SWIGTYPE_p_zx_ns_s.getCPtr(self));
  }

  public static void zx_ns_s_url_set(SWIGTYPE_p_zx_ns_s self, String value) {
    zxidjniJNI.zx_ns_s_url_set(SWIGTYPE_p_zx_ns_s.getCPtr(self), value);
  }

  public static String zx_ns_s_url_get(SWIGTYPE_p_zx_ns_s self) {
    return zxidjniJNI.zx_ns_s_url_get(SWIGTYPE_p_zx_ns_s.getCPtr(self));
  }

  public static SWIGTYPE_p_zx_ns_s new_zx_ns_s() {
    long cPtr = zxidjniJNI.new_zx_ns_s();
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_ns_s(cPtr, true);
  }

  public static void delete_zx_ns_s(SWIGTYPE_p_zx_ns_s self) {
    zxidjniJNI.delete_zx_ns_s(SWIGTYPE_p_zx_ns_s.getCPtr(self));
  }

  public static void zx_ctx_base_set(SWIGTYPE_p_zx_ctx self, String value) {
    zxidjniJNI.zx_ctx_base_set(SWIGTYPE_p_zx_ctx.getCPtr(self), value);
  }

  public static String zx_ctx_base_get(SWIGTYPE_p_zx_ctx self) {
    return zxidjniJNI.zx_ctx_base_get(SWIGTYPE_p_zx_ctx.getCPtr(self));
  }

  public static void zx_ctx_p_set(SWIGTYPE_p_zx_ctx self, String value) {
    zxidjniJNI.zx_ctx_p_set(SWIGTYPE_p_zx_ctx.getCPtr(self), value);
  }

  public static String zx_ctx_p_get(SWIGTYPE_p_zx_ctx self) {
    return zxidjniJNI.zx_ctx_p_get(SWIGTYPE_p_zx_ctx.getCPtr(self));
  }

  public static void zx_ctx_lim_set(SWIGTYPE_p_zx_ctx self, String value) {
    zxidjniJNI.zx_ctx_lim_set(SWIGTYPE_p_zx_ctx.getCPtr(self), value);
  }

  public static String zx_ctx_lim_get(SWIGTYPE_p_zx_ctx self) {
    return zxidjniJNI.zx_ctx_lim_get(SWIGTYPE_p_zx_ctx.getCPtr(self));
  }

  public static void zx_ctx_ns_tab_set(SWIGTYPE_p_zx_ctx self, SWIGTYPE_p_zx_ns_s value) {
    zxidjniJNI.zx_ctx_ns_tab_set(SWIGTYPE_p_zx_ctx.getCPtr(self), SWIGTYPE_p_zx_ns_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_ns_s zx_ctx_ns_tab_get(SWIGTYPE_p_zx_ctx self) {
    long cPtr = zxidjniJNI.zx_ctx_ns_tab_get(SWIGTYPE_p_zx_ctx.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_ns_s(cPtr, false);
  }

  public static void zx_ctx_unknown_ns_set(SWIGTYPE_p_zx_ctx self, SWIGTYPE_p_zx_ns_s value) {
    zxidjniJNI.zx_ctx_unknown_ns_set(SWIGTYPE_p_zx_ctx.getCPtr(self), SWIGTYPE_p_zx_ns_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_ns_s zx_ctx_unknown_ns_get(SWIGTYPE_p_zx_ctx self) {
    long cPtr = zxidjniJNI.zx_ctx_unknown_ns_get(SWIGTYPE_p_zx_ctx.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_ns_s(cPtr, false);
  }

  public static void zx_ctx_guard_seen_n_set(SWIGTYPE_p_zx_ctx self, SWIGTYPE_p_zx_ns_s value) {
    zxidjniJNI.zx_ctx_guard_seen_n_set(SWIGTYPE_p_zx_ctx.getCPtr(self), SWIGTYPE_p_zx_ns_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_ns_s zx_ctx_guard_seen_n_get(SWIGTYPE_p_zx_ctx self) {
    long cPtr = zxidjniJNI.zx_ctx_guard_seen_n_get(SWIGTYPE_p_zx_ctx.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_ns_s(cPtr, false);
  }

  public static void zx_ctx_guard_seen_p_set(SWIGTYPE_p_zx_ctx self, SWIGTYPE_p_zx_ns_s value) {
    zxidjniJNI.zx_ctx_guard_seen_p_set(SWIGTYPE_p_zx_ctx.getCPtr(self), SWIGTYPE_p_zx_ns_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_ns_s zx_ctx_guard_seen_p_get(SWIGTYPE_p_zx_ctx self) {
    long cPtr = zxidjniJNI.zx_ctx_guard_seen_p_get(SWIGTYPE_p_zx_ctx.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_ns_s(cPtr, false);
  }

  public static void zx_ctx_exclude_sig_set(SWIGTYPE_p_zx_ctx self, SWIGTYPE_p_void value) {
    zxidjniJNI.zx_ctx_exclude_sig_set(SWIGTYPE_p_zx_ctx.getCPtr(self), SWIGTYPE_p_void.getCPtr(value));
  }

  public static SWIGTYPE_p_void zx_ctx_exclude_sig_get(SWIGTYPE_p_zx_ctx self) {
    long cPtr = zxidjniJNI.zx_ctx_exclude_sig_get(SWIGTYPE_p_zx_ctx.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_void(cPtr, false);
  }

  public static void zx_ctx_inc_ns_len_set(SWIGTYPE_p_zx_ctx self, SWIGTYPE_p_zx_ns_s value) {
    zxidjniJNI.zx_ctx_inc_ns_len_set(SWIGTYPE_p_zx_ctx.getCPtr(self), SWIGTYPE_p_zx_ns_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_ns_s zx_ctx_inc_ns_len_get(SWIGTYPE_p_zx_ctx self) {
    long cPtr = zxidjniJNI.zx_ctx_inc_ns_len_get(SWIGTYPE_p_zx_ctx.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_ns_s(cPtr, false);
  }

  public static void zx_ctx_inc_ns_set(SWIGTYPE_p_zx_ctx self, SWIGTYPE_p_zx_ns_s value) {
    zxidjniJNI.zx_ctx_inc_ns_set(SWIGTYPE_p_zx_ctx.getCPtr(self), SWIGTYPE_p_zx_ns_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_ns_s zx_ctx_inc_ns_get(SWIGTYPE_p_zx_ctx self) {
    long cPtr = zxidjniJNI.zx_ctx_inc_ns_get(SWIGTYPE_p_zx_ctx.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_ns_s(cPtr, false);
  }

  public static void zx_ctx_malloc_func_set(SWIGTYPE_p_zx_ctx self, SWIGTYPE_p_f_size_t__p_void value) {
    zxidjniJNI.zx_ctx_malloc_func_set(SWIGTYPE_p_zx_ctx.getCPtr(self), SWIGTYPE_p_f_size_t__p_void.getCPtr(value));
  }

  public static SWIGTYPE_p_f_size_t__p_void zx_ctx_malloc_func_get(SWIGTYPE_p_zx_ctx self) {
    long cPtr = zxidjniJNI.zx_ctx_malloc_func_get(SWIGTYPE_p_zx_ctx.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_f_size_t__p_void(cPtr, false);
  }

  public static void zx_ctx_realloc_func_set(SWIGTYPE_p_zx_ctx self, SWIGTYPE_p_f_p_void_size_t__p_void value) {
    zxidjniJNI.zx_ctx_realloc_func_set(SWIGTYPE_p_zx_ctx.getCPtr(self), SWIGTYPE_p_f_p_void_size_t__p_void.getCPtr(value));
  }

  public static SWIGTYPE_p_f_p_void_size_t__p_void zx_ctx_realloc_func_get(SWIGTYPE_p_zx_ctx self) {
    long cPtr = zxidjniJNI.zx_ctx_realloc_func_get(SWIGTYPE_p_zx_ctx.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_f_p_void_size_t__p_void(cPtr, false);
  }

  public static void zx_ctx_free_func_set(SWIGTYPE_p_zx_ctx self, SWIGTYPE_p_f_p_void__void value) {
    zxidjniJNI.zx_ctx_free_func_set(SWIGTYPE_p_zx_ctx.getCPtr(self), SWIGTYPE_p_f_p_void__void.getCPtr(value));
  }

  public static SWIGTYPE_p_f_p_void__void zx_ctx_free_func_get(SWIGTYPE_p_zx_ctx self) {
    long cPtr = zxidjniJNI.zx_ctx_free_func_get(SWIGTYPE_p_zx_ctx.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_f_p_void__void(cPtr, false);
  }

  public static SWIGTYPE_p_zx_ctx new_zx_ctx() {
    long cPtr = zxidjniJNI.new_zx_ctx();
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_ctx(cPtr, true);
  }

  public static void delete_zx_ctx(SWIGTYPE_p_zx_ctx self) {
    zxidjniJNI.delete_zx_ctx(SWIGTYPE_p_zx_ctx.getCPtr(self));
  }

  public static void zx_node_s_n_set(SWIGTYPE_p_zx_node_s self, SWIGTYPE_p_zx_node_s value) {
    zxidjniJNI.zx_node_s_n_set(SWIGTYPE_p_zx_node_s.getCPtr(self), SWIGTYPE_p_zx_node_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_node_s zx_node_s_n_get(SWIGTYPE_p_zx_node_s self) {
    long cPtr = zxidjniJNI.zx_node_s_n_get(SWIGTYPE_p_zx_node_s.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_node_s(cPtr, false);
  }

  public static void zx_node_s_wo_set(SWIGTYPE_p_zx_node_s self, SWIGTYPE_p_zx_node_s value) {
    zxidjniJNI.zx_node_s_wo_set(SWIGTYPE_p_zx_node_s.getCPtr(self), SWIGTYPE_p_zx_node_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_node_s zx_node_s_wo_get(SWIGTYPE_p_zx_node_s self) {
    long cPtr = zxidjniJNI.zx_node_s_wo_get(SWIGTYPE_p_zx_node_s.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_node_s(cPtr, false);
  }

  public static void zx_node_s_ns_set(SWIGTYPE_p_zx_node_s self, SWIGTYPE_p_zx_ns_s value) {
    zxidjniJNI.zx_node_s_ns_set(SWIGTYPE_p_zx_node_s.getCPtr(self), SWIGTYPE_p_zx_ns_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_ns_s zx_node_s_ns_get(SWIGTYPE_p_zx_node_s self) {
    long cPtr = zxidjniJNI.zx_node_s_ns_get(SWIGTYPE_p_zx_node_s.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_ns_s(cPtr, false);
  }

  public static void zx_node_s_tok_set(SWIGTYPE_p_zx_node_s self, short value) {
    zxidjniJNI.zx_node_s_tok_set(SWIGTYPE_p_zx_node_s.getCPtr(self), value);
  }

  public static short zx_node_s_tok_get(SWIGTYPE_p_zx_node_s self) {
    return zxidjniJNI.zx_node_s_tok_get(SWIGTYPE_p_zx_node_s.getCPtr(self));
  }

  public static void zx_node_s_err_set(SWIGTYPE_p_zx_node_s self, short value) {
    zxidjniJNI.zx_node_s_err_set(SWIGTYPE_p_zx_node_s.getCPtr(self), value);
  }

  public static short zx_node_s_err_get(SWIGTYPE_p_zx_node_s self) {
    return zxidjniJNI.zx_node_s_err_get(SWIGTYPE_p_zx_node_s.getCPtr(self));
  }

  public static SWIGTYPE_p_zx_node_s new_zx_node_s() {
    long cPtr = zxidjniJNI.new_zx_node_s();
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_node_s(cPtr, true);
  }

  public static void delete_zx_node_s(SWIGTYPE_p_zx_node_s self) {
    zxidjniJNI.delete_zx_node_s(SWIGTYPE_p_zx_node_s.getCPtr(self));
  }

  public static void zx_elem_s_g_set(SWIGTYPE_p_zx_elem_s self, SWIGTYPE_p_zx_node_s value) {
    zxidjniJNI.zx_elem_s_g_set(SWIGTYPE_p_zx_elem_s.getCPtr(self), SWIGTYPE_p_zx_node_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_node_s zx_elem_s_g_get(SWIGTYPE_p_zx_elem_s self) {
    long cPtr = zxidjniJNI.zx_elem_s_g_get(SWIGTYPE_p_zx_elem_s.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_node_s(cPtr, false);
  }

  public static void zx_elem_s_kids_set(SWIGTYPE_p_zx_elem_s self, SWIGTYPE_p_zx_elem_s value) {
    zxidjniJNI.zx_elem_s_kids_set(SWIGTYPE_p_zx_elem_s.getCPtr(self), SWIGTYPE_p_zx_elem_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_elem_s zx_elem_s_kids_get(SWIGTYPE_p_zx_elem_s self) {
    long cPtr = zxidjniJNI.zx_elem_s_kids_get(SWIGTYPE_p_zx_elem_s.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_elem_s(cPtr, false);
  }

  public static void zx_elem_s_any_attr_set(SWIGTYPE_p_zx_elem_s self, SWIGTYPE_p_zx_any_attr_s value) {
    zxidjniJNI.zx_elem_s_any_attr_set(SWIGTYPE_p_zx_elem_s.getCPtr(self), SWIGTYPE_p_zx_any_attr_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_any_attr_s zx_elem_s_any_attr_get(SWIGTYPE_p_zx_elem_s self) {
    long cPtr = zxidjniJNI.zx_elem_s_any_attr_get(SWIGTYPE_p_zx_elem_s.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_any_attr_s(cPtr, false);
  }

  public static void zx_elem_s_any_elem_set(SWIGTYPE_p_zx_elem_s self, SWIGTYPE_p_zx_any_elem_s value) {
    zxidjniJNI.zx_elem_s_any_elem_set(SWIGTYPE_p_zx_elem_s.getCPtr(self), SWIGTYPE_p_zx_any_elem_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_any_elem_s zx_elem_s_any_elem_get(SWIGTYPE_p_zx_elem_s self) {
    long cPtr = zxidjniJNI.zx_elem_s_any_elem_get(SWIGTYPE_p_zx_elem_s.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_any_elem_s(cPtr, false);
  }

  public static void zx_elem_s_xmlns_set(SWIGTYPE_p_zx_elem_s self, String value) {
    zxidjniJNI.zx_elem_s_xmlns_set(SWIGTYPE_p_zx_elem_s.getCPtr(self), value);
  }

  public static String zx_elem_s_xmlns_get(SWIGTYPE_p_zx_elem_s self) { return zxidjniJNI.zx_elem_s_xmlns_get(SWIGTYPE_p_zx_elem_s.getCPtr(self)); }

  public static void zx_elem_s_content_set(SWIGTYPE_p_zx_elem_s self, String value) {
    zxidjniJNI.zx_elem_s_content_set(SWIGTYPE_p_zx_elem_s.getCPtr(self), value);
  }

  public static String zx_elem_s_content_get(SWIGTYPE_p_zx_elem_s self) { return zxidjniJNI.zx_elem_s_content_get(SWIGTYPE_p_zx_elem_s.getCPtr(self)); }

  public static SWIGTYPE_p_zx_elem_s new_zx_elem_s() {
    long cPtr = zxidjniJNI.new_zx_elem_s();
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_elem_s(cPtr, true);
  }

  public static void delete_zx_elem_s(SWIGTYPE_p_zx_elem_s self) {
    zxidjniJNI.delete_zx_elem_s(SWIGTYPE_p_zx_elem_s.getCPtr(self));
  }

  public static SWIGTYPE_p_zx_elem_s zx_new_simple_elem(SWIGTYPE_p_zx_ctx c, String ss) {
    long cPtr = zxidjniJNI.zx_new_simple_elem(SWIGTYPE_p_zx_ctx.getCPtr(c), ss);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_elem_s(cPtr, false);
  }

  public static SWIGTYPE_p_zx_elem_s zx_ref_len_simple_elem(SWIGTYPE_p_zx_ctx c, int len) {
    long cPtr = zxidjniJNI.zx_ref_len_simple_elem(SWIGTYPE_p_zx_ctx.getCPtr(c), len);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_elem_s(cPtr, false);
  }

  public static SWIGTYPE_p_zx_elem_s zx_ref_simple_elem(SWIGTYPE_p_zx_ctx c, String s) {
    long cPtr = zxidjniJNI.zx_ref_simple_elem(SWIGTYPE_p_zx_ctx.getCPtr(c), s);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_elem_s(cPtr, false);
  }

  public static SWIGTYPE_p_zx_elem_s zx_dup_len_simple_elem(SWIGTYPE_p_zx_ctx c, int len) {
    long cPtr = zxidjniJNI.zx_dup_len_simple_elem(SWIGTYPE_p_zx_ctx.getCPtr(c), len);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_elem_s(cPtr, false);
  }

  public static SWIGTYPE_p_zx_elem_s zx_dup_simple_elem(SWIGTYPE_p_zx_ctx c, String s) {
    long cPtr = zxidjniJNI.zx_dup_simple_elem(SWIGTYPE_p_zx_ctx.getCPtr(c), s);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_elem_s(cPtr, false);
  }

  public static void zx_str_g_set(String self, SWIGTYPE_p_zx_node_s value) {
    zxidjniJNI.zx_str_g_set(self, SWIGTYPE_p_zx_node_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_node_s zx_str_g_get(String self) {
    long cPtr = zxidjniJNI.zx_str_g_get(self);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_node_s(cPtr, false);
  }

  public static void zx_str_len_set(String self, int value) {
    zxidjniJNI.zx_str_len_set(self, value);
  }

  public static int zx_str_len_get(String self) {
    return zxidjniJNI.zx_str_len_get(self);
  }

  public static void zx_str_s_set(String self, String value) {
    zxidjniJNI.zx_str_s_set(self, value);
  }

  public static String zx_str_s_get(String self) {
    return zxidjniJNI.zx_str_s_get(self);
  }

  public static String new_zx_str() { return zxidjniJNI.new_zx_str(); }

  public static void delete_zx_str(String self) {
    zxidjniJNI.delete_zx_str(self);
  }

  public static String zx_ref_str(SWIGTYPE_p_zx_ctx c, String s) { return zxidjniJNI.zx_ref_str(SWIGTYPE_p_zx_ctx.getCPtr(c), s); }

  public static String zx_ref_len_str(SWIGTYPE_p_zx_ctx c, int len) { return zxidjniJNI.zx_ref_len_str(SWIGTYPE_p_zx_ctx.getCPtr(c), len); }

  public static String zx_new_len_str(SWIGTYPE_p_zx_ctx c, int len) { return zxidjniJNI.zx_new_len_str(SWIGTYPE_p_zx_ctx.getCPtr(c), len); }

  public static String zx_dup_str(SWIGTYPE_p_zx_ctx c, String s) { return zxidjniJNI.zx_dup_str(SWIGTYPE_p_zx_ctx.getCPtr(c), s); }

  public static String zx_dup_len_str(SWIGTYPE_p_zx_ctx c, int len) { return zxidjniJNI.zx_dup_len_str(SWIGTYPE_p_zx_ctx.getCPtr(c), len); }

  public static String zx_alloc_sprintf(SWIGTYPE_p_zx_ctx c, SWIGTYPE_p_int retlen, String f) {
    return zxidjniJNI.zx_alloc_sprintf(SWIGTYPE_p_zx_ctx.getCPtr(c), SWIGTYPE_p_int.getCPtr(retlen), f);
  }

  public static String zx_strf(SWIGTYPE_p_zx_ctx c, String f) { return zxidjniJNI.zx_strf(SWIGTYPE_p_zx_ctx.getCPtr(c), f); }

  public static void zx_str_free(SWIGTYPE_p_zx_ctx c, String ss) {
    zxidjniJNI.zx_str_free(SWIGTYPE_p_zx_ctx.getCPtr(c), ss);
  }

  public static String zx_str_to_c(SWIGTYPE_p_zx_ctx c, String ss) {
    return zxidjniJNI.zx_str_to_c(SWIGTYPE_p_zx_ctx.getCPtr(c), ss);
  }

  public static void zx_str_conv(String ss, SWIGTYPE_p_int out_len, SWIGTYPE_p_p_char out_s) {
    zxidjniJNI.zx_str_conv(ss, SWIGTYPE_p_int.getCPtr(out_len), SWIGTYPE_p_p_char.getCPtr(out_s));
  }

  public static int zx_str_ends_in(String ss, int len, String suffix) {
    return zxidjniJNI.zx_str_ends_in(ss, len, suffix);
  }

  public static void zx_any_elem_s_gg_set(SWIGTYPE_p_zx_any_elem_s self, SWIGTYPE_p_zx_elem_s value) {
    zxidjniJNI.zx_any_elem_s_gg_set(SWIGTYPE_p_zx_any_elem_s.getCPtr(self), SWIGTYPE_p_zx_elem_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_elem_s zx_any_elem_s_gg_get(SWIGTYPE_p_zx_any_elem_s self) {
    long cPtr = zxidjniJNI.zx_any_elem_s_gg_get(SWIGTYPE_p_zx_any_elem_s.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_elem_s(cPtr, false);
  }

  public static void zx_any_elem_s_name_len_set(SWIGTYPE_p_zx_any_elem_s self, int value) {
    zxidjniJNI.zx_any_elem_s_name_len_set(SWIGTYPE_p_zx_any_elem_s.getCPtr(self), value);
  }

  public static int zx_any_elem_s_name_len_get(SWIGTYPE_p_zx_any_elem_s self) {
    return zxidjniJNI.zx_any_elem_s_name_len_get(SWIGTYPE_p_zx_any_elem_s.getCPtr(self));
  }

  public static void zx_any_elem_s_name_set(SWIGTYPE_p_zx_any_elem_s self, String value) {
    zxidjniJNI.zx_any_elem_s_name_set(SWIGTYPE_p_zx_any_elem_s.getCPtr(self), value);
  }

  public static String zx_any_elem_s_name_get(SWIGTYPE_p_zx_any_elem_s self) {
    return zxidjniJNI.zx_any_elem_s_name_get(SWIGTYPE_p_zx_any_elem_s.getCPtr(self));
  }

  public static SWIGTYPE_p_zx_any_elem_s new_zx_any_elem_s() {
    long cPtr = zxidjniJNI.new_zx_any_elem_s();
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_any_elem_s(cPtr, true);
  }

  public static void delete_zx_any_elem_s(SWIGTYPE_p_zx_any_elem_s self) {
    zxidjniJNI.delete_zx_any_elem_s(SWIGTYPE_p_zx_any_elem_s.getCPtr(self));
  }

  public static void zx_any_attr_s_ss_set(SWIGTYPE_p_zx_any_attr_s self, String value) {
    zxidjniJNI.zx_any_attr_s_ss_set(SWIGTYPE_p_zx_any_attr_s.getCPtr(self), value);
  }

  public static String zx_any_attr_s_ss_get(SWIGTYPE_p_zx_any_attr_s self) { return zxidjniJNI.zx_any_attr_s_ss_get(SWIGTYPE_p_zx_any_attr_s.getCPtr(self)); }

  public static void zx_any_attr_s_name_len_set(SWIGTYPE_p_zx_any_attr_s self, int value) {
    zxidjniJNI.zx_any_attr_s_name_len_set(SWIGTYPE_p_zx_any_attr_s.getCPtr(self), value);
  }

  public static int zx_any_attr_s_name_len_get(SWIGTYPE_p_zx_any_attr_s self) {
    return zxidjniJNI.zx_any_attr_s_name_len_get(SWIGTYPE_p_zx_any_attr_s.getCPtr(self));
  }

  public static void zx_any_attr_s_name_set(SWIGTYPE_p_zx_any_attr_s self, String value) {
    zxidjniJNI.zx_any_attr_s_name_set(SWIGTYPE_p_zx_any_attr_s.getCPtr(self), value);
  }

  public static String zx_any_attr_s_name_get(SWIGTYPE_p_zx_any_attr_s self) {
    return zxidjniJNI.zx_any_attr_s_name_get(SWIGTYPE_p_zx_any_attr_s.getCPtr(self));
  }

  public static SWIGTYPE_p_zx_any_attr_s new_zx_any_attr_s() {
    long cPtr = zxidjniJNI.new_zx_any_attr_s();
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_any_attr_s(cPtr, true);
  }

  public static void delete_zx_any_attr_s(SWIGTYPE_p_zx_any_attr_s self) {
    zxidjniJNI.delete_zx_any_attr_s(SWIGTYPE_p_zx_any_attr_s.getCPtr(self));
  }

  public static String zx_memmem(String haystack, int haystack_len, String needle, int needle_len) {
    return zxidjniJNI.zx_memmem(haystack, haystack_len, needle, needle_len);
  }

  public static SWIGTYPE_p_void zx_alloc(SWIGTYPE_p_zx_ctx c, int size) {
    long cPtr = zxidjniJNI.zx_alloc(SWIGTYPE_p_zx_ctx.getCPtr(c), size);
    return (cPtr == 0) ? null : new SWIGTYPE_p_void(cPtr, false);
  }

  public static SWIGTYPE_p_void zx_zalloc(SWIGTYPE_p_zx_ctx c, int size) {
    long cPtr = zxidjniJNI.zx_zalloc(SWIGTYPE_p_zx_ctx.getCPtr(c), size);
    return (cPtr == 0) ? null : new SWIGTYPE_p_void(cPtr, false);
  }

  public static SWIGTYPE_p_void zx_free(SWIGTYPE_p_zx_ctx c, SWIGTYPE_p_void p) {
    long cPtr = zxidjniJNI.zx_free(SWIGTYPE_p_zx_ctx.getCPtr(c), SWIGTYPE_p_void.getCPtr(p));
    return (cPtr == 0) ? null : new SWIGTYPE_p_void(cPtr, false);
  }

  public static String zx_dup_cstr(SWIGTYPE_p_zx_ctx c, String str) {
    return zxidjniJNI.zx_dup_cstr(SWIGTYPE_p_zx_ctx.getCPtr(c), str);
  }

  public static void zx_reset_ctx(SWIGTYPE_p_zx_ctx ctx) {
    zxidjniJNI.zx_reset_ctx(SWIGTYPE_p_zx_ctx.getCPtr(ctx));
  }

  public static SWIGTYPE_p_zx_ctx zx_init_ctx() {
    long cPtr = zxidjniJNI.zx_init_ctx();
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_ctx(cPtr, false);
  }

  public static void zx_tok_name_set(SWIGTYPE_p_zx_tok self, String value) {
    zxidjniJNI.zx_tok_name_set(SWIGTYPE_p_zx_tok.getCPtr(self), value);
  }

  public static String zx_tok_name_get(SWIGTYPE_p_zx_tok self) {
    return zxidjniJNI.zx_tok_name_get(SWIGTYPE_p_zx_tok.getCPtr(self));
  }

  public static void zx_tok_prefix_set(SWIGTYPE_p_zx_tok self, String value) {
    zxidjniJNI.zx_tok_prefix_set(SWIGTYPE_p_zx_tok.getCPtr(self), value);
  }

  public static String zx_tok_prefix_get(SWIGTYPE_p_zx_tok self) {
    return zxidjniJNI.zx_tok_prefix_get(SWIGTYPE_p_zx_tok.getCPtr(self));
  }

  public static void zx_tok_ns_set(SWIGTYPE_p_zx_tok self, SWIGTYPE_p_zx_ns_s value) {
    zxidjniJNI.zx_tok_ns_set(SWIGTYPE_p_zx_tok.getCPtr(self), SWIGTYPE_p_zx_ns_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_ns_s zx_tok_ns_get(SWIGTYPE_p_zx_tok self) {
    long cPtr = zxidjniJNI.zx_tok_ns_get(SWIGTYPE_p_zx_tok.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_ns_s(cPtr, false);
  }

  public static SWIGTYPE_p_zx_tok new_zx_tok() {
    long cPtr = zxidjniJNI.new_zx_tok();
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_tok(cPtr, true);
  }

  public static void delete_zx_tok(SWIGTYPE_p_zx_tok self) {
    zxidjniJNI.delete_zx_tok(SWIGTYPE_p_zx_tok.getCPtr(self));
  }

  public static int zx_date_time_to_secs(String dt) {
    return zxidjniJNI.zx_date_time_to_secs(dt);
  }

  public static int write2_or_append_lock_c_path(String c_path, int len1, String data1, int len2, String data2, String which, int seeky, int flag) {
    return zxidjniJNI.write2_or_append_lock_c_path(c_path, len1, data1, len2, data2, which, seeky, flag);
  }

  public static int zx_report_openssl_error(String logkey) {
    return zxidjniJNI.zx_report_openssl_error(logkey);
  }

  public static void zx_fix_any_elem_dec(SWIGTYPE_p_zx_ctx c, SWIGTYPE_p_zx_any_elem_s x, String nam, int namlen) {
    zxidjniJNI.zx_fix_any_elem_dec(SWIGTYPE_p_zx_ctx.getCPtr(c), SWIGTYPE_p_zx_any_elem_s.getCPtr(x), nam, namlen);
  }

  public static SWIGTYPE_p_zx_ns_s zx_locate_ns_by_prefix(SWIGTYPE_p_zx_ctx c, int len, String prefix) {
    long cPtr = zxidjniJNI.zx_locate_ns_by_prefix(SWIGTYPE_p_zx_ctx.getCPtr(c), len, prefix);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_ns_s(cPtr, false);
  }

  public static int zx_is_ns_prefix(SWIGTYPE_p_zx_ns_s ns, int len, String prefix) {
    return zxidjniJNI.zx_is_ns_prefix(SWIGTYPE_p_zx_ns_s.getCPtr(ns), len, prefix);
  }

  public static SWIGTYPE_p_zx_ns_s zx_prefix_seen(SWIGTYPE_p_zx_ctx c, int len, String prefix) {
    long cPtr = zxidjniJNI.zx_prefix_seen(SWIGTYPE_p_zx_ctx.getCPtr(c), len, prefix);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_ns_s(cPtr, false);
  }

  public static SWIGTYPE_p_zx_ns_s zx_prefix_seen_whine(SWIGTYPE_p_zx_ctx c, int len, String prefix, String logkey, int mk_dummy_ns) {
    long cPtr = zxidjniJNI.zx_prefix_seen_whine(SWIGTYPE_p_zx_ctx.getCPtr(c), len, prefix, logkey, mk_dummy_ns);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_ns_s(cPtr, false);
  }

  public static SWIGTYPE_p_zx_ns_s zx_scan_xmlns(SWIGTYPE_p_zx_ctx c) {
    long cPtr = zxidjniJNI.zx_scan_xmlns(SWIGTYPE_p_zx_ctx.getCPtr(c));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_ns_s(cPtr, false);
  }

  public static void zx_pop_seen(SWIGTYPE_p_zx_ns_s ns) {
    zxidjniJNI.zx_pop_seen(SWIGTYPE_p_zx_ns_s.getCPtr(ns));
  }

  public static String zx_raw_cipher(SWIGTYPE_p_zx_ctx c, String algo, int encp, String key, int len, int iv_len, String iv) { return zxidjniJNI.zx_raw_cipher(SWIGTYPE_p_zx_ctx.getCPtr(c), algo, encp, key, len, iv_len, iv); }

  public static String zx_rsa_pub_enc(SWIGTYPE_p_zx_ctx c, String plain, SWIGTYPE_p_p_void rsa_pkey, int pad) { return zxidjniJNI.zx_rsa_pub_enc(SWIGTYPE_p_zx_ctx.getCPtr(c), plain, SWIGTYPE_p_p_void.getCPtr(rsa_pkey), pad); }

  public static String zx_rsa_pub_dec(SWIGTYPE_p_zx_ctx c, String ciphered, SWIGTYPE_p_p_void rsa_pkey, int pad) { return zxidjniJNI.zx_rsa_pub_dec(SWIGTYPE_p_zx_ctx.getCPtr(c), ciphered, SWIGTYPE_p_p_void.getCPtr(rsa_pkey), pad); }

  public static String zx_rsa_priv_dec(SWIGTYPE_p_zx_ctx c, String ciphered, SWIGTYPE_p_p_void rsa_pkey, int pad) { return zxidjniJNI.zx_rsa_priv_dec(SWIGTYPE_p_zx_ctx.getCPtr(c), ciphered, SWIGTYPE_p_p_void.getCPtr(rsa_pkey), pad); }

  public static String zx_rsa_priv_enc(SWIGTYPE_p_zx_ctx c, String plain, SWIGTYPE_p_p_void rsa_pkey, int pad) { return zxidjniJNI.zx_rsa_priv_enc(SWIGTYPE_p_zx_ctx.getCPtr(c), plain, SWIGTYPE_p_p_void.getCPtr(rsa_pkey), pad); }

  public static SWIGTYPE_p_p_void zx_get_rsa_pub_from_cert(SWIGTYPE_p_X509 cert, String logkey) {
    long cPtr = zxidjniJNI.zx_get_rsa_pub_from_cert(SWIGTYPE_p_X509.getCPtr(cert), logkey);
    return (cPtr == 0) ? null : new SWIGTYPE_p_p_void(cPtr, false);
  }

  public static void zx_rand(String buf, int n_bytes) {
    zxidjniJNI.zx_rand(buf, n_bytes);
  }

  public static String zx_md5_crypt(String pw, String salt, String buf) {
    return zxidjniJNI.zx_md5_crypt(pw, salt, buf);
  }

  public static SWIGTYPE_p_zx_tok zx_tok_by_ns(SWIGTYPE_p_zx_tok zt, SWIGTYPE_p_zx_tok lim, int len, String name, SWIGTYPE_p_zx_ns_s ns) {
    long cPtr = zxidjniJNI.zx_tok_by_ns(SWIGTYPE_p_zx_tok.getCPtr(zt), SWIGTYPE_p_zx_tok.getCPtr(lim), len, name, SWIGTYPE_p_zx_ns_s.getCPtr(ns));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_tok(cPtr, false);
  }

  public static int zx_len_xmlns_if_not_seen(SWIGTYPE_p_zx_ctx c, SWIGTYPE_p_zx_ns_s ns, SWIGTYPE_p_p_zx_ns_s pop_seen) {
    return zxidjniJNI.zx_len_xmlns_if_not_seen(SWIGTYPE_p_zx_ctx.getCPtr(c), SWIGTYPE_p_zx_ns_s.getCPtr(ns), SWIGTYPE_p_p_zx_ns_s.getCPtr(pop_seen));
  }

  public static String zx_enc_xmlns_if_not_seen(SWIGTYPE_p_zx_ctx c, String p, SWIGTYPE_p_zx_ns_s ns, SWIGTYPE_p_p_zx_ns_s pop_seen) {
    return zxidjniJNI.zx_enc_xmlns_if_not_seen(SWIGTYPE_p_zx_ctx.getCPtr(c), p, SWIGTYPE_p_zx_ns_s.getCPtr(ns), SWIGTYPE_p_p_zx_ns_s.getCPtr(pop_seen));
  }

  public static void zx_add_xmlns_if_not_seen(SWIGTYPE_p_zx_ctx c, SWIGTYPE_p_zx_ns_s ns, SWIGTYPE_p_p_zx_ns_s pop_seen) {
    zxidjniJNI.zx_add_xmlns_if_not_seen(SWIGTYPE_p_zx_ctx.getCPtr(c), SWIGTYPE_p_zx_ns_s.getCPtr(ns), SWIGTYPE_p_p_zx_ns_s.getCPtr(pop_seen));
  }

  public static String zx_enc_seen(String p, SWIGTYPE_p_zx_ns_s ns) {
    return zxidjniJNI.zx_enc_seen(p, SWIGTYPE_p_zx_ns_s.getCPtr(ns));
  }

  public static int zx_len_so_common(SWIGTYPE_p_zx_ctx c, SWIGTYPE_p_zx_elem_s x) {
    return zxidjniJNI.zx_len_so_common(SWIGTYPE_p_zx_ctx.getCPtr(c), SWIGTYPE_p_zx_elem_s.getCPtr(x));
  }

  public static int zx_len_wo_common(SWIGTYPE_p_zx_ctx c, SWIGTYPE_p_zx_elem_s x) {
    return zxidjniJNI.zx_len_wo_common(SWIGTYPE_p_zx_ctx.getCPtr(c), SWIGTYPE_p_zx_elem_s.getCPtr(x));
  }

  public static String zx_enc_unknown_attrs(String p, SWIGTYPE_p_zx_any_attr_s aa) {
    return zxidjniJNI.zx_enc_unknown_attrs(p, SWIGTYPE_p_zx_any_attr_s.getCPtr(aa));
  }

  public static String zx_enc_so_unknown_elems_and_content(SWIGTYPE_p_zx_ctx c, String p, SWIGTYPE_p_zx_elem_s x) {
    return zxidjniJNI.zx_enc_so_unknown_elems_and_content(SWIGTYPE_p_zx_ctx.getCPtr(c), p, SWIGTYPE_p_zx_elem_s.getCPtr(x));
  }

  public static String zx_easy_enc_common(SWIGTYPE_p_zx_ctx c, String p, String buf, int len) { return zxidjniJNI.zx_easy_enc_common(SWIGTYPE_p_zx_ctx.getCPtr(c), p, buf, len); }

  public static int zx_attr_so_len(String attr, int name_size) {
    return zxidjniJNI.zx_attr_so_len(attr, name_size);
  }

  public static String zx_attr_so_enc(String p, String attr, String name, int name_len) {
    return zxidjniJNI.zx_attr_so_enc(p, attr, name, name_len);
  }

  public static int zx_attr_wo_len(String attr, int name_size) {
    return zxidjniJNI.zx_attr_wo_len(attr, name_size);
  }

  public static String zx_attr_wo_enc(String p, String attr, String name, int name_len) {
    return zxidjniJNI.zx_attr_wo_enc(p, attr, name, name_len);
  }

  public static void zx_free_attr(SWIGTYPE_p_zx_ctx c, String attr, int free_strs) {
    zxidjniJNI.zx_free_attr(SWIGTYPE_p_zx_ctx.getCPtr(c), attr, free_strs);
  }

  public static void zx_free_elem_common(SWIGTYPE_p_zx_ctx c, SWIGTYPE_p_zx_elem_s x, int free_strs) {
    zxidjniJNI.zx_free_elem_common(SWIGTYPE_p_zx_ctx.getCPtr(c), SWIGTYPE_p_zx_elem_s.getCPtr(x), free_strs);
  }

  public static void zx_free_simple_elems(SWIGTYPE_p_zx_ctx c, SWIGTYPE_p_zx_elem_s se, int free_strs) {
    zxidjniJNI.zx_free_simple_elems(SWIGTYPE_p_zx_ctx.getCPtr(c), SWIGTYPE_p_zx_elem_s.getCPtr(se), free_strs);
  }

  public static void zx_prepare_dec_ctx(SWIGTYPE_p_zx_ctx c, SWIGTYPE_p_zx_ns_s ns_tab, String start, String lim) {
    zxidjniJNI.zx_prepare_dec_ctx(SWIGTYPE_p_zx_ctx.getCPtr(c), SWIGTYPE_p_zx_ns_s.getCPtr(ns_tab), start, lim);
  }

  public static int zx_scan_data(SWIGTYPE_p_zx_ctx c, SWIGTYPE_p_zx_elem_s el) {
    return zxidjniJNI.zx_scan_data(SWIGTYPE_p_zx_ctx.getCPtr(c), SWIGTYPE_p_zx_elem_s.getCPtr(el));
  }

  public static int zx_scan_pi_or_comment(SWIGTYPE_p_zx_ctx c) {
    return zxidjniJNI.zx_scan_pi_or_comment(SWIGTYPE_p_zx_ctx.getCPtr(c));
  }

  public static String zx_dec_unknown_attr(SWIGTYPE_p_zx_ctx c, SWIGTYPE_p_zx_elem_s el, String name, String data, int tok, int ctx_tok) { return zxidjniJNI.zx_dec_unknown_attr(SWIGTYPE_p_zx_ctx.getCPtr(c), SWIGTYPE_p_zx_elem_s.getCPtr(el), name, data, tok, ctx_tok); }

  public static String zx_dec_attr_val(SWIGTYPE_p_zx_ctx c, SWIGTYPE_p_p_char name) {
    return zxidjniJNI.zx_dec_attr_val(SWIGTYPE_p_zx_ctx.getCPtr(c), SWIGTYPE_p_p_char.getCPtr(name));
  }

  public static void zx_xml_parse_err(SWIGTYPE_p_zx_ctx c, char quote, String func, String msg) {
    zxidjniJNI.zx_xml_parse_err(SWIGTYPE_p_zx_ctx.getCPtr(c), quote, func, msg);
  }

  public static int zx_len_inc_ns(SWIGTYPE_p_zx_ctx c, SWIGTYPE_p_p_zx_ns_s pop_seenp) {
    return zxidjniJNI.zx_len_inc_ns(SWIGTYPE_p_zx_ctx.getCPtr(c), SWIGTYPE_p_p_zx_ns_s.getCPtr(pop_seenp));
  }

  public static void zx_add_inc_ns(SWIGTYPE_p_zx_ctx c, SWIGTYPE_p_p_zx_ns_s pop_seenp) {
    zxidjniJNI.zx_add_inc_ns(SWIGTYPE_p_zx_ctx.getCPtr(c), SWIGTYPE_p_p_zx_ns_s.getCPtr(pop_seenp));
  }

  public static String zx_enc_inc_ns(SWIGTYPE_p_zx_ctx c, String p, SWIGTYPE_p_p_zx_ns_s pop_seenp) {
    return zxidjniJNI.zx_enc_inc_ns(SWIGTYPE_p_zx_ctx.getCPtr(c), p, SWIGTYPE_p_p_zx_ns_s.getCPtr(pop_seenp));
  }

  public static void conf_magic_set(zxid_conf self, long value) {
    zxidjniJNI.zxid_conf_magic_set(zxid_conf.getCPtr(self), value);
  }

  public static long conf_magic_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_magic_get(zxid_conf.getCPtr(self));
  }

  public static void conf_ctx_set(zxid_conf self, SWIGTYPE_p_zx_ctx value) {
    zxidjniJNI.zxid_conf_ctx_set(zxid_conf.getCPtr(self), SWIGTYPE_p_zx_ctx.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_ctx conf_ctx_get(zxid_conf self) {
    long cPtr = zxidjniJNI.zxid_conf_ctx_get(zxid_conf.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_ctx(cPtr, false);
  }

  public static void conf_cot_set(zxid_conf self, SWIGTYPE_p_zxid_entity value) {
    zxidjniJNI.zxid_conf_cot_set(zxid_conf.getCPtr(self), SWIGTYPE_p_zxid_entity.getCPtr(value));
  }

  public static SWIGTYPE_p_zxid_entity conf_cot_get(zxid_conf self) {
    long cPtr = zxidjniJNI.zxid_conf_cot_get(zxid_conf.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zxid_entity(cPtr, false);
  }

  public static void conf_path_supplied_set(zxid_conf self, int value) {
    zxidjniJNI.zxid_conf_path_supplied_set(zxid_conf.getCPtr(self), value);
  }

  public static int conf_path_supplied_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_path_supplied_get(zxid_conf.getCPtr(self));
  }

  public static void conf_path_len_set(zxid_conf self, int value) {
    zxidjniJNI.zxid_conf_path_len_set(zxid_conf.getCPtr(self), value);
  }

  public static int conf_path_len_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_path_len_get(zxid_conf.getCPtr(self));
  }

  public static void conf_path_set(zxid_conf self, String value) {
    zxidjniJNI.zxid_conf_path_set(zxid_conf.getCPtr(self), value);
  }

  public static String conf_path_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_path_get(zxid_conf.getCPtr(self));
  }

  public static void conf_url_set(zxid_conf self, String value) {
    zxidjniJNI.zxid_conf_url_set(zxid_conf.getCPtr(self), value);
  }

  public static String conf_url_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_url_get(zxid_conf.getCPtr(self));
  }

  public static void conf_non_standard_entityid_set(zxid_conf self, String value) {
    zxidjniJNI.zxid_conf_non_standard_entityid_set(zxid_conf.getCPtr(self), value);
  }

  public static String conf_non_standard_entityid_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_non_standard_entityid_get(zxid_conf.getCPtr(self));
  }

  public static void conf_redirect_hack_imposed_url_set(zxid_conf self, String value) {
    zxidjniJNI.zxid_conf_redirect_hack_imposed_url_set(zxid_conf.getCPtr(self), value);
  }

  public static String conf_redirect_hack_imposed_url_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_redirect_hack_imposed_url_get(zxid_conf.getCPtr(self));
  }

  public static void conf_redirect_hack_zxid_url_set(zxid_conf self, String value) {
    zxidjniJNI.zxid_conf_redirect_hack_zxid_url_set(zxid_conf.getCPtr(self), value);
  }

  public static String conf_redirect_hack_zxid_url_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_redirect_hack_zxid_url_get(zxid_conf.getCPtr(self));
  }

  public static void conf_redirect_hack_zxid_qs_set(zxid_conf self, String value) {
    zxidjniJNI.zxid_conf_redirect_hack_zxid_qs_set(zxid_conf.getCPtr(self), value);
  }

  public static String conf_redirect_hack_zxid_qs_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_redirect_hack_zxid_qs_get(zxid_conf.getCPtr(self));
  }

  public static void conf_cdc_url_set(zxid_conf self, String value) {
    zxidjniJNI.zxid_conf_cdc_url_set(zxid_conf.getCPtr(self), value);
  }

  public static String conf_cdc_url_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_cdc_url_get(zxid_conf.getCPtr(self));
  }

  public static void conf_cdc_choice_set(zxid_conf self, char value) {
    zxidjniJNI.zxid_conf_cdc_choice_set(zxid_conf.getCPtr(self), value);
  }

  public static char conf_cdc_choice_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_cdc_choice_get(zxid_conf.getCPtr(self));
  }

  public static void conf_md_fetch_set(zxid_conf self, char value) {
    zxidjniJNI.zxid_conf_md_fetch_set(zxid_conf.getCPtr(self), value);
  }

  public static char conf_md_fetch_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_md_fetch_get(zxid_conf.getCPtr(self));
  }

  public static void conf_md_populate_cache_set(zxid_conf self, char value) {
    zxidjniJNI.zxid_conf_md_populate_cache_set(zxid_conf.getCPtr(self), value);
  }

  public static char conf_md_populate_cache_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_md_populate_cache_get(zxid_conf.getCPtr(self));
  }

  public static void conf_md_cache_first_set(zxid_conf self, char value) {
    zxidjniJNI.zxid_conf_md_cache_first_set(zxid_conf.getCPtr(self), value);
  }

  public static char conf_md_cache_first_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_md_cache_first_get(zxid_conf.getCPtr(self));
  }

  public static void conf_md_cache_last_set(zxid_conf self, char value) {
    zxidjniJNI.zxid_conf_md_cache_last_set(zxid_conf.getCPtr(self), value);
  }

  public static char conf_md_cache_last_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_md_cache_last_get(zxid_conf.getCPtr(self));
  }

  public static void conf_auto_cert_set(zxid_conf self, char value) {
    zxidjniJNI.zxid_conf_auto_cert_set(zxid_conf.getCPtr(self), value);
  }

  public static char conf_auto_cert_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_auto_cert_get(zxid_conf.getCPtr(self));
  }

  public static void conf_user_local_set(zxid_conf self, char value) {
    zxidjniJNI.zxid_conf_user_local_set(zxid_conf.getCPtr(self), value);
  }

  public static char conf_user_local_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_user_local_get(zxid_conf.getCPtr(self));
  }

  public static void conf_idp_ena_set(zxid_conf self, char value) {
    zxidjniJNI.zxid_conf_idp_ena_set(zxid_conf.getCPtr(self), value);
  }

  public static char conf_idp_ena_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_idp_ena_get(zxid_conf.getCPtr(self));
  }

  public static void conf_pdp_ena_set(zxid_conf self, char value) {
    zxidjniJNI.zxid_conf_pdp_ena_set(zxid_conf.getCPtr(self), value);
  }

  public static char conf_pdp_ena_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_pdp_ena_get(zxid_conf.getCPtr(self));
  }

  public static void conf_authn_req_sign_set(zxid_conf self, char value) {
    zxidjniJNI.zxid_conf_authn_req_sign_set(zxid_conf.getCPtr(self), value);
  }

  public static char conf_authn_req_sign_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_authn_req_sign_get(zxid_conf.getCPtr(self));
  }

  public static void conf_want_authn_req_signed_set(zxid_conf self, char value) {
    zxidjniJNI.zxid_conf_want_authn_req_signed_set(zxid_conf.getCPtr(self), value);
  }

  public static char conf_want_authn_req_signed_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_want_authn_req_signed_get(zxid_conf.getCPtr(self));
  }

  public static void conf_want_sso_a7n_signed_set(zxid_conf self, char value) {
    zxidjniJNI.zxid_conf_want_sso_a7n_signed_set(zxid_conf.getCPtr(self), value);
  }

  public static char conf_want_sso_a7n_signed_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_want_sso_a7n_signed_get(zxid_conf.getCPtr(self));
  }

  public static void conf_sso_soap_sign_set(zxid_conf self, char value) {
    zxidjniJNI.zxid_conf_sso_soap_sign_set(zxid_conf.getCPtr(self), value);
  }

  public static char conf_sso_soap_sign_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_sso_soap_sign_get(zxid_conf.getCPtr(self));
  }

  public static void conf_sso_soap_resp_sign_set(zxid_conf self, char value) {
    zxidjniJNI.zxid_conf_sso_soap_resp_sign_set(zxid_conf.getCPtr(self), value);
  }

  public static char conf_sso_soap_resp_sign_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_sso_soap_resp_sign_get(zxid_conf.getCPtr(self));
  }

  public static void conf_sso_sign_set(zxid_conf self, char value) {
    zxidjniJNI.zxid_conf_sso_sign_set(zxid_conf.getCPtr(self), value);
  }

  public static char conf_sso_sign_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_sso_sign_get(zxid_conf.getCPtr(self));
  }

  public static void conf_wsc_sign_set(zxid_conf self, char value) {
    zxidjniJNI.zxid_conf_wsc_sign_set(zxid_conf.getCPtr(self), value);
  }

  public static char conf_wsc_sign_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_wsc_sign_get(zxid_conf.getCPtr(self));
  }

  public static void conf_wsp_sign_set(zxid_conf self, char value) {
    zxidjniJNI.zxid_conf_wsp_sign_set(zxid_conf.getCPtr(self), value);
  }

  public static char conf_wsp_sign_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_wsp_sign_get(zxid_conf.getCPtr(self));
  }

  public static void conf_nameid_enc_set(zxid_conf self, char value) {
    zxidjniJNI.zxid_conf_nameid_enc_set(zxid_conf.getCPtr(self), value);
  }

  public static char conf_nameid_enc_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_nameid_enc_get(zxid_conf.getCPtr(self));
  }

  public static void conf_post_a7n_enc_set(zxid_conf self, char value) {
    zxidjniJNI.zxid_conf_post_a7n_enc_set(zxid_conf.getCPtr(self), value);
  }

  public static char conf_post_a7n_enc_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_post_a7n_enc_get(zxid_conf.getCPtr(self));
  }

  public static void conf_di_allow_create_set(zxid_conf self, char value) {
    zxidjniJNI.zxid_conf_di_allow_create_set(zxid_conf.getCPtr(self), value);
  }

  public static char conf_di_allow_create_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_di_allow_create_get(zxid_conf.getCPtr(self));
  }

  public static void conf_di_nid_fmt_set(zxid_conf self, char value) {
    zxidjniJNI.zxid_conf_di_nid_fmt_set(zxid_conf.getCPtr(self), value);
  }

  public static char conf_di_nid_fmt_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_di_nid_fmt_get(zxid_conf.getCPtr(self));
  }

  public static void conf_di_a7n_enc_set(zxid_conf self, char value) {
    zxidjniJNI.zxid_conf_di_a7n_enc_set(zxid_conf.getCPtr(self), value);
  }

  public static char conf_di_a7n_enc_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_di_a7n_enc_get(zxid_conf.getCPtr(self));
  }

  public static void conf_show_conf_set(zxid_conf self, char value) {
    zxidjniJNI.zxid_conf_show_conf_set(zxid_conf.getCPtr(self), value);
  }

  public static char conf_show_conf_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_show_conf_get(zxid_conf.getCPtr(self));
  }

  public static void conf_affiliation_set(zxid_conf self, String value) {
    zxidjniJNI.zxid_conf_affiliation_set(zxid_conf.getCPtr(self), value);
  }

  public static String conf_affiliation_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_affiliation_get(zxid_conf.getCPtr(self));
  }

  public static void conf_nice_name_set(zxid_conf self, String value) {
    zxidjniJNI.zxid_conf_nice_name_set(zxid_conf.getCPtr(self), value);
  }

  public static String conf_nice_name_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_nice_name_get(zxid_conf.getCPtr(self));
  }

  public static void conf_ses_arch_dir_set(zxid_conf self, String value) {
    zxidjniJNI.zxid_conf_ses_arch_dir_set(zxid_conf.getCPtr(self), value);
  }

  public static String conf_ses_arch_dir_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_ses_arch_dir_get(zxid_conf.getCPtr(self));
  }

  public static void conf_ses_cookie_name_set(zxid_conf self, String value) {
    zxidjniJNI.zxid_conf_ses_cookie_name_set(zxid_conf.getCPtr(self), value);
  }

  public static String conf_ses_cookie_name_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_ses_cookie_name_get(zxid_conf.getCPtr(self));
  }

  public static void conf_ipport_set(zxid_conf self, String value) {
    zxidjniJNI.zxid_conf_ipport_set(zxid_conf.getCPtr(self), value);
  }

  public static String conf_ipport_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_ipport_get(zxid_conf.getCPtr(self));
  }

  public static void conf_log_err_set(zxid_conf self, char value) {
    zxidjniJNI.zxid_conf_log_err_set(zxid_conf.getCPtr(self), value);
  }

  public static char conf_log_err_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_log_err_get(zxid_conf.getCPtr(self));
  }

  public static void conf_log_act_set(zxid_conf self, char value) {
    zxidjniJNI.zxid_conf_log_act_set(zxid_conf.getCPtr(self), value);
  }

  public static char conf_log_act_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_log_act_get(zxid_conf.getCPtr(self));
  }

  public static void conf_log_issue_a7n_set(zxid_conf self, char value) {
    zxidjniJNI.zxid_conf_log_issue_a7n_set(zxid_conf.getCPtr(self), value);
  }

  public static char conf_log_issue_a7n_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_log_issue_a7n_get(zxid_conf.getCPtr(self));
  }

  public static void conf_log_issue_msg_set(zxid_conf self, char value) {
    zxidjniJNI.zxid_conf_log_issue_msg_set(zxid_conf.getCPtr(self), value);
  }

  public static char conf_log_issue_msg_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_log_issue_msg_get(zxid_conf.getCPtr(self));
  }

  public static void conf_log_rely_a7n_set(zxid_conf self, char value) {
    zxidjniJNI.zxid_conf_log_rely_a7n_set(zxid_conf.getCPtr(self), value);
  }

  public static char conf_log_rely_a7n_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_log_rely_a7n_get(zxid_conf.getCPtr(self));
  }

  public static void conf_log_rely_msg_set(zxid_conf self, char value) {
    zxidjniJNI.zxid_conf_log_rely_msg_set(zxid_conf.getCPtr(self), value);
  }

  public static char conf_log_rely_msg_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_log_rely_msg_get(zxid_conf.getCPtr(self));
  }

  public static void conf_log_err_in_act_set(zxid_conf self, char value) {
    zxidjniJNI.zxid_conf_log_err_in_act_set(zxid_conf.getCPtr(self), value);
  }

  public static char conf_log_err_in_act_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_log_err_in_act_get(zxid_conf.getCPtr(self));
  }

  public static void conf_log_act_in_err_set(zxid_conf self, char value) {
    zxidjniJNI.zxid_conf_log_act_in_err_set(zxid_conf.getCPtr(self), value);
  }

  public static char conf_log_act_in_err_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_log_act_in_err_get(zxid_conf.getCPtr(self));
  }

  public static void conf_log_sigfail_is_err_set(zxid_conf self, char value) {
    zxidjniJNI.zxid_conf_log_sigfail_is_err_set(zxid_conf.getCPtr(self), value);
  }

  public static char conf_log_sigfail_is_err_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_log_sigfail_is_err_get(zxid_conf.getCPtr(self));
  }

  public static void conf_log_level_set(zxid_conf self, char value) {
    zxidjniJNI.zxid_conf_log_level_set(zxid_conf.getCPtr(self), value);
  }

  public static char conf_log_level_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_log_level_get(zxid_conf.getCPtr(self));
  }

  public static void conf_sig_fatal_set(zxid_conf self, char value) {
    zxidjniJNI.zxid_conf_sig_fatal_set(zxid_conf.getCPtr(self), value);
  }

  public static char conf_sig_fatal_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_sig_fatal_get(zxid_conf.getCPtr(self));
  }

  public static void conf_nosig_fatal_set(zxid_conf self, char value) {
    zxidjniJNI.zxid_conf_nosig_fatal_set(zxid_conf.getCPtr(self), value);
  }

  public static char conf_nosig_fatal_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_nosig_fatal_get(zxid_conf.getCPtr(self));
  }

  public static void conf_msg_sig_ok_set(zxid_conf self, char value) {
    zxidjniJNI.zxid_conf_msg_sig_ok_set(zxid_conf.getCPtr(self), value);
  }

  public static char conf_msg_sig_ok_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_msg_sig_ok_get(zxid_conf.getCPtr(self));
  }

  public static void conf_timeout_fatal_set(zxid_conf self, char value) {
    zxidjniJNI.zxid_conf_timeout_fatal_set(zxid_conf.getCPtr(self), value);
  }

  public static char conf_timeout_fatal_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_timeout_fatal_get(zxid_conf.getCPtr(self));
  }

  public static void conf_audience_fatal_set(zxid_conf self, char value) {
    zxidjniJNI.zxid_conf_audience_fatal_set(zxid_conf.getCPtr(self), value);
  }

  public static char conf_audience_fatal_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_audience_fatal_get(zxid_conf.getCPtr(self));
  }

  public static void conf_dup_a7n_fatal_set(zxid_conf self, char value) {
    zxidjniJNI.zxid_conf_dup_a7n_fatal_set(zxid_conf.getCPtr(self), value);
  }

  public static char conf_dup_a7n_fatal_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_dup_a7n_fatal_get(zxid_conf.getCPtr(self));
  }

  public static void conf_dup_msg_fatal_set(zxid_conf self, char value) {
    zxidjniJNI.zxid_conf_dup_msg_fatal_set(zxid_conf.getCPtr(self), value);
  }

  public static char conf_dup_msg_fatal_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_dup_msg_fatal_get(zxid_conf.getCPtr(self));
  }

  public static void conf_wsp_nosig_fatal_set(zxid_conf self, char value) {
    zxidjniJNI.zxid_conf_wsp_nosig_fatal_set(zxid_conf.getCPtr(self), value);
  }

  public static char conf_wsp_nosig_fatal_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_wsp_nosig_fatal_get(zxid_conf.getCPtr(self));
  }

  public static void conf_notimestamp_fatal_set(zxid_conf self, char value) {
    zxidjniJNI.zxid_conf_notimestamp_fatal_set(zxid_conf.getCPtr(self), value);
  }

  public static char conf_notimestamp_fatal_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_notimestamp_fatal_get(zxid_conf.getCPtr(self));
  }

  public static void conf_redir_to_content_set(zxid_conf self, char value) {
    zxidjniJNI.zxid_conf_redir_to_content_set(zxid_conf.getCPtr(self), value);
  }

  public static char conf_redir_to_content_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_redir_to_content_get(zxid_conf.getCPtr(self));
  }

  public static void conf_remote_user_ena_set(zxid_conf self, char value) {
    zxidjniJNI.zxid_conf_remote_user_ena_set(zxid_conf.getCPtr(self), value);
  }

  public static char conf_remote_user_ena_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_remote_user_ena_get(zxid_conf.getCPtr(self));
  }

  public static void conf_anon_ok_set(zxid_conf self, String value) {
    zxidjniJNI.zxid_conf_anon_ok_set(zxid_conf.getCPtr(self), value);
  }

  public static String conf_anon_ok_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_anon_ok_get(zxid_conf.getCPtr(self));
  }

  public static void conf_required_authnctx_set(zxid_conf self, SWIGTYPE_p_p_char value) {
    zxidjniJNI.zxid_conf_required_authnctx_set(zxid_conf.getCPtr(self), SWIGTYPE_p_p_char.getCPtr(value));
  }

  public static SWIGTYPE_p_p_char conf_required_authnctx_get(zxid_conf self) {
    long cPtr = zxidjniJNI.zxid_conf_required_authnctx_get(zxid_conf.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_p_char(cPtr, false);
  }

  public static void conf_issue_authnctx_pw_set(zxid_conf self, String value) {
    zxidjniJNI.zxid_conf_issue_authnctx_pw_set(zxid_conf.getCPtr(self), value);
  }

  public static String conf_issue_authnctx_pw_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_issue_authnctx_pw_get(zxid_conf.getCPtr(self));
  }

  public static void conf_idp_pref_acs_binding_set(zxid_conf self, String value) {
    zxidjniJNI.zxid_conf_idp_pref_acs_binding_set(zxid_conf.getCPtr(self), value);
  }

  public static String conf_idp_pref_acs_binding_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_idp_pref_acs_binding_get(zxid_conf.getCPtr(self));
  }

  public static void conf_before_slop_set(zxid_conf self, int value) {
    zxidjniJNI.zxid_conf_before_slop_set(zxid_conf.getCPtr(self), value);
  }

  public static int conf_before_slop_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_before_slop_get(zxid_conf.getCPtr(self));
  }

  public static void conf_after_slop_set(zxid_conf self, int value) {
    zxidjniJNI.zxid_conf_after_slop_set(zxid_conf.getCPtr(self), value);
  }

  public static int conf_after_slop_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_after_slop_get(zxid_conf.getCPtr(self));
  }

  public static void conf_timeskew_set(zxid_conf self, int value) {
    zxidjniJNI.zxid_conf_timeskew_set(zxid_conf.getCPtr(self), value);
  }

  public static int conf_timeskew_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_timeskew_get(zxid_conf.getCPtr(self));
  }

  public static void conf_a7nttl_set(zxid_conf self, int value) {
    zxidjniJNI.zxid_conf_a7nttl_set(zxid_conf.getCPtr(self), value);
  }

  public static int conf_a7nttl_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_a7nttl_get(zxid_conf.getCPtr(self));
  }

  public static void conf_pdp_url_set(zxid_conf self, String value) {
    zxidjniJNI.zxid_conf_pdp_url_set(zxid_conf.getCPtr(self), value);
  }

  public static String conf_pdp_url_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_pdp_url_get(zxid_conf.getCPtr(self));
  }

  public static void conf_pdp_call_url_set(zxid_conf self, String value) {
    zxidjniJNI.zxid_conf_pdp_call_url_set(zxid_conf.getCPtr(self), value);
  }

  public static String conf_pdp_call_url_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_pdp_call_url_get(zxid_conf.getCPtr(self));
  }

  public static void conf_xasp_vers_set(zxid_conf self, String value) {
    zxidjniJNI.zxid_conf_xasp_vers_set(zxid_conf.getCPtr(self), value);
  }

  public static String conf_xasp_vers_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_xasp_vers_get(zxid_conf.getCPtr(self));
  }

  public static void conf_need_set(zxid_conf self, SWIGTYPE_p_zxid_need value) {
    zxidjniJNI.zxid_conf_need_set(zxid_conf.getCPtr(self), SWIGTYPE_p_zxid_need.getCPtr(value));
  }

  public static SWIGTYPE_p_zxid_need conf_need_get(zxid_conf self) {
    long cPtr = zxidjniJNI.zxid_conf_need_get(zxid_conf.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zxid_need(cPtr, false);
  }

  public static void conf_want_set(zxid_conf self, SWIGTYPE_p_zxid_need value) {
    zxidjniJNI.zxid_conf_want_set(zxid_conf.getCPtr(self), SWIGTYPE_p_zxid_need.getCPtr(value));
  }

  public static SWIGTYPE_p_zxid_need conf_want_get(zxid_conf self) {
    long cPtr = zxidjniJNI.zxid_conf_want_get(zxid_conf.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zxid_need(cPtr, false);
  }

  public static void conf_attrsrc_set(zxid_conf self, SWIGTYPE_p_zxid_atsrc value) {
    zxidjniJNI.zxid_conf_attrsrc_set(zxid_conf.getCPtr(self), SWIGTYPE_p_zxid_atsrc.getCPtr(value));
  }

  public static SWIGTYPE_p_zxid_atsrc conf_attrsrc_get(zxid_conf self) {
    long cPtr = zxidjniJNI.zxid_conf_attrsrc_get(zxid_conf.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zxid_atsrc(cPtr, false);
  }

  public static void conf_inmap_set(zxid_conf self, SWIGTYPE_p_zxid_map value) {
    zxidjniJNI.zxid_conf_inmap_set(zxid_conf.getCPtr(self), SWIGTYPE_p_zxid_map.getCPtr(value));
  }

  public static SWIGTYPE_p_zxid_map conf_inmap_get(zxid_conf self) {
    long cPtr = zxidjniJNI.zxid_conf_inmap_get(zxid_conf.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zxid_map(cPtr, false);
  }

  public static void conf_outmap_set(zxid_conf self, SWIGTYPE_p_zxid_map value) {
    zxidjniJNI.zxid_conf_outmap_set(zxid_conf.getCPtr(self), SWIGTYPE_p_zxid_map.getCPtr(value));
  }

  public static SWIGTYPE_p_zxid_map conf_outmap_get(zxid_conf self) {
    long cPtr = zxidjniJNI.zxid_conf_outmap_get(zxid_conf.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zxid_map(cPtr, false);
  }

  public static void conf_pepmap_set(zxid_conf self, SWIGTYPE_p_zxid_map value) {
    zxidjniJNI.zxid_conf_pepmap_set(zxid_conf.getCPtr(self), SWIGTYPE_p_zxid_map.getCPtr(value));
  }

  public static SWIGTYPE_p_zxid_map conf_pepmap_get(zxid_conf self) {
    long cPtr = zxidjniJNI.zxid_conf_pepmap_get(zxid_conf.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zxid_map(cPtr, false);
  }

  public static void conf_localpdp_role_permit_set(zxid_conf self, SWIGTYPE_p_zxid_cstr_list value) {
    zxidjniJNI.zxid_conf_localpdp_role_permit_set(zxid_conf.getCPtr(self), SWIGTYPE_p_zxid_cstr_list.getCPtr(value));
  }

  public static SWIGTYPE_p_zxid_cstr_list conf_localpdp_role_permit_get(zxid_conf self) {
    long cPtr = zxidjniJNI.zxid_conf_localpdp_role_permit_get(zxid_conf.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zxid_cstr_list(cPtr, false);
  }

  public static void conf_localpdp_role_deny_set(zxid_conf self, SWIGTYPE_p_zxid_cstr_list value) {
    zxidjniJNI.zxid_conf_localpdp_role_deny_set(zxid_conf.getCPtr(self), SWIGTYPE_p_zxid_cstr_list.getCPtr(value));
  }

  public static SWIGTYPE_p_zxid_cstr_list conf_localpdp_role_deny_get(zxid_conf self) {
    long cPtr = zxidjniJNI.zxid_conf_localpdp_role_deny_get(zxid_conf.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zxid_cstr_list(cPtr, false);
  }

  public static void conf_localpdp_idpnid_permit_set(zxid_conf self, SWIGTYPE_p_zxid_cstr_list value) {
    zxidjniJNI.zxid_conf_localpdp_idpnid_permit_set(zxid_conf.getCPtr(self), SWIGTYPE_p_zxid_cstr_list.getCPtr(value));
  }

  public static SWIGTYPE_p_zxid_cstr_list conf_localpdp_idpnid_permit_get(zxid_conf self) {
    long cPtr = zxidjniJNI.zxid_conf_localpdp_idpnid_permit_get(zxid_conf.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zxid_cstr_list(cPtr, false);
  }

  public static void conf_localpdp_idpnid_deny_set(zxid_conf self, SWIGTYPE_p_zxid_cstr_list value) {
    zxidjniJNI.zxid_conf_localpdp_idpnid_deny_set(zxid_conf.getCPtr(self), SWIGTYPE_p_zxid_cstr_list.getCPtr(value));
  }

  public static SWIGTYPE_p_zxid_cstr_list conf_localpdp_idpnid_deny_get(zxid_conf self) {
    long cPtr = zxidjniJNI.zxid_conf_localpdp_idpnid_deny_get(zxid_conf.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zxid_cstr_list(cPtr, false);
  }

  public static void conf_max_soap_retry_set(zxid_conf self, int value) {
    zxidjniJNI.zxid_conf_max_soap_retry_set(zxid_conf.getCPtr(self), value);
  }

  public static int conf_max_soap_retry_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_max_soap_retry_get(zxid_conf.getCPtr(self));
  }

  public static void conf_defaultqs_set(zxid_conf self, String value) {
    zxidjniJNI.zxid_conf_defaultqs_set(zxid_conf.getCPtr(self), value);
  }

  public static String conf_defaultqs_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_defaultqs_get(zxid_conf.getCPtr(self));
  }

  public static void conf_mod_saml_attr_prefix_set(zxid_conf self, String value) {
    zxidjniJNI.zxid_conf_mod_saml_attr_prefix_set(zxid_conf.getCPtr(self), value);
  }

  public static String conf_mod_saml_attr_prefix_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_mod_saml_attr_prefix_get(zxid_conf.getCPtr(self));
  }

  public static void conf_idp_sel_page_set(zxid_conf self, String value) {
    zxidjniJNI.zxid_conf_idp_sel_page_set(zxid_conf.getCPtr(self), value);
  }

  public static String conf_idp_sel_page_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_idp_sel_page_get(zxid_conf.getCPtr(self));
  }

  public static void conf_idp_sel_start_set(zxid_conf self, String value) {
    zxidjniJNI.zxid_conf_idp_sel_start_set(zxid_conf.getCPtr(self), value);
  }

  public static String conf_idp_sel_start_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_idp_sel_start_get(zxid_conf.getCPtr(self));
  }

  public static void conf_idp_sel_new_idp_set(zxid_conf self, String value) {
    zxidjniJNI.zxid_conf_idp_sel_new_idp_set(zxid_conf.getCPtr(self), value);
  }

  public static String conf_idp_sel_new_idp_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_idp_sel_new_idp_get(zxid_conf.getCPtr(self));
  }

  public static void conf_idp_sel_our_eid_set(zxid_conf self, String value) {
    zxidjniJNI.zxid_conf_idp_sel_our_eid_set(zxid_conf.getCPtr(self), value);
  }

  public static String conf_idp_sel_our_eid_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_idp_sel_our_eid_get(zxid_conf.getCPtr(self));
  }

  public static void conf_idp_sel_tech_user_set(zxid_conf self, String value) {
    zxidjniJNI.zxid_conf_idp_sel_tech_user_set(zxid_conf.getCPtr(self), value);
  }

  public static String conf_idp_sel_tech_user_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_idp_sel_tech_user_get(zxid_conf.getCPtr(self));
  }

  public static void conf_idp_sel_tech_site_set(zxid_conf self, String value) {
    zxidjniJNI.zxid_conf_idp_sel_tech_site_set(zxid_conf.getCPtr(self), value);
  }

  public static String conf_idp_sel_tech_site_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_idp_sel_tech_site_get(zxid_conf.getCPtr(self));
  }

  public static void conf_idp_sel_footer_set(zxid_conf self, String value) {
    zxidjniJNI.zxid_conf_idp_sel_footer_set(zxid_conf.getCPtr(self), value);
  }

  public static String conf_idp_sel_footer_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_idp_sel_footer_get(zxid_conf.getCPtr(self));
  }

  public static void conf_idp_sel_end_set(zxid_conf self, String value) {
    zxidjniJNI.zxid_conf_idp_sel_end_set(zxid_conf.getCPtr(self), value);
  }

  public static String conf_idp_sel_end_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_idp_sel_end_get(zxid_conf.getCPtr(self));
  }

  public static void conf_an_page_set(zxid_conf self, String value) {
    zxidjniJNI.zxid_conf_an_page_set(zxid_conf.getCPtr(self), value);
  }

  public static String conf_an_page_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_an_page_get(zxid_conf.getCPtr(self));
  }

  public static void conf_an_start_set(zxid_conf self, String value) {
    zxidjniJNI.zxid_conf_an_start_set(zxid_conf.getCPtr(self), value);
  }

  public static String conf_an_start_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_an_start_get(zxid_conf.getCPtr(self));
  }

  public static void conf_an_our_eid_set(zxid_conf self, String value) {
    zxidjniJNI.zxid_conf_an_our_eid_set(zxid_conf.getCPtr(self), value);
  }

  public static String conf_an_our_eid_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_an_our_eid_get(zxid_conf.getCPtr(self));
  }

  public static void conf_an_tech_user_set(zxid_conf self, String value) {
    zxidjniJNI.zxid_conf_an_tech_user_set(zxid_conf.getCPtr(self), value);
  }

  public static String conf_an_tech_user_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_an_tech_user_get(zxid_conf.getCPtr(self));
  }

  public static void conf_an_tech_site_set(zxid_conf self, String value) {
    zxidjniJNI.zxid_conf_an_tech_site_set(zxid_conf.getCPtr(self), value);
  }

  public static String conf_an_tech_site_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_an_tech_site_get(zxid_conf.getCPtr(self));
  }

  public static void conf_an_footer_set(zxid_conf self, String value) {
    zxidjniJNI.zxid_conf_an_footer_set(zxid_conf.getCPtr(self), value);
  }

  public static String conf_an_footer_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_an_footer_get(zxid_conf.getCPtr(self));
  }

  public static void conf_an_end_set(zxid_conf self, String value) {
    zxidjniJNI.zxid_conf_an_end_set(zxid_conf.getCPtr(self), value);
  }

  public static String conf_an_end_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_an_end_get(zxid_conf.getCPtr(self));
  }

  public static void conf_mgmt_start_set(zxid_conf self, String value) {
    zxidjniJNI.zxid_conf_mgmt_start_set(zxid_conf.getCPtr(self), value);
  }

  public static String conf_mgmt_start_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_mgmt_start_get(zxid_conf.getCPtr(self));
  }

  public static void conf_mgmt_logout_set(zxid_conf self, String value) {
    zxidjniJNI.zxid_conf_mgmt_logout_set(zxid_conf.getCPtr(self), value);
  }

  public static String conf_mgmt_logout_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_mgmt_logout_get(zxid_conf.getCPtr(self));
  }

  public static void conf_mgmt_defed_set(zxid_conf self, String value) {
    zxidjniJNI.zxid_conf_mgmt_defed_set(zxid_conf.getCPtr(self), value);
  }

  public static String conf_mgmt_defed_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_mgmt_defed_get(zxid_conf.getCPtr(self));
  }

  public static void conf_mgmt_footer_set(zxid_conf self, String value) {
    zxidjniJNI.zxid_conf_mgmt_footer_set(zxid_conf.getCPtr(self), value);
  }

  public static String conf_mgmt_footer_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_mgmt_footer_get(zxid_conf.getCPtr(self));
  }

  public static void conf_mgmt_end_set(zxid_conf self, String value) {
    zxidjniJNI.zxid_conf_mgmt_end_set(zxid_conf.getCPtr(self), value);
  }

  public static String conf_mgmt_end_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_mgmt_end_get(zxid_conf.getCPtr(self));
  }

  public static void conf_dbg_set(zxid_conf self, String value) {
    zxidjniJNI.zxid_conf_dbg_set(zxid_conf.getCPtr(self), value);
  }

  public static String conf_dbg_get(zxid_conf self) {
    return zxidjniJNI.zxid_conf_dbg_get(zxid_conf.getCPtr(self));
  }

  public static zxid_conf new_zxid_conf() {
    long cPtr = zxidjniJNI.new_zxid_conf();
    return (cPtr == 0) ? null : new zxid_conf(cPtr, true);
  }

  public static void delete_zxid_conf(zxid_conf self) {
    zxidjniJNI.delete_zxid_conf(zxid_conf.getCPtr(self));
  }

  public static void cgi_magic_set(SWIGTYPE_p_zxid_cgi self, long value) {
    zxidjniJNI.zxid_cgi_magic_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static long cgi_magic_get(SWIGTYPE_p_zxid_cgi self) {
    return zxidjniJNI.zxid_cgi_magic_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
  }

  public static void cgi_op_set(SWIGTYPE_p_zxid_cgi self, char value) {
    zxidjniJNI.zxid_cgi_op_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static char cgi_op_get(SWIGTYPE_p_zxid_cgi self) {
    return zxidjniJNI.zxid_cgi_op_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
  }

  public static void cgi_pr_ix_set(SWIGTYPE_p_zxid_cgi self, char value) {
    zxidjniJNI.zxid_cgi_pr_ix_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static char cgi_pr_ix_get(SWIGTYPE_p_zxid_cgi self) {
    return zxidjniJNI.zxid_cgi_pr_ix_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
  }

  public static void cgi_allow_create_set(SWIGTYPE_p_zxid_cgi self, char value) {
    zxidjniJNI.zxid_cgi_allow_create_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static char cgi_allow_create_get(SWIGTYPE_p_zxid_cgi self) {
    return zxidjniJNI.zxid_cgi_allow_create_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
  }

  public static void cgi_ispassive_set(SWIGTYPE_p_zxid_cgi self, char value) {
    zxidjniJNI.zxid_cgi_ispassive_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static char cgi_ispassive_get(SWIGTYPE_p_zxid_cgi self) {
    return zxidjniJNI.zxid_cgi_ispassive_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
  }

  public static void cgi_force_authn_set(SWIGTYPE_p_zxid_cgi self, char value) {
    zxidjniJNI.zxid_cgi_force_authn_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static char cgi_force_authn_get(SWIGTYPE_p_zxid_cgi self) {
    return zxidjniJNI.zxid_cgi_force_authn_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
  }

  public static void cgi_enc_hint_set(SWIGTYPE_p_zxid_cgi self, char value) {
    zxidjniJNI.zxid_cgi_enc_hint_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static char cgi_enc_hint_get(SWIGTYPE_p_zxid_cgi self) {
    return zxidjniJNI.zxid_cgi_enc_hint_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
  }

  public static void cgi_pad6_set(SWIGTYPE_p_zxid_cgi self, char value) {
    zxidjniJNI.zxid_cgi_pad6_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static char cgi_pad6_get(SWIGTYPE_p_zxid_cgi self) {
    return zxidjniJNI.zxid_cgi_pad6_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
  }

  public static void cgi_pad7_set(SWIGTYPE_p_zxid_cgi self, char value) {
    zxidjniJNI.zxid_cgi_pad7_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static char cgi_pad7_get(SWIGTYPE_p_zxid_cgi self) {
    return zxidjniJNI.zxid_cgi_pad7_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
  }

  public static void cgi_sid_set(SWIGTYPE_p_zxid_cgi self, String value) {
    zxidjniJNI.zxid_cgi_sid_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static String cgi_sid_get(SWIGTYPE_p_zxid_cgi self) {
    return zxidjniJNI.zxid_cgi_sid_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
  }

  public static void cgi_nid_set(SWIGTYPE_p_zxid_cgi self, String value) {
    zxidjniJNI.zxid_cgi_nid_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static String cgi_nid_get(SWIGTYPE_p_zxid_cgi self) {
    return zxidjniJNI.zxid_cgi_nid_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
  }

  public static void cgi_uid_set(SWIGTYPE_p_zxid_cgi self, String value) {
    zxidjniJNI.zxid_cgi_uid_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static String cgi_uid_get(SWIGTYPE_p_zxid_cgi self) {
    return zxidjniJNI.zxid_cgi_uid_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
  }

  public static void cgi_pw_set(SWIGTYPE_p_zxid_cgi self, String value) {
    zxidjniJNI.zxid_cgi_pw_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static String cgi_pw_get(SWIGTYPE_p_zxid_cgi self) {
    return zxidjniJNI.zxid_cgi_pw_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
  }

  public static void cgi_ssoreq_set(SWIGTYPE_p_zxid_cgi self, String value) {
    zxidjniJNI.zxid_cgi_ssoreq_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static String cgi_ssoreq_get(SWIGTYPE_p_zxid_cgi self) {
    return zxidjniJNI.zxid_cgi_ssoreq_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
  }

  public static void cgi_cdc_set(SWIGTYPE_p_zxid_cgi self, String value) {
    zxidjniJNI.zxid_cgi_cdc_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static String cgi_cdc_get(SWIGTYPE_p_zxid_cgi self) {
    return zxidjniJNI.zxid_cgi_cdc_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
  }

  public static void cgi_eid_set(SWIGTYPE_p_zxid_cgi self, String value) {
    zxidjniJNI.zxid_cgi_eid_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static String cgi_eid_get(SWIGTYPE_p_zxid_cgi self) {
    return zxidjniJNI.zxid_cgi_eid_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
  }

  public static void cgi_nid_fmt_set(SWIGTYPE_p_zxid_cgi self, String value) {
    zxidjniJNI.zxid_cgi_nid_fmt_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static String cgi_nid_fmt_get(SWIGTYPE_p_zxid_cgi self) {
    return zxidjniJNI.zxid_cgi_nid_fmt_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
  }

  public static void cgi_affil_set(SWIGTYPE_p_zxid_cgi self, String value) {
    zxidjniJNI.zxid_cgi_affil_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static String cgi_affil_get(SWIGTYPE_p_zxid_cgi self) {
    return zxidjniJNI.zxid_cgi_affil_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
  }

  public static void cgi_consent_set(SWIGTYPE_p_zxid_cgi self, String value) {
    zxidjniJNI.zxid_cgi_consent_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static String cgi_consent_get(SWIGTYPE_p_zxid_cgi self) {
    return zxidjniJNI.zxid_cgi_consent_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
  }

  public static void cgi_matching_rule_set(SWIGTYPE_p_zxid_cgi self, String value) {
    zxidjniJNI.zxid_cgi_matching_rule_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static String cgi_matching_rule_get(SWIGTYPE_p_zxid_cgi self) {
    return zxidjniJNI.zxid_cgi_matching_rule_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
  }

  public static void cgi_authn_ctx_set(SWIGTYPE_p_zxid_cgi self, String value) {
    zxidjniJNI.zxid_cgi_authn_ctx_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static String cgi_authn_ctx_get(SWIGTYPE_p_zxid_cgi self) {
    return zxidjniJNI.zxid_cgi_authn_ctx_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
  }

  public static void cgi_pxy_count_set(SWIGTYPE_p_zxid_cgi self, String value) {
    zxidjniJNI.zxid_cgi_pxy_count_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static String cgi_pxy_count_get(SWIGTYPE_p_zxid_cgi self) {
    return zxidjniJNI.zxid_cgi_pxy_count_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
  }

  public static void cgi_get_complete_set(SWIGTYPE_p_zxid_cgi self, String value) {
    zxidjniJNI.zxid_cgi_get_complete_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static String cgi_get_complete_get(SWIGTYPE_p_zxid_cgi self) {
    return zxidjniJNI.zxid_cgi_get_complete_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
  }

  public static void cgi_idppxylist_set(SWIGTYPE_p_zxid_cgi self, String value) {
    zxidjniJNI.zxid_cgi_idppxylist_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static String cgi_idppxylist_get(SWIGTYPE_p_zxid_cgi self) {
    return zxidjniJNI.zxid_cgi_idppxylist_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
  }

  public static void cgi_rs_set(SWIGTYPE_p_zxid_cgi self, String value) {
    zxidjniJNI.zxid_cgi_rs_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static String cgi_rs_get(SWIGTYPE_p_zxid_cgi self) {
    return zxidjniJNI.zxid_cgi_rs_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
  }

  public static void cgi_newnym_set(SWIGTYPE_p_zxid_cgi self, String value) {
    zxidjniJNI.zxid_cgi_newnym_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static String cgi_newnym_get(SWIGTYPE_p_zxid_cgi self) {
    return zxidjniJNI.zxid_cgi_newnym_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
  }

  public static void cgi_saml_art_set(SWIGTYPE_p_zxid_cgi self, String value) {
    zxidjniJNI.zxid_cgi_saml_art_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static String cgi_saml_art_get(SWIGTYPE_p_zxid_cgi self) {
    return zxidjniJNI.zxid_cgi_saml_art_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
  }

  public static void cgi_saml_resp_set(SWIGTYPE_p_zxid_cgi self, String value) {
    zxidjniJNI.zxid_cgi_saml_resp_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static String cgi_saml_resp_get(SWIGTYPE_p_zxid_cgi self) {
    return zxidjniJNI.zxid_cgi_saml_resp_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
  }

  public static void cgi_saml_req_set(SWIGTYPE_p_zxid_cgi self, String value) {
    zxidjniJNI.zxid_cgi_saml_req_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static String cgi_saml_req_get(SWIGTYPE_p_zxid_cgi self) {
    return zxidjniJNI.zxid_cgi_saml_req_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
  }

  public static void cgi_sigalg_set(SWIGTYPE_p_zxid_cgi self, String value) {
    zxidjniJNI.zxid_cgi_sigalg_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static String cgi_sigalg_get(SWIGTYPE_p_zxid_cgi self) {
    return zxidjniJNI.zxid_cgi_sigalg_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
  }

  public static void cgi_sig_set(SWIGTYPE_p_zxid_cgi self, String value) {
    zxidjniJNI.zxid_cgi_sig_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static String cgi_sig_get(SWIGTYPE_p_zxid_cgi self) {
    return zxidjniJNI.zxid_cgi_sig_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
  }

  public static void cgi_sigval_set(SWIGTYPE_p_zxid_cgi self, String value) {
    zxidjniJNI.zxid_cgi_sigval_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static String cgi_sigval_get(SWIGTYPE_p_zxid_cgi self) {
    return zxidjniJNI.zxid_cgi_sigval_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
  }

  public static void cgi_sigmsg_set(SWIGTYPE_p_zxid_cgi self, String value) {
    zxidjniJNI.zxid_cgi_sigmsg_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static String cgi_sigmsg_get(SWIGTYPE_p_zxid_cgi self) {
    return zxidjniJNI.zxid_cgi_sigmsg_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
  }

  public static void cgi_err_set(SWIGTYPE_p_zxid_cgi self, String value) {
    zxidjniJNI.zxid_cgi_err_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static String cgi_err_get(SWIGTYPE_p_zxid_cgi self) {
    return zxidjniJNI.zxid_cgi_err_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
  }

  public static void cgi_msg_set(SWIGTYPE_p_zxid_cgi self, String value) {
    zxidjniJNI.zxid_cgi_msg_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static String cgi_msg_get(SWIGTYPE_p_zxid_cgi self) {
    return zxidjniJNI.zxid_cgi_msg_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
  }

  public static void cgi_dbg_set(SWIGTYPE_p_zxid_cgi self, String value) {
    zxidjniJNI.zxid_cgi_dbg_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static String cgi_dbg_get(SWIGTYPE_p_zxid_cgi self) {
    return zxidjniJNI.zxid_cgi_dbg_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
  }

  public static void cgi_zxapp_set(SWIGTYPE_p_zxid_cgi self, String value) {
    zxidjniJNI.zxid_cgi_zxapp_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static String cgi_zxapp_get(SWIGTYPE_p_zxid_cgi self) {
    return zxidjniJNI.zxid_cgi_zxapp_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
  }

  public static void cgi_zxrfr_set(SWIGTYPE_p_zxid_cgi self, String value) {
    zxidjniJNI.zxid_cgi_zxrfr_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static String cgi_zxrfr_get(SWIGTYPE_p_zxid_cgi self) {
    return zxidjniJNI.zxid_cgi_zxrfr_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
  }

  public static void cgi_ok_set(SWIGTYPE_p_zxid_cgi self, String value) {
    zxidjniJNI.zxid_cgi_ok_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), value);
  }

  public static String cgi_ok_get(SWIGTYPE_p_zxid_cgi self) {
    return zxidjniJNI.zxid_cgi_ok_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
  }

  public static void cgi_idp_list_set(SWIGTYPE_p_zxid_cgi self, SWIGTYPE_p_zxid_entity value) {
    zxidjniJNI.zxid_cgi_idp_list_set(SWIGTYPE_p_zxid_cgi.getCPtr(self), SWIGTYPE_p_zxid_entity.getCPtr(value));
  }

  public static SWIGTYPE_p_zxid_entity cgi_idp_list_get(SWIGTYPE_p_zxid_cgi self) {
    long cPtr = zxidjniJNI.zxid_cgi_idp_list_get(SWIGTYPE_p_zxid_cgi.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zxid_entity(cPtr, false);
  }

  public static SWIGTYPE_p_zxid_cgi new_zxid_cgi() {
    long cPtr = zxidjniJNI.new_zxid_cgi();
    return (cPtr == 0) ? null : new SWIGTYPE_p_zxid_cgi(cPtr, true);
  }

  public static void delete_zxid_cgi(SWIGTYPE_p_zxid_cgi self) {
    zxidjniJNI.delete_zxid_cgi(SWIGTYPE_p_zxid_cgi.getCPtr(self));
  }

  public static void ses_magic_set(zxid_ses self, long value) {
    zxidjniJNI.zxid_ses_magic_set(zxid_ses.getCPtr(self), value);
  }

  public static long ses_magic_get(zxid_ses self) {
    return zxidjniJNI.zxid_ses_magic_get(zxid_ses.getCPtr(self));
  }

  public static void ses_sid_set(zxid_ses self, String value) {
    zxidjniJNI.zxid_ses_sid_set(zxid_ses.getCPtr(self), value);
  }

  public static String ses_sid_get(zxid_ses self) {
    return zxidjniJNI.zxid_ses_sid_get(zxid_ses.getCPtr(self));
  }

  public static void ses_uid_set(zxid_ses self, String value) {
    zxidjniJNI.zxid_ses_uid_set(zxid_ses.getCPtr(self), value);
  }

  public static String ses_uid_get(zxid_ses self) {
    return zxidjniJNI.zxid_ses_uid_get(zxid_ses.getCPtr(self));
  }

  public static void ses_nid_set(zxid_ses self, String value) {
    zxidjniJNI.zxid_ses_nid_set(zxid_ses.getCPtr(self), value);
  }

  public static String ses_nid_get(zxid_ses self) {
    return zxidjniJNI.zxid_ses_nid_get(zxid_ses.getCPtr(self));
  }

  public static void ses_tgt_set(zxid_ses self, String value) {
    zxidjniJNI.zxid_ses_tgt_set(zxid_ses.getCPtr(self), value);
  }

  public static String ses_tgt_get(zxid_ses self) {
    return zxidjniJNI.zxid_ses_tgt_get(zxid_ses.getCPtr(self));
  }

  public static void ses_sesix_set(zxid_ses self, String value) {
    zxidjniJNI.zxid_ses_sesix_set(zxid_ses.getCPtr(self), value);
  }

  public static String ses_sesix_get(zxid_ses self) {
    return zxidjniJNI.zxid_ses_sesix_get(zxid_ses.getCPtr(self));
  }

  public static void ses_msgid_set(zxid_ses self, String value) {
    zxidjniJNI.zxid_ses_msgid_set(zxid_ses.getCPtr(self), value);
  }

  public static String ses_msgid_get(zxid_ses self) {
    return zxidjniJNI.zxid_ses_msgid_get(zxid_ses.getCPtr(self));
  }

  public static void ses_an_ctx_set(zxid_ses self, String value) {
    zxidjniJNI.zxid_ses_an_ctx_set(zxid_ses.getCPtr(self), value);
  }

  public static String ses_an_ctx_get(zxid_ses self) {
    return zxidjniJNI.zxid_ses_an_ctx_get(zxid_ses.getCPtr(self));
  }

  public static void ses_nidfmt_set(zxid_ses self, char value) {
    zxidjniJNI.zxid_ses_nidfmt_set(zxid_ses.getCPtr(self), value);
  }

  public static char ses_nidfmt_get(zxid_ses self) {
    return zxidjniJNI.zxid_ses_nidfmt_get(zxid_ses.getCPtr(self));
  }

  public static void ses_tgtfmt_set(zxid_ses self, char value) {
    zxidjniJNI.zxid_ses_tgtfmt_set(zxid_ses.getCPtr(self), value);
  }

  public static char ses_tgtfmt_get(zxid_ses self) {
    return zxidjniJNI.zxid_ses_tgtfmt_get(zxid_ses.getCPtr(self));
  }

  public static void ses_sigres_set(zxid_ses self, char value) {
    zxidjniJNI.zxid_ses_sigres_set(zxid_ses.getCPtr(self), value);
  }

  public static char ses_sigres_get(zxid_ses self) {
    return zxidjniJNI.zxid_ses_sigres_get(zxid_ses.getCPtr(self));
  }

  public static void ses_pad3_set(zxid_ses self, char value) {
    zxidjniJNI.zxid_ses_pad3_set(zxid_ses.getCPtr(self), value);
  }

  public static char ses_pad3_get(zxid_ses self) {
    return zxidjniJNI.zxid_ses_pad3_get(zxid_ses.getCPtr(self));
  }

  public static void ses_sso_a7n_path_set(zxid_ses self, String value) {
    zxidjniJNI.zxid_ses_sso_a7n_path_set(zxid_ses.getCPtr(self), value);
  }

  public static String ses_sso_a7n_path_get(zxid_ses self) {
    return zxidjniJNI.zxid_ses_sso_a7n_path_get(zxid_ses.getCPtr(self));
  }

  public static void ses_tgt_a7n_path_set(zxid_ses self, String value) {
    zxidjniJNI.zxid_ses_tgt_a7n_path_set(zxid_ses.getCPtr(self), value);
  }

  public static String ses_tgt_a7n_path_get(zxid_ses self) {
    return zxidjniJNI.zxid_ses_tgt_a7n_path_get(zxid_ses.getCPtr(self));
  }

  public static void ses_setcookie_set(zxid_ses self, String value) {
    zxidjniJNI.zxid_ses_setcookie_set(zxid_ses.getCPtr(self), value);
  }

  public static String ses_setcookie_get(zxid_ses self) {
    return zxidjniJNI.zxid_ses_setcookie_get(zxid_ses.getCPtr(self));
  }

  public static void ses_cookie_set(zxid_ses self, String value) {
    zxidjniJNI.zxid_ses_cookie_set(zxid_ses.getCPtr(self), value);
  }

  public static String ses_cookie_get(zxid_ses self) {
    return zxidjniJNI.zxid_ses_cookie_get(zxid_ses.getCPtr(self));
  }

  public static void ses_rs_set(zxid_ses self, String value) {
    zxidjniJNI.zxid_ses_rs_set(zxid_ses.getCPtr(self), value);
  }

  public static String ses_rs_get(zxid_ses self) {
    return zxidjniJNI.zxid_ses_rs_get(zxid_ses.getCPtr(self));
  }

  public static void ses_nameid_set(zxid_ses self, SWIGTYPE_p_zx_sa_NameID_s value) {
    zxidjniJNI.zxid_ses_nameid_set(zxid_ses.getCPtr(self), SWIGTYPE_p_zx_sa_NameID_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_sa_NameID_s ses_nameid_get(zxid_ses self) {
    long cPtr = zxidjniJNI.zxid_ses_nameid_get(zxid_ses.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_sa_NameID_s(cPtr, false);
  }

  public static void ses_a7n_set(zxid_ses self, SWIGTYPE_p_zx_sa_Assertion_s value) {
    zxidjniJNI.zxid_ses_a7n_set(zxid_ses.getCPtr(self), SWIGTYPE_p_zx_sa_Assertion_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_sa_Assertion_s ses_a7n_get(zxid_ses self) {
    long cPtr = zxidjniJNI.zxid_ses_a7n_get(zxid_ses.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_sa_Assertion_s(cPtr, false);
  }

  public static void ses_tgta7n_set(zxid_ses self, SWIGTYPE_p_zx_sa_Assertion_s value) {
    zxidjniJNI.zxid_ses_tgta7n_set(zxid_ses.getCPtr(self), SWIGTYPE_p_zx_sa_Assertion_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_sa_Assertion_s ses_tgta7n_get(zxid_ses self) {
    long cPtr = zxidjniJNI.zxid_ses_tgta7n_get(zxid_ses.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_sa_Assertion_s(cPtr, false);
  }

  public static void ses_a7n11_set(zxid_ses self, SWIGTYPE_p_zx_sa11_Assertion_s value) {
    zxidjniJNI.zxid_ses_a7n11_set(zxid_ses.getCPtr(self), SWIGTYPE_p_zx_sa11_Assertion_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_sa11_Assertion_s ses_a7n11_get(zxid_ses self) {
    long cPtr = zxidjniJNI.zxid_ses_a7n11_get(zxid_ses.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_sa11_Assertion_s(cPtr, false);
  }

  public static void ses_tgta7n11_set(zxid_ses self, SWIGTYPE_p_zx_sa11_Assertion_s value) {
    zxidjniJNI.zxid_ses_tgta7n11_set(zxid_ses.getCPtr(self), SWIGTYPE_p_zx_sa11_Assertion_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_sa11_Assertion_s ses_tgta7n11_get(zxid_ses self) {
    long cPtr = zxidjniJNI.zxid_ses_tgta7n11_get(zxid_ses.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_sa11_Assertion_s(cPtr, false);
  }

  public static void ses_a7n12_set(zxid_ses self, SWIGTYPE_p_zx_ff12_Assertion_s value) {
    zxidjniJNI.zxid_ses_a7n12_set(zxid_ses.getCPtr(self), SWIGTYPE_p_zx_ff12_Assertion_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_ff12_Assertion_s ses_a7n12_get(zxid_ses self) {
    long cPtr = zxidjniJNI.zxid_ses_a7n12_get(zxid_ses.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_ff12_Assertion_s(cPtr, false);
  }

  public static void ses_tgta7n12_set(zxid_ses self, SWIGTYPE_p_zx_ff12_Assertion_s value) {
    zxidjniJNI.zxid_ses_tgta7n12_set(zxid_ses.getCPtr(self), SWIGTYPE_p_zx_ff12_Assertion_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_ff12_Assertion_s ses_tgta7n12_get(zxid_ses self) {
    long cPtr = zxidjniJNI.zxid_ses_tgta7n12_get(zxid_ses.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_ff12_Assertion_s(cPtr, false);
  }

  public static void ses_sesbuf_set(zxid_ses self, String value) {
    zxidjniJNI.zxid_ses_sesbuf_set(zxid_ses.getCPtr(self), value);
  }

  public static String ses_sesbuf_get(zxid_ses self) {
    return zxidjniJNI.zxid_ses_sesbuf_get(zxid_ses.getCPtr(self));
  }

  public static void ses_sso_a7n_buf_set(zxid_ses self, String value) {
    zxidjniJNI.zxid_ses_sso_a7n_buf_set(zxid_ses.getCPtr(self), value);
  }

  public static String ses_sso_a7n_buf_get(zxid_ses self) {
    return zxidjniJNI.zxid_ses_sso_a7n_buf_get(zxid_ses.getCPtr(self));
  }

  public static void ses_at_set(zxid_ses self, SWIGTYPE_p_zxid_attr value) {
    zxidjniJNI.zxid_ses_at_set(zxid_ses.getCPtr(self), SWIGTYPE_p_zxid_attr.getCPtr(value));
  }

  public static SWIGTYPE_p_zxid_attr ses_at_get(zxid_ses self) {
    long cPtr = zxidjniJNI.zxid_ses_at_get(zxid_ses.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zxid_attr(cPtr, false);
  }

  public static zxid_ses new_zxid_ses() {
    long cPtr = zxidjniJNI.new_zxid_ses();
    return (cPtr == 0) ? null : new zxid_ses(cPtr, true);
  }

  public static void delete_zxid_ses(zxid_ses self) {
    zxidjniJNI.delete_zxid_ses(zxid_ses.getCPtr(self));
  }

  public static void attr_n_set(SWIGTYPE_p_zxid_attr self, SWIGTYPE_p_zxid_attr value) {
    zxidjniJNI.zxid_attr_n_set(SWIGTYPE_p_zxid_attr.getCPtr(self), SWIGTYPE_p_zxid_attr.getCPtr(value));
  }

  public static SWIGTYPE_p_zxid_attr attr_n_get(SWIGTYPE_p_zxid_attr self) {
    long cPtr = zxidjniJNI.zxid_attr_n_get(SWIGTYPE_p_zxid_attr.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zxid_attr(cPtr, false);
  }

  public static void attr_nv_set(SWIGTYPE_p_zxid_attr self, SWIGTYPE_p_zxid_attr value) {
    zxidjniJNI.zxid_attr_nv_set(SWIGTYPE_p_zxid_attr.getCPtr(self), SWIGTYPE_p_zxid_attr.getCPtr(value));
  }

  public static SWIGTYPE_p_zxid_attr attr_nv_get(SWIGTYPE_p_zxid_attr self) {
    long cPtr = zxidjniJNI.zxid_attr_nv_get(SWIGTYPE_p_zxid_attr.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zxid_attr(cPtr, false);
  }

  public static void attr_name_set(SWIGTYPE_p_zxid_attr self, String value) {
    zxidjniJNI.zxid_attr_name_set(SWIGTYPE_p_zxid_attr.getCPtr(self), value);
  }

  public static String attr_name_get(SWIGTYPE_p_zxid_attr self) {
    return zxidjniJNI.zxid_attr_name_get(SWIGTYPE_p_zxid_attr.getCPtr(self));
  }

  public static void attr_val_set(SWIGTYPE_p_zxid_attr self, String value) {
    zxidjniJNI.zxid_attr_val_set(SWIGTYPE_p_zxid_attr.getCPtr(self), value);
  }

  public static String attr_val_get(SWIGTYPE_p_zxid_attr self) {
    return zxidjniJNI.zxid_attr_val_get(SWIGTYPE_p_zxid_attr.getCPtr(self));
  }

  public static void attr_map_val_set(SWIGTYPE_p_zxid_attr self, String value) {
    zxidjniJNI.zxid_attr_map_val_set(SWIGTYPE_p_zxid_attr.getCPtr(self), value);
  }

  public static String attr_map_val_get(SWIGTYPE_p_zxid_attr self) { return zxidjniJNI.zxid_attr_map_val_get(SWIGTYPE_p_zxid_attr.getCPtr(self)); }

  public static void attr_orig_set(SWIGTYPE_p_zxid_attr self, SWIGTYPE_p_zx_sa_Attribute_s value) {
    zxidjniJNI.zxid_attr_orig_set(SWIGTYPE_p_zxid_attr.getCPtr(self), SWIGTYPE_p_zx_sa_Attribute_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_sa_Attribute_s attr_orig_get(SWIGTYPE_p_zxid_attr self) {
    long cPtr = zxidjniJNI.zxid_attr_orig_get(SWIGTYPE_p_zxid_attr.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_sa_Attribute_s(cPtr, false);
  }

  public static void attr_issuer_set(SWIGTYPE_p_zxid_attr self, String value) {
    zxidjniJNI.zxid_attr_issuer_set(SWIGTYPE_p_zxid_attr.getCPtr(self), value);
  }

  public static String attr_issuer_get(SWIGTYPE_p_zxid_attr self) { return zxidjniJNI.zxid_attr_issuer_get(SWIGTYPE_p_zxid_attr.getCPtr(self)); }

  public static SWIGTYPE_p_zxid_attr new_zxid_attr() {
    long cPtr = zxidjniJNI.new_zxid_attr();
    return (cPtr == 0) ? null : new SWIGTYPE_p_zxid_attr(cPtr, true);
  }

  public static void delete_zxid_attr(SWIGTYPE_p_zxid_attr self) {
    zxidjniJNI.delete_zxid_attr(SWIGTYPE_p_zxid_attr.getCPtr(self));
  }

  public static void need_n_set(SWIGTYPE_p_zxid_need self, SWIGTYPE_p_zxid_need value) {
    zxidjniJNI.zxid_need_n_set(SWIGTYPE_p_zxid_need.getCPtr(self), SWIGTYPE_p_zxid_need.getCPtr(value));
  }

  public static SWIGTYPE_p_zxid_need need_n_get(SWIGTYPE_p_zxid_need self) {
    long cPtr = zxidjniJNI.zxid_need_n_get(SWIGTYPE_p_zxid_need.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zxid_need(cPtr, false);
  }

  public static void need_at_set(SWIGTYPE_p_zxid_need self, SWIGTYPE_p_zxid_attr value) {
    zxidjniJNI.zxid_need_at_set(SWIGTYPE_p_zxid_need.getCPtr(self), SWIGTYPE_p_zxid_attr.getCPtr(value));
  }

  public static SWIGTYPE_p_zxid_attr need_at_get(SWIGTYPE_p_zxid_need self) {
    long cPtr = zxidjniJNI.zxid_need_at_get(SWIGTYPE_p_zxid_need.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zxid_attr(cPtr, false);
  }

  public static void need_usage_set(SWIGTYPE_p_zxid_need self, String value) {
    zxidjniJNI.zxid_need_usage_set(SWIGTYPE_p_zxid_need.getCPtr(self), value);
  }

  public static String need_usage_get(SWIGTYPE_p_zxid_need self) {
    return zxidjniJNI.zxid_need_usage_get(SWIGTYPE_p_zxid_need.getCPtr(self));
  }

  public static void need_retent_set(SWIGTYPE_p_zxid_need self, String value) {
    zxidjniJNI.zxid_need_retent_set(SWIGTYPE_p_zxid_need.getCPtr(self), value);
  }

  public static String need_retent_get(SWIGTYPE_p_zxid_need self) {
    return zxidjniJNI.zxid_need_retent_get(SWIGTYPE_p_zxid_need.getCPtr(self));
  }

  public static void need_oblig_set(SWIGTYPE_p_zxid_need self, String value) {
    zxidjniJNI.zxid_need_oblig_set(SWIGTYPE_p_zxid_need.getCPtr(self), value);
  }

  public static String need_oblig_get(SWIGTYPE_p_zxid_need self) {
    return zxidjniJNI.zxid_need_oblig_get(SWIGTYPE_p_zxid_need.getCPtr(self));
  }

  public static void need_ext_set(SWIGTYPE_p_zxid_need self, String value) {
    zxidjniJNI.zxid_need_ext_set(SWIGTYPE_p_zxid_need.getCPtr(self), value);
  }

  public static String need_ext_get(SWIGTYPE_p_zxid_need self) {
    return zxidjniJNI.zxid_need_ext_get(SWIGTYPE_p_zxid_need.getCPtr(self));
  }

  public static SWIGTYPE_p_zxid_need new_zxid_need() {
    long cPtr = zxidjniJNI.new_zxid_need();
    return (cPtr == 0) ? null : new SWIGTYPE_p_zxid_need(cPtr, true);
  }

  public static void delete_zxid_need(SWIGTYPE_p_zxid_need self) {
    zxidjniJNI.delete_zxid_need(SWIGTYPE_p_zxid_need.getCPtr(self));
  }

  public static void map_n_set(SWIGTYPE_p_zxid_map self, SWIGTYPE_p_zxid_map value) {
    zxidjniJNI.zxid_map_n_set(SWIGTYPE_p_zxid_map.getCPtr(self), SWIGTYPE_p_zxid_map.getCPtr(value));
  }

  public static SWIGTYPE_p_zxid_map map_n_get(SWIGTYPE_p_zxid_map self) {
    long cPtr = zxidjniJNI.zxid_map_n_get(SWIGTYPE_p_zxid_map.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zxid_map(cPtr, false);
  }

  public static void map_rule_set(SWIGTYPE_p_zxid_map self, int value) {
    zxidjniJNI.zxid_map_rule_set(SWIGTYPE_p_zxid_map.getCPtr(self), value);
  }

  public static int map_rule_get(SWIGTYPE_p_zxid_map self) {
    return zxidjniJNI.zxid_map_rule_get(SWIGTYPE_p_zxid_map.getCPtr(self));
  }

  public static void map_ns_set(SWIGTYPE_p_zxid_map self, String value) {
    zxidjniJNI.zxid_map_ns_set(SWIGTYPE_p_zxid_map.getCPtr(self), value);
  }

  public static String map_ns_get(SWIGTYPE_p_zxid_map self) {
    return zxidjniJNI.zxid_map_ns_get(SWIGTYPE_p_zxid_map.getCPtr(self));
  }

  public static void map_src_set(SWIGTYPE_p_zxid_map self, String value) {
    zxidjniJNI.zxid_map_src_set(SWIGTYPE_p_zxid_map.getCPtr(self), value);
  }

  public static String map_src_get(SWIGTYPE_p_zxid_map self) {
    return zxidjniJNI.zxid_map_src_get(SWIGTYPE_p_zxid_map.getCPtr(self));
  }

  public static void map_dst_set(SWIGTYPE_p_zxid_map self, String value) {
    zxidjniJNI.zxid_map_dst_set(SWIGTYPE_p_zxid_map.getCPtr(self), value);
  }

  public static String map_dst_get(SWIGTYPE_p_zxid_map self) {
    return zxidjniJNI.zxid_map_dst_get(SWIGTYPE_p_zxid_map.getCPtr(self));
  }

  public static void map_ext_set(SWIGTYPE_p_zxid_map self, String value) {
    zxidjniJNI.zxid_map_ext_set(SWIGTYPE_p_zxid_map.getCPtr(self), value);
  }

  public static String map_ext_get(SWIGTYPE_p_zxid_map self) {
    return zxidjniJNI.zxid_map_ext_get(SWIGTYPE_p_zxid_map.getCPtr(self));
  }

  public static SWIGTYPE_p_zxid_map new_zxid_map() {
    long cPtr = zxidjniJNI.new_zxid_map();
    return (cPtr == 0) ? null : new SWIGTYPE_p_zxid_map(cPtr, true);
  }

  public static void delete_zxid_map(SWIGTYPE_p_zxid_map self) {
    zxidjniJNI.delete_zxid_map(SWIGTYPE_p_zxid_map.getCPtr(self));
  }

  public static void cstr_list_n_set(SWIGTYPE_p_zxid_cstr_list self, SWIGTYPE_p_zxid_cstr_list value) {
    zxidjniJNI.zxid_cstr_list_n_set(SWIGTYPE_p_zxid_cstr_list.getCPtr(self), SWIGTYPE_p_zxid_cstr_list.getCPtr(value));
  }

  public static SWIGTYPE_p_zxid_cstr_list cstr_list_n_get(SWIGTYPE_p_zxid_cstr_list self) {
    long cPtr = zxidjniJNI.zxid_cstr_list_n_get(SWIGTYPE_p_zxid_cstr_list.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zxid_cstr_list(cPtr, false);
  }

  public static void cstr_list_s_set(SWIGTYPE_p_zxid_cstr_list self, String value) {
    zxidjniJNI.zxid_cstr_list_s_set(SWIGTYPE_p_zxid_cstr_list.getCPtr(self), value);
  }

  public static String cstr_list_s_get(SWIGTYPE_p_zxid_cstr_list self) {
    return zxidjniJNI.zxid_cstr_list_s_get(SWIGTYPE_p_zxid_cstr_list.getCPtr(self));
  }

  public static SWIGTYPE_p_zxid_cstr_list new_zxid_cstr_list() {
    long cPtr = zxidjniJNI.new_zxid_cstr_list();
    return (cPtr == 0) ? null : new SWIGTYPE_p_zxid_cstr_list(cPtr, true);
  }

  public static void delete_zxid_cstr_list(SWIGTYPE_p_zxid_cstr_list self) {
    zxidjniJNI.delete_zxid_cstr_list(SWIGTYPE_p_zxid_cstr_list.getCPtr(self));
  }

  public static void atsrc_n_set(SWIGTYPE_p_zxid_atsrc self, SWIGTYPE_p_zxid_atsrc value) {
    zxidjniJNI.zxid_atsrc_n_set(SWIGTYPE_p_zxid_atsrc.getCPtr(self), SWIGTYPE_p_zxid_atsrc.getCPtr(value));
  }

  public static SWIGTYPE_p_zxid_atsrc atsrc_n_get(SWIGTYPE_p_zxid_atsrc self) {
    long cPtr = zxidjniJNI.zxid_atsrc_n_get(SWIGTYPE_p_zxid_atsrc.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zxid_atsrc(cPtr, false);
  }

  public static void atsrc_at_set(SWIGTYPE_p_zxid_atsrc self, SWIGTYPE_p_zxid_attr value) {
    zxidjniJNI.zxid_atsrc_at_set(SWIGTYPE_p_zxid_atsrc.getCPtr(self), SWIGTYPE_p_zxid_attr.getCPtr(value));
  }

  public static SWIGTYPE_p_zxid_attr atsrc_at_get(SWIGTYPE_p_zxid_atsrc self) {
    long cPtr = zxidjniJNI.zxid_atsrc_at_get(SWIGTYPE_p_zxid_atsrc.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zxid_attr(cPtr, false);
  }

  public static void atsrc_ns_set(SWIGTYPE_p_zxid_atsrc self, String value) {
    zxidjniJNI.zxid_atsrc_ns_set(SWIGTYPE_p_zxid_atsrc.getCPtr(self), value);
  }

  public static String atsrc_ns_get(SWIGTYPE_p_zxid_atsrc self) {
    return zxidjniJNI.zxid_atsrc_ns_get(SWIGTYPE_p_zxid_atsrc.getCPtr(self));
  }

  public static void atsrc_weight_set(SWIGTYPE_p_zxid_atsrc self, String value) {
    zxidjniJNI.zxid_atsrc_weight_set(SWIGTYPE_p_zxid_atsrc.getCPtr(self), value);
  }

  public static String atsrc_weight_get(SWIGTYPE_p_zxid_atsrc self) {
    return zxidjniJNI.zxid_atsrc_weight_get(SWIGTYPE_p_zxid_atsrc.getCPtr(self));
  }

  public static void atsrc_url_set(SWIGTYPE_p_zxid_atsrc self, String value) {
    zxidjniJNI.zxid_atsrc_url_set(SWIGTYPE_p_zxid_atsrc.getCPtr(self), value);
  }

  public static String atsrc_url_get(SWIGTYPE_p_zxid_atsrc self) {
    return zxidjniJNI.zxid_atsrc_url_get(SWIGTYPE_p_zxid_atsrc.getCPtr(self));
  }

  public static void atsrc_aapml_set(SWIGTYPE_p_zxid_atsrc self, String value) {
    zxidjniJNI.zxid_atsrc_aapml_set(SWIGTYPE_p_zxid_atsrc.getCPtr(self), value);
  }

  public static String atsrc_aapml_get(SWIGTYPE_p_zxid_atsrc self) {
    return zxidjniJNI.zxid_atsrc_aapml_get(SWIGTYPE_p_zxid_atsrc.getCPtr(self));
  }

  public static void atsrc_otherlim_set(SWIGTYPE_p_zxid_atsrc self, String value) {
    zxidjniJNI.zxid_atsrc_otherlim_set(SWIGTYPE_p_zxid_atsrc.getCPtr(self), value);
  }

  public static String atsrc_otherlim_get(SWIGTYPE_p_zxid_atsrc self) {
    return zxidjniJNI.zxid_atsrc_otherlim_get(SWIGTYPE_p_zxid_atsrc.getCPtr(self));
  }

  public static void atsrc_ext_set(SWIGTYPE_p_zxid_atsrc self, String value) {
    zxidjniJNI.zxid_atsrc_ext_set(SWIGTYPE_p_zxid_atsrc.getCPtr(self), value);
  }

  public static String atsrc_ext_get(SWIGTYPE_p_zxid_atsrc self) {
    return zxidjniJNI.zxid_atsrc_ext_get(SWIGTYPE_p_zxid_atsrc.getCPtr(self));
  }

  public static SWIGTYPE_p_zxid_atsrc new_zxid_atsrc() {
    long cPtr = zxidjniJNI.new_zxid_atsrc();
    return (cPtr == 0) ? null : new SWIGTYPE_p_zxid_atsrc(cPtr, true);
  }

  public static void delete_zxid_atsrc(SWIGTYPE_p_zxid_atsrc self) {
    zxidjniJNI.delete_zxid_atsrc(SWIGTYPE_p_zxid_atsrc.getCPtr(self));
  }

  public static void entity_n_set(SWIGTYPE_p_zxid_entity self, SWIGTYPE_p_zxid_entity value) {
    zxidjniJNI.zxid_entity_n_set(SWIGTYPE_p_zxid_entity.getCPtr(self), SWIGTYPE_p_zxid_entity.getCPtr(value));
  }

  public static SWIGTYPE_p_zxid_entity entity_n_get(SWIGTYPE_p_zxid_entity self) {
    long cPtr = zxidjniJNI.zxid_entity_n_get(SWIGTYPE_p_zxid_entity.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zxid_entity(cPtr, false);
  }

  public static void entity_n_cdc_set(SWIGTYPE_p_zxid_entity self, SWIGTYPE_p_zxid_entity value) {
    zxidjniJNI.zxid_entity_n_cdc_set(SWIGTYPE_p_zxid_entity.getCPtr(self), SWIGTYPE_p_zxid_entity.getCPtr(value));
  }

  public static SWIGTYPE_p_zxid_entity entity_n_cdc_get(SWIGTYPE_p_zxid_entity self) {
    long cPtr = zxidjniJNI.zxid_entity_n_cdc_get(SWIGTYPE_p_zxid_entity.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zxid_entity(cPtr, false);
  }

  public static void entity_eid_len_set(SWIGTYPE_p_zxid_entity self, int value) {
    zxidjniJNI.zxid_entity_eid_len_set(SWIGTYPE_p_zxid_entity.getCPtr(self), value);
  }

  public static int entity_eid_len_get(SWIGTYPE_p_zxid_entity self) {
    return zxidjniJNI.zxid_entity_eid_len_get(SWIGTYPE_p_zxid_entity.getCPtr(self));
  }

  public static void entity_eid_set(SWIGTYPE_p_zxid_entity self, String value) {
    zxidjniJNI.zxid_entity_eid_set(SWIGTYPE_p_zxid_entity.getCPtr(self), value);
  }

  public static String entity_eid_get(SWIGTYPE_p_zxid_entity self) {
    return zxidjniJNI.zxid_entity_eid_get(SWIGTYPE_p_zxid_entity.getCPtr(self));
  }

  public static void entity_sha1_name_set(SWIGTYPE_p_zxid_entity self, String value) {
    zxidjniJNI.zxid_entity_sha1_name_set(SWIGTYPE_p_zxid_entity.getCPtr(self), value);
  }

  public static String entity_sha1_name_get(SWIGTYPE_p_zxid_entity self) {
    return zxidjniJNI.zxid_entity_sha1_name_get(SWIGTYPE_p_zxid_entity.getCPtr(self));
  }

  public static void entity_tls_cert_set(SWIGTYPE_p_zxid_entity self, SWIGTYPE_p_X509 value) {
    zxidjniJNI.zxid_entity_tls_cert_set(SWIGTYPE_p_zxid_entity.getCPtr(self), SWIGTYPE_p_X509.getCPtr(value));
  }

  public static SWIGTYPE_p_X509 entity_tls_cert_get(SWIGTYPE_p_zxid_entity self) {
    long cPtr = zxidjniJNI.zxid_entity_tls_cert_get(SWIGTYPE_p_zxid_entity.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_X509(cPtr, false);
  }

  public static void entity_sign_cert_set(SWIGTYPE_p_zxid_entity self, SWIGTYPE_p_X509 value) {
    zxidjniJNI.zxid_entity_sign_cert_set(SWIGTYPE_p_zxid_entity.getCPtr(self), SWIGTYPE_p_X509.getCPtr(value));
  }

  public static SWIGTYPE_p_X509 entity_sign_cert_get(SWIGTYPE_p_zxid_entity self) {
    long cPtr = zxidjniJNI.zxid_entity_sign_cert_get(SWIGTYPE_p_zxid_entity.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_X509(cPtr, false);
  }

  public static void entity_enc_cert_set(SWIGTYPE_p_zxid_entity self, SWIGTYPE_p_X509 value) {
    zxidjniJNI.zxid_entity_enc_cert_set(SWIGTYPE_p_zxid_entity.getCPtr(self), SWIGTYPE_p_X509.getCPtr(value));
  }

  public static SWIGTYPE_p_X509 entity_enc_cert_get(SWIGTYPE_p_zxid_entity self) {
    long cPtr = zxidjniJNI.zxid_entity_enc_cert_get(SWIGTYPE_p_zxid_entity.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_X509(cPtr, false);
  }

  public static void entity_ed_set(SWIGTYPE_p_zxid_entity self, SWIGTYPE_p_zx_md_EntityDescriptor_s value) {
    zxidjniJNI.zxid_entity_ed_set(SWIGTYPE_p_zxid_entity.getCPtr(self), SWIGTYPE_p_zx_md_EntityDescriptor_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_md_EntityDescriptor_s entity_ed_get(SWIGTYPE_p_zxid_entity self) {
    long cPtr = zxidjniJNI.zxid_entity_ed_get(SWIGTYPE_p_zxid_entity.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_md_EntityDescriptor_s(cPtr, false);
  }

  public static SWIGTYPE_p_zxid_entity new_zxid_entity() {
    long cPtr = zxidjniJNI.new_zxid_entity();
    return (cPtr == 0) ? null : new SWIGTYPE_p_zxid_entity(cPtr, true);
  }

  public static void delete_zxid_entity(SWIGTYPE_p_zxid_entity self) {
    zxidjniJNI.delete_zxid_entity(SWIGTYPE_p_zxid_entity.getCPtr(self));
  }

  public static String simple(String conf, String qs, int auto_flags) {
    return zxidjniJNI.zxid_simple(conf, qs, auto_flags);
  }

  public static String idp_list(String conf, int auto_flags) {
    return zxidjniJNI.zxid_idp_list(conf, auto_flags);
  }

  public static String idp_select(String conf, int auto_flags) {
    return zxidjniJNI.zxid_idp_select(conf, auto_flags);
  }

  public static String fed_mgmt(String conf, String sid, int auto_flags) {
    return zxidjniJNI.zxid_fed_mgmt(conf, sid, auto_flags);
  }

  public static zxid_conf new_conf_to_cf(String conf) {
    long cPtr = zxidjniJNI.zxid_new_conf_to_cf(conf);
    return (cPtr == 0) ? null : new zxid_conf(cPtr, false);
  }

  public static String simple_cf(zxid_conf cf, int qs_len, String qs, SWIGTYPE_p_int res_len, int auto_flags) {
    return zxidjniJNI.zxid_simple_cf(zxid_conf.getCPtr(cf), qs_len, qs, SWIGTYPE_p_int.getCPtr(res_len), auto_flags);
  }

  public static String idp_list_cf(zxid_conf cf, SWIGTYPE_p_int res_len, int auto_flags) {
    return zxidjniJNI.zxid_idp_list_cf(zxid_conf.getCPtr(cf), SWIGTYPE_p_int.getCPtr(res_len), auto_flags);
  }

  public static String idp_select_cf(zxid_conf cf, SWIGTYPE_p_int res_len, int auto_flags) {
    return zxidjniJNI.zxid_idp_select_cf(zxid_conf.getCPtr(cf), SWIGTYPE_p_int.getCPtr(res_len), auto_flags);
  }

  public static String fed_mgmt_cf(zxid_conf cf, SWIGTYPE_p_int res_len, int sid_len, String sid, int auto_flags) {
    return zxidjniJNI.zxid_fed_mgmt_cf(zxid_conf.getCPtr(cf), SWIGTYPE_p_int.getCPtr(res_len), sid_len, sid, auto_flags);
  }

  public static int conf_to_cf_len(zxid_conf cf, int conf_len, String conf) {
    return zxidjniJNI.zxid_conf_to_cf_len(zxid_conf.getCPtr(cf), conf_len, conf);
  }

  public static String simple_len(int conf_len, String conf, int qs_len, String qs, SWIGTYPE_p_int res_len, int auto_flags) {
    return zxidjniJNI.zxid_simple_len(conf_len, conf, qs_len, qs, SWIGTYPE_p_int.getCPtr(res_len), auto_flags);
  }

  public static String idp_list_len(int conf_len, String conf, SWIGTYPE_p_int res_len, int auto_flags) {
    return zxidjniJNI.zxid_idp_list_len(conf_len, conf, SWIGTYPE_p_int.getCPtr(res_len), auto_flags);
  }

  public static String idp_select_len(int conf_len, String conf, SWIGTYPE_p_int res_len, int auto_flags) {
    return zxidjniJNI.zxid_idp_select_len(conf_len, conf, SWIGTYPE_p_int.getCPtr(res_len), auto_flags);
  }

  public static String fed_mgmt_len(int conf_len, String conf, SWIGTYPE_p_int res_len, String sid, int auto_flags) {
    return zxidjniJNI.zxid_fed_mgmt_len(conf_len, conf, SWIGTYPE_p_int.getCPtr(res_len), sid, auto_flags);
  }

  public static String idp_select_zxstr_cf(zxid_conf cf, int auto_flags) { return zxidjniJNI.zxid_idp_select_zxstr_cf(zxid_conf.getCPtr(cf), auto_flags); }

  public static String simple_ab_pep(zxid_conf cf, zxid_ses ses, SWIGTYPE_p_int res_len, int auto_flags) {
    return zxidjniJNI.zxid_simple_ab_pep(zxid_conf.getCPtr(cf), zxid_ses.getCPtr(ses), SWIGTYPE_p_int.getCPtr(res_len), auto_flags);
  }

  public static String simple_ses_active_cf(zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, zxid_ses ses, SWIGTYPE_p_int res_len, int auto_flags) {
    return zxidjniJNI.zxid_simple_ses_active_cf(zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), zxid_ses.getCPtr(ses), SWIGTYPE_p_int.getCPtr(res_len), auto_flags);
  }

  public static String simple_no_ses_cf(zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, zxid_ses ses, SWIGTYPE_p_int res_len, int auto_flags) {
    return zxidjniJNI.zxid_simple_no_ses_cf(zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), zxid_ses.getCPtr(ses), SWIGTYPE_p_int.getCPtr(res_len), auto_flags);
  }

  public static void zxsig_ref_sref_set(SWIGTYPE_p_zxsig_ref self, SWIGTYPE_p_zx_ds_Reference_s value) {
    zxidjniJNI.zxsig_ref_sref_set(SWIGTYPE_p_zxsig_ref.getCPtr(self), SWIGTYPE_p_zx_ds_Reference_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_ds_Reference_s zxsig_ref_sref_get(SWIGTYPE_p_zxsig_ref self) {
    long cPtr = zxidjniJNI.zxsig_ref_sref_get(SWIGTYPE_p_zxsig_ref.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_ds_Reference_s(cPtr, false);
  }

  public static void zxsig_ref_blob_set(SWIGTYPE_p_zxsig_ref self, SWIGTYPE_p_zx_elem_s value) {
    zxidjniJNI.zxsig_ref_blob_set(SWIGTYPE_p_zxsig_ref.getCPtr(self), SWIGTYPE_p_zx_elem_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_elem_s zxsig_ref_blob_get(SWIGTYPE_p_zxsig_ref self) {
    long cPtr = zxidjniJNI.zxsig_ref_blob_get(SWIGTYPE_p_zxsig_ref.getCPtr(self));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_elem_s(cPtr, false);
  }

  public static void zxsig_ref_id_set(SWIGTYPE_p_zxsig_ref self, String value) {
    zxidjniJNI.zxsig_ref_id_set(SWIGTYPE_p_zxsig_ref.getCPtr(self), value);
  }

  public static String zxsig_ref_id_get(SWIGTYPE_p_zxsig_ref self) { return zxidjniJNI.zxsig_ref_id_get(SWIGTYPE_p_zxsig_ref.getCPtr(self)); }

  public static void zxsig_ref_canon_set(SWIGTYPE_p_zxsig_ref self, String value) {
    zxidjniJNI.zxsig_ref_canon_set(SWIGTYPE_p_zxsig_ref.getCPtr(self), value);
  }

  public static String zxsig_ref_canon_get(SWIGTYPE_p_zxsig_ref self) { return zxidjniJNI.zxsig_ref_canon_get(SWIGTYPE_p_zxsig_ref.getCPtr(self)); }

  public static SWIGTYPE_p_zxsig_ref new_zxsig_ref() {
    long cPtr = zxidjniJNI.new_zxsig_ref();
    return (cPtr == 0) ? null : new SWIGTYPE_p_zxsig_ref(cPtr, true);
  }

  public static void delete_zxsig_ref(SWIGTYPE_p_zxsig_ref self) {
    zxidjniJNI.delete_zxsig_ref(SWIGTYPE_p_zxsig_ref.getCPtr(self));
  }

  public static SWIGTYPE_p_zx_ds_Signature_s zxsig_sign(SWIGTYPE_p_zx_ctx c, int n, SWIGTYPE_p_zxsig_ref sref, SWIGTYPE_p_X509 cert, SWIGTYPE_p_p_void priv_key) {
    long cPtr = zxidjniJNI.zxsig_sign(SWIGTYPE_p_zx_ctx.getCPtr(c), n, SWIGTYPE_p_zxsig_ref.getCPtr(sref), SWIGTYPE_p_X509.getCPtr(cert), SWIGTYPE_p_p_void.getCPtr(priv_key));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_ds_Signature_s(cPtr, false);
  }

  public static int zxsig_validate(SWIGTYPE_p_zx_ctx c, SWIGTYPE_p_X509 cert, SWIGTYPE_p_zx_ds_Signature_s sig, int n, SWIGTYPE_p_zxsig_ref refs) {
    return zxidjniJNI.zxsig_validate(SWIGTYPE_p_zx_ctx.getCPtr(c), SWIGTYPE_p_X509.getCPtr(cert), SWIGTYPE_p_zx_ds_Signature_s.getCPtr(sig), n, SWIGTYPE_p_zxsig_ref.getCPtr(refs));
  }

  public static int zxsig_data_rsa_sha1(SWIGTYPE_p_zx_ctx c, int len, String d, SWIGTYPE_p_p_char sig, SWIGTYPE_p_p_void priv_key, String lk) {
    return zxidjniJNI.zxsig_data_rsa_sha1(SWIGTYPE_p_zx_ctx.getCPtr(c), len, d, SWIGTYPE_p_p_char.getCPtr(sig), SWIGTYPE_p_p_void.getCPtr(priv_key), lk);
  }

  public static int zxsig_verify_data_rsa_sha1(int len, String data, int siglen, String sig, SWIGTYPE_p_X509 cert, String lk) {
    return zxidjniJNI.zxsig_verify_data_rsa_sha1(len, data, siglen, sig, SWIGTYPE_p_X509.getCPtr(cert), lk);
  }

  public static String zxenc_symkey_dec(zxid_conf cf, SWIGTYPE_p_zx_xenc_EncryptedData_s ed, String symkey) { return zxidjniJNI.zxenc_symkey_dec(zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_xenc_EncryptedData_s.getCPtr(ed), symkey); }

  public static String zxenc_privkey_dec(zxid_conf cf, SWIGTYPE_p_zx_xenc_EncryptedData_s ed, SWIGTYPE_p_zx_xenc_EncryptedKey_s ek) { return zxidjniJNI.zxenc_privkey_dec(zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_xenc_EncryptedData_s.getCPtr(ed), SWIGTYPE_p_zx_xenc_EncryptedKey_s.getCPtr(ek)); }

  public static SWIGTYPE_p_zx_xenc_EncryptedData_s zxenc_symkey_enc(zxid_conf cf, String data, String ed_id, String symkey, String symkey_id) {
    long cPtr = zxidjniJNI.zxenc_symkey_enc(zxid_conf.getCPtr(cf), data, ed_id, symkey, symkey_id);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_xenc_EncryptedData_s(cPtr, false);
  }

  public static SWIGTYPE_p_zx_xenc_EncryptedData_s zxenc_pubkey_enc(zxid_conf cf, String data, SWIGTYPE_p_p_zx_xenc_EncryptedKey_s ekp, SWIGTYPE_p_X509 cert, String idsuffix) {
    long cPtr = zxidjniJNI.zxenc_pubkey_enc(zxid_conf.getCPtr(cf), data, SWIGTYPE_p_p_zx_xenc_EncryptedKey_s.getCPtr(ekp), SWIGTYPE_p_X509.getCPtr(cert), idsuffix);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_xenc_EncryptedData_s(cPtr, false);
  }

  public static void zxlog_write_line(zxid_conf cf, String c_path, int encflags, int n, String logbuf) {
    zxidjniJNI.zxlog_write_line(zxid_conf.getCPtr(cf), c_path, encflags, n, logbuf);
  }

  public static String zxlog_path(zxid_conf cf, String entid, String objid, String dir, String kind, int create_dirs) { return zxidjniJNI.zxlog_path(zxid_conf.getCPtr(cf), entid, objid, dir, kind, create_dirs); }

  public static int zxlog_dup_check(zxid_conf cf, String path, String logkey) {
    return zxidjniJNI.zxlog_dup_check(zxid_conf.getCPtr(cf), path, logkey);
  }

  public static int zxlog_blob(zxid_conf cf, int logflag, String path, String blob, String lk) {
    return zxidjniJNI.zxlog_blob(zxid_conf.getCPtr(cf), logflag, path, blob, lk);
  }

  public static int zxlog(zxid_conf cf, SWIGTYPE_p_timeval ourts, SWIGTYPE_p_timeval srcts, String ipport, String entid, String msgid, String a7nid, String nid, String sigval, String res, String op, String arg, String fmt) {
    return zxidjniJNI.zxlog(zxid_conf.getCPtr(cf), SWIGTYPE_p_timeval.getCPtr(ourts), SWIGTYPE_p_timeval.getCPtr(srcts), ipport, entid, msgid, a7nid, nid, sigval, res, op, arg, fmt);
  }

  public static SWIGTYPE_p_zxid_entity get_ent_from_file(zxid_conf cf, String sha1_name) {
    long cPtr = zxidjniJNI.zxid_get_ent_from_file(zxid_conf.getCPtr(cf), sha1_name);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zxid_entity(cPtr, false);
  }

  public static SWIGTYPE_p_zxid_entity get_ent_from_cache(zxid_conf cf, String eid) {
    long cPtr = zxidjniJNI.zxid_get_ent_from_cache(zxid_conf.getCPtr(cf), eid);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zxid_entity(cPtr, false);
  }

  public static int write_ent_to_cache(zxid_conf cf, SWIGTYPE_p_zxid_entity ent) {
    return zxidjniJNI.zxid_write_ent_to_cache(zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_entity.getCPtr(ent));
  }

  public static SWIGTYPE_p_zxid_entity parse_meta(zxid_conf cf, SWIGTYPE_p_p_char md, String lim) {
    long cPtr = zxidjniJNI.zxid_parse_meta(zxid_conf.getCPtr(cf), SWIGTYPE_p_p_char.getCPtr(md), lim);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zxid_entity(cPtr, false);
  }

  public static SWIGTYPE_p_zxid_entity get_meta_ss(zxid_conf cf, String url) {
    long cPtr = zxidjniJNI.zxid_get_meta_ss(zxid_conf.getCPtr(cf), url);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zxid_entity(cPtr, false);
  }

  public static SWIGTYPE_p_zxid_entity get_meta(zxid_conf cf, String url) {
    long cPtr = zxidjniJNI.zxid_get_meta(zxid_conf.getCPtr(cf), url);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zxid_entity(cPtr, false);
  }

  public static SWIGTYPE_p_zxid_entity get_ent_ss(zxid_conf cf, String eid) {
    long cPtr = zxidjniJNI.zxid_get_ent_ss(zxid_conf.getCPtr(cf), eid);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zxid_entity(cPtr, false);
  }

  public static SWIGTYPE_p_zxid_entity get_ent(zxid_conf cf, String eid) {
    long cPtr = zxidjniJNI.zxid_get_ent(zxid_conf.getCPtr(cf), eid);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zxid_entity(cPtr, false);
  }

  public static SWIGTYPE_p_zxid_entity get_ent_by_succinct_id(zxid_conf cf, String raw_succinct_id) {
    long cPtr = zxidjniJNI.zxid_get_ent_by_succinct_id(zxid_conf.getCPtr(cf), raw_succinct_id);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zxid_entity(cPtr, false);
  }

  public static SWIGTYPE_p_zxid_entity get_ent_by_sha1_name(zxid_conf cf, String sha1_name) {
    long cPtr = zxidjniJNI.zxid_get_ent_by_sha1_name(zxid_conf.getCPtr(cf), sha1_name);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zxid_entity(cPtr, false);
  }

  public static SWIGTYPE_p_zxid_entity load_cot_cache(zxid_conf cf) {
    long cPtr = zxidjniJNI.zxid_load_cot_cache(zxid_conf.getCPtr(cf));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zxid_entity(cPtr, false);
  }

  public static SWIGTYPE_p_zx_ds_KeyInfo_s key_info(zxid_conf cf, SWIGTYPE_p_X509 x) {
    long cPtr = zxidjniJNI.zxid_key_info(zxid_conf.getCPtr(cf), SWIGTYPE_p_X509.getCPtr(x));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_ds_KeyInfo_s(cPtr, false);
  }

  public static SWIGTYPE_p_zx_md_KeyDescriptor_s key_desc(zxid_conf cf, String use, SWIGTYPE_p_X509 cert) {
    long cPtr = zxidjniJNI.zxid_key_desc(zxid_conf.getCPtr(cf), use, SWIGTYPE_p_X509.getCPtr(cert));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_md_KeyDescriptor_s(cPtr, false);
  }

  public static SWIGTYPE_p_zx_md_ArtifactResolutionService_s ar_desc(zxid_conf cf, String binding, String loc, String resp_loc) {
    long cPtr = zxidjniJNI.zxid_ar_desc(zxid_conf.getCPtr(cf), binding, loc, resp_loc);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_md_ArtifactResolutionService_s(cPtr, false);
  }

  public static SWIGTYPE_p_zx_md_SingleSignOnService_s sso_desc(zxid_conf cf, String binding, String loc, String resp_loc) {
    long cPtr = zxidjniJNI.zxid_sso_desc(zxid_conf.getCPtr(cf), binding, loc, resp_loc);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_md_SingleSignOnService_s(cPtr, false);
  }

  public static SWIGTYPE_p_zx_md_SingleLogoutService_s slo_desc(zxid_conf cf, String binding, String loc, String resp_loc) {
    long cPtr = zxidjniJNI.zxid_slo_desc(zxid_conf.getCPtr(cf), binding, loc, resp_loc);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_md_SingleLogoutService_s(cPtr, false);
  }

  public static SWIGTYPE_p_zx_md_ManageNameIDService_s mni_desc(zxid_conf cf, String binding, String loc, String resp_loc) {
    long cPtr = zxidjniJNI.zxid_mni_desc(zxid_conf.getCPtr(cf), binding, loc, resp_loc);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_md_ManageNameIDService_s(cPtr, false);
  }

  public static SWIGTYPE_p_zx_md_AssertionConsumerService_s ac_desc(zxid_conf cf, String binding, String loc, String index) {
    long cPtr = zxidjniJNI.zxid_ac_desc(zxid_conf.getCPtr(cf), binding, loc, index);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_md_AssertionConsumerService_s(cPtr, false);
  }

  public static SWIGTYPE_p_zx_md_IDPSSODescriptor_s idp_sso_desc(zxid_conf cf) {
    long cPtr = zxidjniJNI.zxid_idp_sso_desc(zxid_conf.getCPtr(cf));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_md_IDPSSODescriptor_s(cPtr, false);
  }

  public static SWIGTYPE_p_zx_md_SPSSODescriptor_s sp_sso_desc(zxid_conf cf) {
    long cPtr = zxidjniJNI.zxid_sp_sso_desc(zxid_conf.getCPtr(cf));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_md_SPSSODescriptor_s(cPtr, false);
  }

  public static String sp_meta(zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi) { return zxidjniJNI.zxid_sp_meta(zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi)); }

  public static int send_sp_meta(zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi) {
    return zxidjniJNI.zxid_send_sp_meta(zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi));
  }

  public static String sp_carml(zxid_conf cf) { return zxidjniJNI.zxid_sp_carml(zxid_conf.getCPtr(cf)); }

  public static String my_entity_id(zxid_conf cf) { return zxidjniJNI.zxid_my_entity_id(zxid_conf.getCPtr(cf)); }

  public static String my_cdc_url(zxid_conf cf) { return zxidjniJNI.zxid_my_cdc_url(zxid_conf.getCPtr(cf)); }

  public static SWIGTYPE_p_zx_sa_Issuer_s my_issuer(zxid_conf cf) {
    long cPtr = zxidjniJNI.zxid_my_issuer(zxid_conf.getCPtr(cf));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_sa_Issuer_s(cPtr, false);
  }

  public static void sha1_file(zxid_conf cf, String name, String sha1) {
    zxidjniJNI.zxid_sha1_file(zxid_conf.getCPtr(cf), name, sha1);
  }

  public static SWIGTYPE_p_X509 extract_cert(String buf, String name) {
    long cPtr = zxidjniJNI.zxid_extract_cert(buf, name);
    return (cPtr == 0) ? null : new SWIGTYPE_p_X509(cPtr, false);
  }

  public static SWIGTYPE_p_p_void extract_private_key(String buf, String name) {
    long cPtr = zxidjniJNI.zxid_extract_private_key(buf, name);
    return (cPtr == 0) ? null : new SWIGTYPE_p_p_void(cPtr, false);
  }

  public static SWIGTYPE_p_X509 read_cert(zxid_conf cf, String name) {
    long cPtr = zxidjniJNI.zxid_read_cert(zxid_conf.getCPtr(cf), name);
    return (cPtr == 0) ? null : new SWIGTYPE_p_X509(cPtr, false);
  }

  public static SWIGTYPE_p_p_void read_private_key(zxid_conf cf, String name) {
    long cPtr = zxidjniJNI.zxid_read_private_key(zxid_conf.getCPtr(cf), name);
    return (cPtr == 0) ? null : new SWIGTYPE_p_p_void(cPtr, false);
  }

  public static int set_opt(zxid_conf cf, int which, int val) {
    return zxidjniJNI.zxid_set_opt(zxid_conf.getCPtr(cf), which, val);
  }

  public static String set_opt_cstr(zxid_conf cf, int which, String val) {
    return zxidjniJNI.zxid_set_opt_cstr(zxid_conf.getCPtr(cf), which, val);
  }

  public static void url_set(zxid_conf cf, String url) {
    zxidjniJNI.zxid_url_set(zxid_conf.getCPtr(cf), url);
  }

  public static int init_conf(zxid_conf cf, String conf_dir) {
    return zxidjniJNI.zxid_init_conf(zxid_conf.getCPtr(cf), conf_dir);
  }

  public static zxid_conf init_conf_ctx(zxid_conf cf, String zxid_path) {
    long cPtr = zxidjniJNI.zxid_init_conf_ctx(zxid_conf.getCPtr(cf), zxid_path);
    return (cPtr == 0) ? null : new zxid_conf(cPtr, false);
  }

  public static zxid_conf new_conf(String zxid_path) {
    long cPtr = zxidjniJNI.zxid_new_conf(zxid_path);
    return (cPtr == 0) ? null : new zxid_conf(cPtr, false);
  }

  public static int parse_conf_raw(zxid_conf cf, int qs_len, String qs) {
    return zxidjniJNI.zxid_parse_conf_raw(zxid_conf.getCPtr(cf), qs_len, qs);
  }

  public static int parse_conf(zxid_conf cf, String qs) {
    return zxidjniJNI.zxid_parse_conf(zxid_conf.getCPtr(cf), qs);
  }

  public static int mk_self_sig_cert(zxid_conf cf, int buflen, String buf, String lk, String name) {
    return zxidjniJNI.zxid_mk_self_sig_cert(zxid_conf.getCPtr(cf), buflen, buf, lk, name);
  }

  public static SWIGTYPE_p_zxid_map load_map(zxid_conf cf, SWIGTYPE_p_zxid_map map, String v) {
    long cPtr = zxidjniJNI.zxid_load_map(zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_map.getCPtr(map), v);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zxid_map(cPtr, false);
  }

  public static SWIGTYPE_p_zxid_need load_need(zxid_conf cf, SWIGTYPE_p_zxid_need need, String v) {
    long cPtr = zxidjniJNI.zxid_load_need(zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_need.getCPtr(need), v);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zxid_need(cPtr, false);
  }

  public static SWIGTYPE_p_zxid_atsrc load_atsrc(zxid_conf cf, SWIGTYPE_p_zxid_atsrc atsrc, String v) {
    long cPtr = zxidjniJNI.zxid_load_atsrc(zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_atsrc.getCPtr(atsrc), v);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zxid_atsrc(cPtr, false);
  }

  public static SWIGTYPE_p_zxid_attr new_at(zxid_conf cf, SWIGTYPE_p_zxid_attr at, int name_len, String name, int val_len, String val, String lk) {
    long cPtr = zxidjniJNI.zxid_new_at(zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_attr.getCPtr(at), name_len, name, val_len, val, lk);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zxid_attr(cPtr, false);
  }

  public static SWIGTYPE_p_zxid_cstr_list load_cstr_list(zxid_conf cf, SWIGTYPE_p_zxid_cstr_list lst, String v) {
    long cPtr = zxidjniJNI.zxid_load_cstr_list(zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cstr_list.getCPtr(lst), v);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zxid_cstr_list(cPtr, false);
  }

  public static SWIGTYPE_p_zxid_need is_needed(SWIGTYPE_p_zxid_need need, String name) {
    long cPtr = zxidjniJNI.zxid_is_needed(SWIGTYPE_p_zxid_need.getCPtr(need), name);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zxid_need(cPtr, false);
  }

  public static SWIGTYPE_p_zxid_map find_map(SWIGTYPE_p_zxid_map map, String name) {
    long cPtr = zxidjniJNI.zxid_find_map(SWIGTYPE_p_zxid_map.getCPtr(map), name);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zxid_map(cPtr, false);
  }

  public static SWIGTYPE_p_zxid_cstr_list find_cstr_list(SWIGTYPE_p_zxid_cstr_list lst, String name) {
    long cPtr = zxidjniJNI.zxid_find_cstr_list(SWIGTYPE_p_zxid_cstr_list.getCPtr(lst), name);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zxid_cstr_list(cPtr, false);
  }

  public static SWIGTYPE_p_zxid_attr find_at(SWIGTYPE_p_zxid_attr pool, String name) {
    long cPtr = zxidjniJNI.zxid_find_at(SWIGTYPE_p_zxid_attr.getCPtr(pool), name);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zxid_attr(cPtr, false);
  }

  public static String show_conf(zxid_conf cf) { return zxidjniJNI.zxid_show_conf(zxid_conf.getCPtr(cf)); }

  public static int parse_cgi(SWIGTYPE_p_zxid_cgi cgi, String qs) {
    return zxidjniJNI.zxid_parse_cgi(SWIGTYPE_p_zxid_cgi.getCPtr(cgi), qs);
  }

  public static SWIGTYPE_p_zxid_cgi new_cgi(zxid_conf cf, String qs) {
    long cPtr = zxidjniJNI.zxid_new_cgi(zxid_conf.getCPtr(cf), qs);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zxid_cgi(cPtr, false);
  }

  public static void get_sid_from_cookie(zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, String cookie) {
    zxidjniJNI.zxid_get_sid_from_cookie(zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), cookie);
  }

  public static zxid_ses alloc_ses(zxid_conf cf) {
    long cPtr = zxidjniJNI.zxid_alloc_ses(zxid_conf.getCPtr(cf));
    return (cPtr == 0) ? null : new zxid_ses(cPtr, false);
  }

  public static zxid_ses fetch_ses(zxid_conf cf, String sid) {
    long cPtr = zxidjniJNI.zxid_fetch_ses(zxid_conf.getCPtr(cf), sid);
    return (cPtr == 0) ? null : new zxid_ses(cPtr, false);
  }

  public static int get_ses(zxid_conf cf, zxid_ses ses, String sid) {
    return zxidjniJNI.zxid_get_ses(zxid_conf.getCPtr(cf), zxid_ses.getCPtr(ses), sid);
  }

  public static int put_ses(zxid_conf cf, zxid_ses ses) {
    return zxidjniJNI.zxid_put_ses(zxid_conf.getCPtr(cf), zxid_ses.getCPtr(ses));
  }

  public static int del_ses(zxid_conf cf, zxid_ses ses) {
    return zxidjniJNI.zxid_del_ses(zxid_conf.getCPtr(cf), zxid_ses.getCPtr(ses));
  }

  public static int get_ses_sso_a7n(zxid_conf cf, zxid_ses ses) {
    return zxidjniJNI.zxid_get_ses_sso_a7n(zxid_conf.getCPtr(cf), zxid_ses.getCPtr(ses));
  }

  public static SWIGTYPE_p_zxid_entity get_ses_idp(zxid_conf cf, zxid_ses ses) {
    long cPtr = zxidjniJNI.zxid_get_ses_idp(zxid_conf.getCPtr(cf), zxid_ses.getCPtr(ses));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zxid_entity(cPtr, false);
  }

  public static int find_ses(zxid_conf cf, zxid_ses ses, String ses_ix, String nid) {
    return zxidjniJNI.zxid_find_ses(zxid_conf.getCPtr(cf), zxid_ses.getCPtr(ses), ses_ix, nid);
  }

  public static String pool_to_ldif(zxid_conf cf, SWIGTYPE_p_zxid_attr pool) { return zxidjniJNI.zxid_pool_to_ldif(zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_attr.getCPtr(pool)); }

  public static String pool_to_json(zxid_conf cf, SWIGTYPE_p_zxid_attr pool) { return zxidjniJNI.zxid_pool_to_json(zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_attr.getCPtr(pool)); }

  public static String pool_to_qs(zxid_conf cf, SWIGTYPE_p_zxid_attr pool) { return zxidjniJNI.zxid_pool_to_qs(zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_attr.getCPtr(pool)); }

  public static void ses_to_pool(zxid_conf cf, zxid_ses ses) {
    zxidjniJNI.zxid_ses_to_pool(zxid_conf.getCPtr(cf), zxid_ses.getCPtr(ses));
  }

  public static void add_attr_to_pool(zxid_conf cf, zxid_ses ses, String at_name, String val) {
    zxidjniJNI.zxid_add_attr_to_pool(zxid_conf.getCPtr(cf), zxid_ses.getCPtr(ses), at_name, val);
  }

  public static int add_qs_to_pool(zxid_conf cf, zxid_ses ses, String qs, int apply_map) {
    return zxidjniJNI.zxid_add_qs_to_pool(zxid_conf.getCPtr(cf), zxid_ses.getCPtr(ses), qs, apply_map);
  }

  public static SWIGTYPE_p_zx_sa_NameID_s parse_mni(zxid_conf cf, String buf, SWIGTYPE_p_p_char pmniptr) {
    long cPtr = zxidjniJNI.zxid_parse_mni(zxid_conf.getCPtr(cf), buf, SWIGTYPE_p_p_char.getCPtr(pmniptr));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_sa_NameID_s(cPtr, false);
  }

  public static int put_user(zxid_conf cf, String nidfmt, String idpent, String spqual, String idpnid, String mniptr) {
    return zxidjniJNI.zxid_put_user(zxid_conf.getCPtr(cf), nidfmt, idpent, spqual, idpnid, mniptr);
  }

  public static SWIGTYPE_p_zx_sa_NameID_s get_user_nameid(zxid_conf cf, SWIGTYPE_p_zx_sa_NameID_s oldnid) {
    long cPtr = zxidjniJNI.zxid_get_user_nameid(zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_sa_NameID_s.getCPtr(oldnid));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_sa_NameID_s(cPtr, false);
  }

  public static void user_change_nameid(zxid_conf cf, SWIGTYPE_p_zx_sa_NameID_s oldnid, String newnym) {
    zxidjniJNI.zxid_user_change_nameid(zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_sa_NameID_s.getCPtr(oldnid), newnym);
  }

  public static int pw_authn(zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, zxid_ses ses) {
    return zxidjniJNI.zxid_pw_authn(zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), zxid_ses.getCPtr(ses));
  }

  public static int version() {
    return zxidjniJNI.zxid_version();
  }

  public static String version_str() {
    return zxidjniJNI.zxid_version_str();
  }

  public static String date_time(zxid_conf cf, SWIGTYPE_p_time_t secs) { return zxidjniJNI.zxid_date_time(zxid_conf.getCPtr(cf), SWIGTYPE_p_time_t.getCPtr(secs)); }

  public static String mk_id(zxid_conf cf, String prefix, int bits) { return zxidjniJNI.zxid_mk_id(zxid_conf.getCPtr(cf), prefix, bits); }

  public static SWIGTYPE_p_zx_root_s soap_call_raw(zxid_conf cf, String url, String data) {
    long cPtr = zxidjniJNI.zxid_soap_call_raw(zxid_conf.getCPtr(cf), url, data);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_root_s(cPtr, false);
  }

  public static String lecp_check(zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi) { return zxidjniJNI.zxid_lecp_check(zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi)); }

  public static int cdc_read(zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi) {
    return zxidjniJNI.zxid_cdc_read(zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi));
  }

  public static int cdc_check(zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi) {
    return zxidjniJNI.zxid_cdc_check(zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi));
  }

  public static SWIGTYPE_p_zx_root_s soap_call_envelope(zxid_conf cf, String url, SWIGTYPE_p_zx_e_Envelope_s env) {
    long cPtr = zxidjniJNI.zxid_soap_call_envelope(zxid_conf.getCPtr(cf), url, SWIGTYPE_p_zx_e_Envelope_s.getCPtr(env));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_root_s(cPtr, false);
  }

  public static SWIGTYPE_p_zx_root_s soap_call_hdr_body(zxid_conf cf, String url, SWIGTYPE_p_zx_e_Header_s hdr, SWIGTYPE_p_zx_e_Body_s body) {
    long cPtr = zxidjniJNI.zxid_soap_call_hdr_body(zxid_conf.getCPtr(cf), url, SWIGTYPE_p_zx_e_Header_s.getCPtr(hdr), SWIGTYPE_p_zx_e_Body_s.getCPtr(body));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_root_s(cPtr, false);
  }

  public static SWIGTYPE_p_zx_root_s soap_call_body(zxid_conf cf, String url, SWIGTYPE_p_zx_e_Body_s body) {
    long cPtr = zxidjniJNI.zxid_soap_call_body(zxid_conf.getCPtr(cf), url, SWIGTYPE_p_zx_e_Body_s.getCPtr(body));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_root_s(cPtr, false);
  }

  public static int soap_cgi_resp_body(zxid_conf cf, SWIGTYPE_p_zx_e_Body_s body) {
    return zxidjniJNI.zxid_soap_cgi_resp_body(zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_e_Body_s.getCPtr(body));
  }

  public static String saml2_post_enc(zxid_conf cf, String field, String payload, String relay_state, int sign, String action_url) { return zxidjniJNI.zxid_saml2_post_enc(zxid_conf.getCPtr(cf), field, payload, relay_state, sign, action_url); }

  public static String saml2_redir_enc(zxid_conf cf, String cgivar, String pay_load, String relay_state) { return zxidjniJNI.zxid_saml2_redir_enc(zxid_conf.getCPtr(cf), cgivar, pay_load, relay_state); }

  public static String saml2_redir_url(zxid_conf cf, String loc, String pay_load, String relay_state) { return zxidjniJNI.zxid_saml2_redir_url(zxid_conf.getCPtr(cf), loc, pay_load, relay_state); }

  public static String saml2_redir(zxid_conf cf, String loc, String pay_load, String relay_state) { return zxidjniJNI.zxid_saml2_redir(zxid_conf.getCPtr(cf), loc, pay_load, relay_state); }

  public static String saml2_resp_redir(zxid_conf cf, String loc, String pay_load, String relay_state) { return zxidjniJNI.zxid_saml2_resp_redir(zxid_conf.getCPtr(cf), loc, pay_load, relay_state); }

  public static int saml_ok(zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, SWIGTYPE_p_zx_sp_Status_s st, String what) {
    return zxidjniJNI.zxid_saml_ok(zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), SWIGTYPE_p_zx_sp_Status_s.getCPtr(st), what);
  }

  public static SWIGTYPE_p_zx_sa_NameID_s decrypt_nameid(zxid_conf cf, SWIGTYPE_p_zx_sa_NameID_s nid, SWIGTYPE_p_zx_sa_EncryptedID_s encid) {
    long cPtr = zxidjniJNI.zxid_decrypt_nameid(zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_sa_NameID_s.getCPtr(nid), SWIGTYPE_p_zx_sa_EncryptedID_s.getCPtr(encid));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_sa_NameID_s(cPtr, false);
  }

  public static String decrypt_newnym(zxid_conf cf, String newnym, SWIGTYPE_p_zx_sp_NewEncryptedID_s encid) { return zxidjniJNI.zxid_decrypt_newnym(zxid_conf.getCPtr(cf), newnym, SWIGTYPE_p_zx_sp_NewEncryptedID_s.getCPtr(encid)); }

  public static int chk_sig(zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, zxid_ses ses, SWIGTYPE_p_zx_elem_s elem, SWIGTYPE_p_zx_ds_Signature_s sig, SWIGTYPE_p_zx_sa_Issuer_s issue_ent, String lk) {
    return zxidjniJNI.zxid_chk_sig(zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), zxid_ses.getCPtr(ses), SWIGTYPE_p_zx_elem_s.getCPtr(elem), SWIGTYPE_p_zx_ds_Signature_s.getCPtr(sig), SWIGTYPE_p_zx_sa_Issuer_s.getCPtr(issue_ent), lk);
  }

  public static String map_val(zxid_conf cf, SWIGTYPE_p_zxid_map map, String val) { return zxidjniJNI.zxid_map_val(zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_map.getCPtr(map), val); }

  public static String idp_loc_raw(zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, SWIGTYPE_p_zxid_entity idp_meta, int svc_type, String binding, int req) { return zxidjniJNI.zxid_idp_loc_raw(zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), SWIGTYPE_p_zxid_entity.getCPtr(idp_meta), svc_type, binding, req); }

  public static String idp_loc(zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, zxid_ses ses, SWIGTYPE_p_zxid_entity idp_meta, int svc_type, String binding) { return zxidjniJNI.zxid_idp_loc(zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), zxid_ses.getCPtr(ses), SWIGTYPE_p_zxid_entity.getCPtr(idp_meta), svc_type, binding); }

  public static SWIGTYPE_p_zx_root_s idp_soap(zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, zxid_ses ses, SWIGTYPE_p_zxid_entity idp_meta, int svc_type, SWIGTYPE_p_zx_e_Body_s body) {
    long cPtr = zxidjniJNI.zxid_idp_soap(zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), zxid_ses.getCPtr(ses), SWIGTYPE_p_zxid_entity.getCPtr(idp_meta), svc_type, SWIGTYPE_p_zx_e_Body_s.getCPtr(body));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_root_s(cPtr, false);
  }

  public static String sp_loc_by_index_raw(zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, SWIGTYPE_p_zxid_entity sp_meta, int svc_type, String ix, SWIGTYPE_p_int binding) { return zxidjniJNI.zxid_sp_loc_by_index_raw(zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), SWIGTYPE_p_zxid_entity.getCPtr(sp_meta), svc_type, ix, SWIGTYPE_p_int.getCPtr(binding)); }

  public static String sp_loc_raw(zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, SWIGTYPE_p_zxid_entity sp_meta, int svc_type, String binding, int req) { return zxidjniJNI.zxid_sp_loc_raw(zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), SWIGTYPE_p_zxid_entity.getCPtr(sp_meta), svc_type, binding, req); }

  public static String sp_loc(zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, zxid_ses ses, SWIGTYPE_p_zxid_entity sp_meta, int svc_type, String binding) { return zxidjniJNI.zxid_sp_loc(zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), zxid_ses.getCPtr(ses), SWIGTYPE_p_zxid_entity.getCPtr(sp_meta), svc_type, binding); }

  public static SWIGTYPE_p_zx_root_s sp_soap(zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, zxid_ses ses, SWIGTYPE_p_zxid_entity sp_meta, int svc_type, SWIGTYPE_p_zx_e_Body_s body) {
    long cPtr = zxidjniJNI.zxid_sp_soap(zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), zxid_ses.getCPtr(ses), SWIGTYPE_p_zxid_entity.getCPtr(sp_meta), svc_type, SWIGTYPE_p_zx_e_Body_s.getCPtr(body));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_root_s(cPtr, false);
  }

  public static SWIGTYPE_p_zx_root_s decode_redir_or_post(zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, zxid_ses ses, int chk_dup) {
    long cPtr = zxidjniJNI.zxid_decode_redir_or_post(zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), zxid_ses.getCPtr(ses), chk_dup);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_root_s(cPtr, false);
  }

  public static String sp_dispatch(zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, zxid_ses ses) { return zxidjniJNI.zxid_sp_dispatch(zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), zxid_ses.getCPtr(ses)); }

  public static int sp_soap_dispatch(zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, zxid_ses ses, SWIGTYPE_p_zx_root_s r) {
    return zxidjniJNI.zxid_sp_soap_dispatch(zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), zxid_ses.getCPtr(ses), SWIGTYPE_p_zx_root_s.getCPtr(r));
  }

  public static int sp_soap_parse(zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, zxid_ses ses, int len, String buf) {
    return zxidjniJNI.zxid_sp_soap_parse(zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), zxid_ses.getCPtr(ses), len, buf);
  }

  public static SWIGTYPE_p_zx_sa_Assertion_s dec_a7n(zxid_conf cf, SWIGTYPE_p_zx_sa_Assertion_s a7n, SWIGTYPE_p_zx_sa_EncryptedAssertion_s enca7n) {
    long cPtr = zxidjniJNI.zxid_dec_a7n(zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_sa_Assertion_s.getCPtr(a7n), SWIGTYPE_p_zx_sa_EncryptedAssertion_s.getCPtr(enca7n));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_sa_Assertion_s(cPtr, false);
  }

  public static String idp_dispatch(zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, zxid_ses ses, int chk_dup) { return zxidjniJNI.zxid_idp_dispatch(zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), zxid_ses.getCPtr(ses), chk_dup); }

  public static int idp_soap_dispatch(zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, zxid_ses ses, SWIGTYPE_p_zx_root_s r) {
    return zxidjniJNI.zxid_idp_soap_dispatch(zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), zxid_ses.getCPtr(ses), SWIGTYPE_p_zx_root_s.getCPtr(r));
  }

  public static int idp_soap_parse(zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, zxid_ses ses, int len, String buf) {
    return zxidjniJNI.zxid_idp_soap_parse(zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), zxid_ses.getCPtr(ses), len, buf);
  }

  public static int anoint_a7n(zxid_conf cf, int sign, SWIGTYPE_p_zx_sa_Assertion_s a7n, String issued_to, String lk) {
    return zxidjniJNI.zxid_anoint_a7n(zxid_conf.getCPtr(cf), sign, SWIGTYPE_p_zx_sa_Assertion_s.getCPtr(a7n), issued_to, lk);
  }

  public static SWIGTYPE_p_zx_sa_Attribute_s add_ldif_attrs(zxid_conf cf, SWIGTYPE_p_zx_sa_Attribute_s prev, int len, String p, String lk) {
    long cPtr = zxidjniJNI.zxid_add_ldif_attrs(zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_sa_Attribute_s.getCPtr(prev), len, p, lk);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_sa_Attribute_s(cPtr, false);
  }

  public static SWIGTYPE_p_zx_sa_Attribute_s gen_boots(zxid_conf cf, String uid, String path, SWIGTYPE_p_zx_sa_Attribute_s bootstraps) {
    long cPtr = zxidjniJNI.zxid_gen_boots(zxid_conf.getCPtr(cf), uid, path, SWIGTYPE_p_zx_sa_Attribute_s.getCPtr(bootstraps));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_sa_Attribute_s(cPtr, false);
  }

  public static SWIGTYPE_p_zx_sa_Assertion_s mk_user_a7n_to_sp(zxid_conf cf, zxid_ses ses, String uid, SWIGTYPE_p_zx_sa_NameID_s nameid, SWIGTYPE_p_zxid_entity sp_meta, String sp_name_buf, int add_bs) {
    long cPtr = zxidjniJNI.zxid_mk_user_a7n_to_sp(zxid_conf.getCPtr(cf), zxid_ses.getCPtr(ses), uid, SWIGTYPE_p_zx_sa_NameID_s.getCPtr(nameid), SWIGTYPE_p_zxid_entity.getCPtr(sp_meta), sp_name_buf, add_bs);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_sa_Assertion_s(cPtr, false);
  }

  public static SWIGTYPE_p_zx_sa_NameID_s check_fed(zxid_conf cf, String affil, String uid, char allow_create, SWIGTYPE_p_timeval srcts, String issuer, String req_id, String sp_name_buf) {
    long cPtr = zxidjniJNI.zxid_check_fed(zxid_conf.getCPtr(cf), affil, uid, allow_create, SWIGTYPE_p_timeval.getCPtr(srcts), issuer, req_id, sp_name_buf);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_sa_NameID_s(cPtr, false);
  }

  public static String add_fed_tok_to_epr(zxid_conf cf, SWIGTYPE_p_zx_a_EndpointReference_s epr, String uid) {
    return zxidjniJNI.zxid_add_fed_tok_to_epr(zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_a_EndpointReference_s.getCPtr(epr), uid);
  }

  public static String idp_sso(zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, zxid_ses ses, SWIGTYPE_p_zx_sp_AuthnRequest_s ar) { return zxidjniJNI.zxid_idp_sso(zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), zxid_ses.getCPtr(ses), SWIGTYPE_p_zx_sp_AuthnRequest_s.getCPtr(ar)); }

  public static SWIGTYPE_p_zx_as_SASLResponse_s idp_as_do(zxid_conf cf, SWIGTYPE_p_zx_as_SASLRequest_s req) {
    long cPtr = zxidjniJNI.zxid_idp_as_do(zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_as_SASLRequest_s.getCPtr(req));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_as_SASLResponse_s(cPtr, false);
  }

  public static int pick_sso_profile(zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, SWIGTYPE_p_zxid_entity idp_met) {
    return zxidjniJNI.zxid_pick_sso_profile(zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), SWIGTYPE_p_zxid_entity.getCPtr(idp_met));
  }

  public static int start_sso(zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi) {
    return zxidjniJNI.zxid_start_sso(zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi));
  }

  public static String start_sso_url(zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi) { return zxidjniJNI.zxid_start_sso_url(zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi)); }

  public static String start_sso_location(zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi) { return zxidjniJNI.zxid_start_sso_location(zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi)); }

  public static int sp_deref_art(zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, zxid_ses ses) {
    return zxidjniJNI.zxid_sp_deref_art(zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), zxid_ses.getCPtr(ses));
  }

  public static int sp_sso_finalize(zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, zxid_ses ses, SWIGTYPE_p_zx_sa_Assertion_s a7n) {
    return zxidjniJNI.zxid_sp_sso_finalize(zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), zxid_ses.getCPtr(ses), SWIGTYPE_p_zx_sa_Assertion_s.getCPtr(a7n));
  }

  public static int sp_anon_finalize(zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, zxid_ses ses) {
    return zxidjniJNI.zxid_sp_anon_finalize(zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), zxid_ses.getCPtr(ses));
  }

  public static String saml2_map_nid_fmt(String f) {
    return zxidjniJNI.zxid_saml2_map_nid_fmt(f);
  }

  public static String saml2_map_protocol_binding(String b) {
    return zxidjniJNI.zxid_saml2_map_protocol_binding(b);
  }

  public static int protocol_binding_map_saml2(String b) {
    return zxidjniJNI.zxid_protocol_binding_map_saml2(b);
  }

  public static String saml2_map_authn_ctx(String c) {
    return zxidjniJNI.zxid_saml2_map_authn_ctx(c);
  }

  public static SWIGTYPE_p_zx_sa_Issuer_s issuer(zxid_conf cf, String nameid, String affiliation) {
    long cPtr = zxidjniJNI.zxid_issuer(zxid_conf.getCPtr(cf), nameid, affiliation);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_sa_Issuer_s(cPtr, false);
  }

  public static void sigres_map(int sigres, SWIGTYPE_p_p_char sigval, SWIGTYPE_p_p_char sigmsg) {
    zxidjniJNI.zxid_sigres_map(sigres, SWIGTYPE_p_p_char.getCPtr(sigval), SWIGTYPE_p_p_char.getCPtr(sigmsg));
  }

  public static int validate_cond(zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, zxid_ses ses, SWIGTYPE_p_zx_sa_Assertion_s a7n, String myentid, SWIGTYPE_p_timeval ourts, SWIGTYPE_p_p_char err) {
    return zxidjniJNI.zxid_validate_cond(zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), zxid_ses.getCPtr(ses), SWIGTYPE_p_zx_sa_Assertion_s.getCPtr(a7n), myentid, SWIGTYPE_p_timeval.getCPtr(ourts), SWIGTYPE_p_p_char.getCPtr(err));
  }

  public static int sp_slo_soap(zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, zxid_ses ses) {
    return zxidjniJNI.zxid_sp_slo_soap(zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), zxid_ses.getCPtr(ses));
  }

  public static String sp_slo_redir(zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, zxid_ses ses) { return zxidjniJNI.zxid_sp_slo_redir(zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), zxid_ses.getCPtr(ses)); }

  public static int sp_slo_do(zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, zxid_ses ses, SWIGTYPE_p_zx_sp_LogoutRequest_s req) {
    return zxidjniJNI.zxid_sp_slo_do(zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), zxid_ses.getCPtr(ses), SWIGTYPE_p_zx_sp_LogoutRequest_s.getCPtr(req));
  }

  public static int idp_slo_do(zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, zxid_ses ses, SWIGTYPE_p_zx_sp_LogoutRequest_s req) {
    return zxidjniJNI.zxid_idp_slo_do(zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), zxid_ses.getCPtr(ses), SWIGTYPE_p_zx_sp_LogoutRequest_s.getCPtr(req));
  }

  public static String slo_resp_redir(zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, SWIGTYPE_p_zx_sp_LogoutRequest_s req) { return zxidjniJNI.zxid_slo_resp_redir(zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), SWIGTYPE_p_zx_sp_LogoutRequest_s.getCPtr(req)); }

  public static int sp_mni_soap(zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, zxid_ses ses, String new_nym) {
    return zxidjniJNI.zxid_sp_mni_soap(zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), zxid_ses.getCPtr(ses), new_nym);
  }

  public static String sp_mni_redir(zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, zxid_ses ses, String new_nym) { return zxidjniJNI.zxid_sp_mni_redir(zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), zxid_ses.getCPtr(ses), new_nym); }

  public static SWIGTYPE_p_zx_sp_ManageNameIDResponse_s mni_do(zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, zxid_ses ses, SWIGTYPE_p_zx_sp_ManageNameIDRequest_s mni) {
    long cPtr = zxidjniJNI.zxid_mni_do(zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), zxid_ses.getCPtr(ses), SWIGTYPE_p_zx_sp_ManageNameIDRequest_s.getCPtr(mni));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_sp_ManageNameIDResponse_s(cPtr, false);
  }

  public static String mni_do_ss(zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, zxid_ses ses, SWIGTYPE_p_zx_sp_ManageNameIDRequest_s mni, String loc) { return zxidjniJNI.zxid_mni_do_ss(zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), zxid_ses.getCPtr(ses), SWIGTYPE_p_zx_sp_ManageNameIDRequest_s.getCPtr(mni), loc); }

  public static int pep_az_soap(zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi, zxid_ses ses, String pdp_url) {
    return zxidjniJNI.zxid_pep_az_soap(zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi), zxid_ses.getCPtr(ses), pdp_url);
  }

  public static int az_cf_ses(zxid_conf cf, String qs, zxid_ses ses) {
    return zxidjniJNI.zxid_az_cf_ses(zxid_conf.getCPtr(cf), qs, zxid_ses.getCPtr(ses));
  }

  public static int az_cf(zxid_conf cf, String qs, String sid) {
    return zxidjniJNI.zxid_az_cf(zxid_conf.getCPtr(cf), qs, sid);
  }

  public static int az(String conf, String qs, String sid) {
    return zxidjniJNI.zxid_az(conf, qs, sid);
  }

  public static SWIGTYPE_p_zx_sa_Attribute_s find_attribute(SWIGTYPE_p_zx_sa_Assertion_s a7n, int nfmt_len, String nfmt, int name_len, String name, int friendly_len, String friendly, int n) {
    long cPtr = zxidjniJNI.zxid_find_attribute(SWIGTYPE_p_zx_sa_Assertion_s.getCPtr(a7n), nfmt_len, nfmt, name_len, name, friendly_len, friendly, n);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_sa_Attribute_s(cPtr, false);
  }

  public static SWIGTYPE_p_zx_sp_AuthnRequest_s mk_authn_req(zxid_conf cf, SWIGTYPE_p_zxid_cgi cgi) {
    long cPtr = zxidjniJNI.zxid_mk_authn_req(zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_cgi.getCPtr(cgi));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_sp_AuthnRequest_s(cPtr, false);
  }

  public static SWIGTYPE_p_zx_sp_ArtifactResolve_s mk_art_deref(zxid_conf cf, SWIGTYPE_p_zxid_entity idp_meta, String artifact) {
    long cPtr = zxidjniJNI.zxid_mk_art_deref(zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_entity.getCPtr(idp_meta), artifact);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_sp_ArtifactResolve_s(cPtr, false);
  }

  public static SWIGTYPE_p_zx_sp_Status_s mk_Status(zxid_conf cf, String sc1, String sc2, String msg) {
    long cPtr = zxidjniJNI.zxid_mk_Status(zxid_conf.getCPtr(cf), sc1, sc2, msg);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_sp_Status_s(cPtr, false);
  }

  public static SWIGTYPE_p_zx_sp_Status_s OK(zxid_conf cf) {
    long cPtr = zxidjniJNI.zxid_OK(zxid_conf.getCPtr(cf));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_sp_Status_s(cPtr, false);
  }

  public static SWIGTYPE_p_zx_sa_EncryptedID_s mk_enc_id(zxid_conf cf, SWIGTYPE_p_zx_sa_NameID_s nid, SWIGTYPE_p_zxid_entity meta) {
    long cPtr = zxidjniJNI.zxid_mk_enc_id(zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_sa_NameID_s.getCPtr(nid), SWIGTYPE_p_zxid_entity.getCPtr(meta));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_sa_EncryptedID_s(cPtr, false);
  }

  public static SWIGTYPE_p_zx_sa_EncryptedAssertion_s mk_enc_a7n(zxid_conf cf, SWIGTYPE_p_zx_sa_Assertion_s a7n, SWIGTYPE_p_zxid_entity meta) {
    long cPtr = zxidjniJNI.zxid_mk_enc_a7n(zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_sa_Assertion_s.getCPtr(a7n), SWIGTYPE_p_zxid_entity.getCPtr(meta));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_sa_EncryptedAssertion_s(cPtr, false);
  }

  public static SWIGTYPE_p_zx_sp_LogoutRequest_s mk_logout(zxid_conf cf, SWIGTYPE_p_zx_sa_NameID_s nid, String ses_ix, SWIGTYPE_p_zxid_entity idp) {
    long cPtr = zxidjniJNI.zxid_mk_logout(zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_sa_NameID_s.getCPtr(nid), ses_ix, SWIGTYPE_p_zxid_entity.getCPtr(idp));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_sp_LogoutRequest_s(cPtr, false);
  }

  public static SWIGTYPE_p_zx_sp_LogoutResponse_s mk_logout_resp(zxid_conf cf, SWIGTYPE_p_zx_sp_Status_s st, String req_id) {
    long cPtr = zxidjniJNI.zxid_mk_logout_resp(zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_sp_Status_s.getCPtr(st), req_id);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_sp_LogoutResponse_s(cPtr, false);
  }

  public static SWIGTYPE_p_zx_sp_ManageNameIDRequest_s mk_mni(zxid_conf cf, SWIGTYPE_p_zx_sa_NameID_s nid, String new_nym, SWIGTYPE_p_zxid_entity idp) {
    long cPtr = zxidjniJNI.zxid_mk_mni(zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_sa_NameID_s.getCPtr(nid), new_nym, SWIGTYPE_p_zxid_entity.getCPtr(idp));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_sp_ManageNameIDRequest_s(cPtr, false);
  }

  public static SWIGTYPE_p_zx_sp_ManageNameIDResponse_s mk_mni_resp(zxid_conf cf, SWIGTYPE_p_zx_sp_Status_s st, String req_id) {
    long cPtr = zxidjniJNI.zxid_mk_mni_resp(zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_sp_Status_s.getCPtr(st), req_id);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_sp_ManageNameIDResponse_s(cPtr, false);
  }

  public static SWIGTYPE_p_zx_sa_Assertion_s mk_a7n(zxid_conf cf, String audience, SWIGTYPE_p_zx_sa_Subject_s subj, SWIGTYPE_p_zx_sa_AuthnStatement_s an_stmt, SWIGTYPE_p_zx_sa_AttributeStatement_s at_stmt, SWIGTYPE_p_zx_xasa_XACMLAuthzDecisionStatement_s az_stmt) {
    long cPtr = zxidjniJNI.zxid_mk_a7n(zxid_conf.getCPtr(cf), audience, SWIGTYPE_p_zx_sa_Subject_s.getCPtr(subj), SWIGTYPE_p_zx_sa_AuthnStatement_s.getCPtr(an_stmt), SWIGTYPE_p_zx_sa_AttributeStatement_s.getCPtr(at_stmt), SWIGTYPE_p_zx_xasa_XACMLAuthzDecisionStatement_s.getCPtr(az_stmt));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_sa_Assertion_s(cPtr, false);
  }

  public static SWIGTYPE_p_zx_sa_Subject_s mk_subj(zxid_conf cf, SWIGTYPE_p_zxid_entity sp_meta, SWIGTYPE_p_zx_sa_NameID_s nid) {
    long cPtr = zxidjniJNI.zxid_mk_subj(zxid_conf.getCPtr(cf), SWIGTYPE_p_zxid_entity.getCPtr(sp_meta), SWIGTYPE_p_zx_sa_NameID_s.getCPtr(nid));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_sa_Subject_s(cPtr, false);
  }

  public static SWIGTYPE_p_zx_sa_AuthnStatement_s mk_an_stmt(zxid_conf cf, zxid_ses ses) {
    long cPtr = zxidjniJNI.zxid_mk_an_stmt(zxid_conf.getCPtr(cf), zxid_ses.getCPtr(ses));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_sa_AuthnStatement_s(cPtr, false);
  }

  public static SWIGTYPE_p_zx_sp_Response_s mk_saml_resp(zxid_conf cf) {
    long cPtr = zxidjniJNI.zxid_mk_saml_resp(zxid_conf.getCPtr(cf));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_sp_Response_s(cPtr, false);
  }

  public static SWIGTYPE_p_zx_xac_Response_s mk_xacml_resp(zxid_conf cf, String decision) {
    long cPtr = zxidjniJNI.zxid_mk_xacml_resp(zxid_conf.getCPtr(cf), decision);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_xac_Response_s(cPtr, false);
  }

  public static SWIGTYPE_p_zx_xac_Attribute_s mk_xacml_simple_at(zxid_conf cf, SWIGTYPE_p_zx_xac_Attribute_s aa, String atid, String attype, String atissuer, String atvalue) {
    long cPtr = zxidjniJNI.zxid_mk_xacml_simple_at(zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_xac_Attribute_s.getCPtr(aa), atid, attype, atissuer, atvalue);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_xac_Attribute_s(cPtr, false);
  }

  public static SWIGTYPE_p_zx_xasp_XACMLAuthzDecisionQuery_s mk_az(zxid_conf cf, SWIGTYPE_p_zx_xac_Attribute_s subj, SWIGTYPE_p_zx_xac_Attribute_s rsrc, SWIGTYPE_p_zx_xac_Attribute_s act, SWIGTYPE_p_zx_xac_Attribute_s env) {
    long cPtr = zxidjniJNI.zxid_mk_az(zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_xac_Attribute_s.getCPtr(subj), SWIGTYPE_p_zx_xac_Attribute_s.getCPtr(rsrc), SWIGTYPE_p_zx_xac_Attribute_s.getCPtr(act), SWIGTYPE_p_zx_xac_Attribute_s.getCPtr(env));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_xasp_XACMLAuthzDecisionQuery_s(cPtr, false);
  }

  public static SWIGTYPE_p_zx_xaspcd1_XACMLAuthzDecisionQuery_s mk_az_cd1(zxid_conf cf, SWIGTYPE_p_zx_xac_Attribute_s subj, SWIGTYPE_p_zx_xac_Attribute_s rsrc, SWIGTYPE_p_zx_xac_Attribute_s act, SWIGTYPE_p_zx_xac_Attribute_s env) {
    long cPtr = zxidjniJNI.zxid_mk_az_cd1(zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_xac_Attribute_s.getCPtr(subj), SWIGTYPE_p_zx_xac_Attribute_s.getCPtr(rsrc), SWIGTYPE_p_zx_xac_Attribute_s.getCPtr(act), SWIGTYPE_p_zx_xac_Attribute_s.getCPtr(env));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_xaspcd1_XACMLAuthzDecisionQuery_s(cPtr, false);
  }

  public static SWIGTYPE_p_zx_sa_Attribute_s mk_attribute(zxid_conf cf, String name, String val) {
    long cPtr = zxidjniJNI.zxid_mk_attribute(zxid_conf.getCPtr(cf), name, val);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_sa_Attribute_s(cPtr, false);
  }

  public static SWIGTYPE_p_zx_lu_Status_s mk_lu_Status(zxid_conf cf, String sc1, String sc2, String msg, String ref) {
    long cPtr = zxidjniJNI.zxid_mk_lu_Status(zxid_conf.getCPtr(cf), sc1, sc2, msg, ref);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_lu_Status_s(cPtr, false);
  }

  public static SWIGTYPE_p_zx_di_Query_s mk_di_query(zxid_conf cf, String svc_type, String url, String di_opt, String action) {
    long cPtr = zxidjniJNI.zxid_mk_di_query(zxid_conf.getCPtr(cf), svc_type, url, di_opt, action);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_di_Query_s(cPtr, false);
  }

  public static SWIGTYPE_p_zx_a_Address_s mk_addr(zxid_conf cf, String url) {
    long cPtr = zxidjniJNI.zxid_mk_addr(zxid_conf.getCPtr(cf), url);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_a_Address_s(cPtr, false);
  }

  public static SWIGTYPE_p_zx_dap_Select_s mk_dap_select(zxid_conf cf, String dn, String filter, String attributes, int deref_aliases, int scope, int sizelimit, int timelimit, int typesonly) {
    long cPtr = zxidjniJNI.zxid_mk_dap_select(zxid_conf.getCPtr(cf), dn, filter, attributes, deref_aliases, scope, sizelimit, timelimit, typesonly);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_dap_Select_s(cPtr, false);
  }

  public static SWIGTYPE_p_zx_dap_QueryItem_s mk_dap_query_item(zxid_conf cf, SWIGTYPE_p_zx_dap_Select_s sel, String objtype, String predef, String sort, String changed_since, int incl_common_attrs, int offset, int count, String setreq, String setid, String contingent_itemidref) {
    long cPtr = zxidjniJNI.zxid_mk_dap_query_item(zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_dap_Select_s.getCPtr(sel), objtype, predef, sort, changed_since, incl_common_attrs, offset, count, setreq, setid, contingent_itemidref);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_dap_QueryItem_s(cPtr, false);
  }

  public static SWIGTYPE_p_zx_dap_TestOp_s mk_dap_testop(zxid_conf cf, String dn, String filter, String attributes, int deref_aliases, int scope, int sizelimit, int timelimit, int typesonly) {
    long cPtr = zxidjniJNI.zxid_mk_dap_testop(zxid_conf.getCPtr(cf), dn, filter, attributes, deref_aliases, scope, sizelimit, timelimit, typesonly);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_dap_TestOp_s(cPtr, false);
  }

  public static SWIGTYPE_p_zx_dap_TestItem_s mk_dap_test_item(zxid_conf cf, SWIGTYPE_p_zx_dap_TestOp_s top, String objtype, String predef) {
    long cPtr = zxidjniJNI.zxid_mk_dap_test_item(zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_dap_TestOp_s.getCPtr(top), objtype, predef);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_dap_TestItem_s(cPtr, false);
  }

  public static SWIGTYPE_p_zx_dap_ResultQuery_s mk_dap_resquery(zxid_conf cf, SWIGTYPE_p_zx_dap_Select_s sel, String objtype, String predef, String sort, String changed_since, int incl_common_attr, String contingent_itemidref) {
    long cPtr = zxidjniJNI.zxid_mk_dap_resquery(zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_dap_Select_s.getCPtr(sel), objtype, predef, sort, changed_since, incl_common_attr, contingent_itemidref);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_dap_ResultQuery_s(cPtr, false);
  }

  public static SWIGTYPE_p_zx_dap_Subscription_s mk_dap_subscription(zxid_conf cf, String subsID, String itemidref, SWIGTYPE_p_zx_dap_ResultQuery_s rq, String aggreg, String trig, String starts, String expires, int incl_data, String admin_notif, String notify_ref) {
    long cPtr = zxidjniJNI.zxid_mk_dap_subscription(zxid_conf.getCPtr(cf), subsID, itemidref, SWIGTYPE_p_zx_dap_ResultQuery_s.getCPtr(rq), aggreg, trig, starts, expires, incl_data, admin_notif, notify_ref);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_dap_Subscription_s(cPtr, false);
  }

  public static SWIGTYPE_p_zx_dap_Query_s mk_dap_query(zxid_conf cf, SWIGTYPE_p_zx_dap_TestItem_s tis, SWIGTYPE_p_zx_dap_QueryItem_s qis, SWIGTYPE_p_zx_dap_Subscription_s subs) {
    long cPtr = zxidjniJNI.zxid_mk_dap_query(zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_dap_TestItem_s.getCPtr(tis), SWIGTYPE_p_zx_dap_QueryItem_s.getCPtr(qis), SWIGTYPE_p_zx_dap_Subscription_s.getCPtr(subs));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_dap_Query_s(cPtr, false);
  }

  public static String wsp_validate(zxid_conf cf, zxid_ses ses, String az_cred, String enve) {
    return zxidjniJNI.zxid_wsp_validate(zxid_conf.getCPtr(cf), zxid_ses.getCPtr(ses), az_cred, enve);
  }

  public static String wsp_decorate(zxid_conf cf, zxid_ses ses, String az_cred, String enve) { return zxidjniJNI.zxid_wsp_decorate(zxid_conf.getCPtr(cf), zxid_ses.getCPtr(ses), az_cred, enve); }

  public static String wsp_decoratef(zxid_conf cf, zxid_ses ses, String az_cred, String env_f) { return zxidjniJNI.zxid_wsp_decoratef(zxid_conf.getCPtr(cf), zxid_ses.getCPtr(ses), az_cred, env_f); }

  public static SWIGTYPE_p_zx_e_Envelope_s wsf_decor(zxid_conf cf, zxid_ses ses, SWIGTYPE_p_zx_e_Envelope_s env) {
    long cPtr = zxidjniJNI.zxid_wsf_decor(zxid_conf.getCPtr(cf), zxid_ses.getCPtr(ses), SWIGTYPE_p_zx_e_Envelope_s.getCPtr(env));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_e_Envelope_s(cPtr, false);
  }

  public static int map_sec_mech(SWIGTYPE_p_zx_a_EndpointReference_s epr) {
    return zxidjniJNI.zxid_map_sec_mech(SWIGTYPE_p_zx_a_EndpointReference_s.getCPtr(epr));
  }

  public static int add_header_refs(zxid_conf cf, int n_refs, SWIGTYPE_p_zxsig_ref refs, SWIGTYPE_p_zx_e_Header_s hdr) {
    return zxidjniJNI.zxid_add_header_refs(zxid_conf.getCPtr(cf), n_refs, SWIGTYPE_p_zxsig_ref.getCPtr(refs), SWIGTYPE_p_zx_e_Header_s.getCPtr(hdr));
  }

  public static void wsf_sign(zxid_conf cf, int sign_flags, SWIGTYPE_p_zx_wsse_Security_s sec, SWIGTYPE_p_zx_wsse_SecurityTokenReference_s str, SWIGTYPE_p_zx_e_Header_s hdr, SWIGTYPE_p_zx_e_Body_s bdy) {
    zxidjniJNI.zxid_wsf_sign(zxid_conf.getCPtr(cf), sign_flags, SWIGTYPE_p_zx_wsse_Security_s.getCPtr(sec), SWIGTYPE_p_zx_wsse_SecurityTokenReference_s.getCPtr(str), SWIGTYPE_p_zx_e_Header_s.getCPtr(hdr), SWIGTYPE_p_zx_e_Body_s.getCPtr(bdy));
  }

  public static SWIGTYPE_p_zx_e_Envelope_s wsc_call(zxid_conf cf, zxid_ses ses, SWIGTYPE_p_zx_a_EndpointReference_s epr, SWIGTYPE_p_zx_e_Envelope_s env) {
    long cPtr = zxidjniJNI.zxid_wsc_call(zxid_conf.getCPtr(cf), zxid_ses.getCPtr(ses), SWIGTYPE_p_zx_a_EndpointReference_s.getCPtr(epr), SWIGTYPE_p_zx_e_Envelope_s.getCPtr(env));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_e_Envelope_s(cPtr, false);
  }

  public static String call(zxid_conf cf, zxid_ses ses, String svctype, String url, String di_opt, String az_cred, String enve) { return zxidjniJNI.zxid_call(zxid_conf.getCPtr(cf), zxid_ses.getCPtr(ses), svctype, url, di_opt, az_cred, enve); }

  public static String callf(zxid_conf cf, zxid_ses ses, String svctype, String url, String di_opt, String az_cred, String env_f) { return zxidjniJNI.zxid_callf(zxid_conf.getCPtr(cf), zxid_ses.getCPtr(ses), svctype, url, di_opt, az_cred, env_f); }

  public static int nice_sha1(zxid_conf cf, String buf, int buf_len, String name, String contint, int ign_prefix) {
    return zxidjniJNI.zxid_nice_sha1(zxid_conf.getCPtr(cf), buf, buf_len, name, contint, ign_prefix);
  }

  public static void fold_svc(String path, int len) {
    zxidjniJNI.zxid_fold_svc(path, len);
  }

  public static int epr_path(zxid_conf cf, String dir, String sid, String buf, int buf_len, String svc, String cont) {
    return zxidjniJNI.zxid_epr_path(zxid_conf.getCPtr(cf), dir, sid, buf, buf_len, svc, cont);
  }

  public static SWIGTYPE_p_zx_a_EndpointReference_s get_epr(zxid_conf cf, zxid_ses ses, String svc, String url, String di_opt, String action, int n) {
    long cPtr = zxidjniJNI.zxid_get_epr(zxid_conf.getCPtr(cf), zxid_ses.getCPtr(ses), svc, url, di_opt, action, n);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_a_EndpointReference_s(cPtr, false);
  }

  public static SWIGTYPE_p_zx_a_EndpointReference_s find_epr(zxid_conf cf, zxid_ses ses, String svc, String url, String di_opt, String action, int n) {
    long cPtr = zxidjniJNI.zxid_find_epr(zxid_conf.getCPtr(cf), zxid_ses.getCPtr(ses), svc, url, di_opt, action, n);
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_a_EndpointReference_s(cPtr, false);
  }

  public static int cache_epr(zxid_conf cf, zxid_ses ses, SWIGTYPE_p_zx_a_EndpointReference_s epr) {
    return zxidjniJNI.zxid_cache_epr(zxid_conf.getCPtr(cf), zxid_ses.getCPtr(ses), SWIGTYPE_p_zx_a_EndpointReference_s.getCPtr(epr));
  }

  public static void snarf_eprs_from_ses(zxid_conf cf, zxid_ses ses) {
    zxidjniJNI.zxid_snarf_eprs_from_ses(zxid_conf.getCPtr(cf), zxid_ses.getCPtr(ses));
  }

  public static String get_epr_address(zxid_conf cf, SWIGTYPE_p_zx_a_EndpointReference_s epr) { return zxidjniJNI.zxid_get_epr_address(zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_a_EndpointReference_s.getCPtr(epr)); }

  public static String get_epr_entid(zxid_conf cf, SWIGTYPE_p_zx_a_EndpointReference_s epr) { return zxidjniJNI.zxid_get_epr_entid(zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_a_EndpointReference_s.getCPtr(epr)); }

  public static SWIGTYPE_p_zx_di_QueryResponse_s di_query(zxid_conf cf, SWIGTYPE_p_zx_sa_Assertion_s a7n, SWIGTYPE_p_zx_di_Query_s req) {
    long cPtr = zxidjniJNI.zxid_di_query(zxid_conf.getCPtr(cf), SWIGTYPE_p_zx_sa_Assertion_s.getCPtr(a7n), SWIGTYPE_p_zx_di_Query_s.getCPtr(req));
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_di_QueryResponse_s(cPtr, false);
  }

  public static void std_basis_64_set(String value) {
    zxidjniJNI.std_basis_64_set(value);
  }

  public static String std_basis_64_get() {
    return zxidjniJNI.std_basis_64_get();
  }

  public static void safe_basis_64_set(String value) {
    zxidjniJNI.safe_basis_64_set(value);
  }

  public static String safe_basis_64_get() {
    return zxidjniJNI.safe_basis_64_get();
  }

  public static void zx_std_index_64_set(SWIGTYPE_p_unsigned_char value) {
    zxidjniJNI.zx_std_index_64_set(SWIGTYPE_p_unsigned_char.getCPtr(value));
  }

  public static SWIGTYPE_p_unsigned_char zx_std_index_64_get() {
    long cPtr = zxidjniJNI.zx_std_index_64_get();
    return (cPtr == 0) ? null : new SWIGTYPE_p_unsigned_char(cPtr, false);
  }

  public static String base64_fancy_raw(String p, int len, String r, String basis_64, int line_len, int eol_len, String eol, char eq_pad) {
    return zxidjniJNI.base64_fancy_raw(p, len, r, basis_64, line_len, eol_len, eol, eq_pad);
  }

  public static String unbase64_raw(String p, String lim, String r, SWIGTYPE_p_unsigned_char index_64) {
    return zxidjniJNI.unbase64_raw(p, lim, r, SWIGTYPE_p_unsigned_char.getCPtr(index_64));
  }

  public static String sha1_safe_base64(String out_buf, int len, String data) {
    return zxidjniJNI.sha1_safe_base64(out_buf, len, data);
  }

  public static String zx_zlib_raw_deflate(SWIGTYPE_p_zx_ctx c, int in_len, String in, SWIGTYPE_p_int out_len) {
    return zxidjniJNI.zx_zlib_raw_deflate(SWIGTYPE_p_zx_ctx.getCPtr(c), in_len, in, SWIGTYPE_p_int.getCPtr(out_len));
  }

  public static String zx_zlib_raw_inflate(SWIGTYPE_p_zx_ctx c, int in_len, String in, SWIGTYPE_p_int out_len) {
    return zxidjniJNI.zx_zlib_raw_inflate(SWIGTYPE_p_zx_ctx.getCPtr(c), in_len, in, SWIGTYPE_p_int.getCPtr(out_len));
  }

  public static int zx_url_encode_len(int in_len, String in) {
    return zxidjniJNI.zx_url_encode_len(in_len, in);
  }

  public static String zx_url_encode_raw(int in_len, String in, String out) {
    return zxidjniJNI.zx_url_encode_raw(in_len, in, out);
  }

  public static String zx_url_encode(SWIGTYPE_p_zx_ctx c, int in_len, String in, SWIGTYPE_p_int out_len) {
    return zxidjniJNI.zx_url_encode(SWIGTYPE_p_zx_ctx.getCPtr(c), in_len, in, SWIGTYPE_p_int.getCPtr(out_len));
  }

  public static void hex_trans_set(SWIGTYPE_p_unsigned_char value) {
    zxidjniJNI.hex_trans_set(SWIGTYPE_p_unsigned_char.getCPtr(value));
  }

  public static SWIGTYPE_p_unsigned_char hex_trans_get() {
    long cPtr = zxidjniJNI.hex_trans_get();
    return (cPtr == 0) ? null : new SWIGTYPE_p_unsigned_char(cPtr, false);
  }

  public static void ykmodhex_trans_set(SWIGTYPE_p_unsigned_char value) {
    zxidjniJNI.ykmodhex_trans_set(SWIGTYPE_p_unsigned_char.getCPtr(value));
  }

  public static SWIGTYPE_p_unsigned_char ykmodhex_trans_get() {
    long cPtr = zxidjniJNI.ykmodhex_trans_get();
    return (cPtr == 0) ? null : new SWIGTYPE_p_unsigned_char(cPtr, false);
  }

  public static String zx_hexdec(String dst, String src, int len, SWIGTYPE_p_unsigned_char trans) {
    return zxidjniJNI.zx_hexdec(dst, src, len, SWIGTYPE_p_unsigned_char.getCPtr(trans));
  }

  public static int read_all(int maxlen, String buf, String logkey, String name_fmt) {
    return zxidjniJNI.read_all(maxlen, buf, logkey, name_fmt);
  }

  public static int name_from_path(String buf, int buf_len, String name_fmt) {
    return zxidjniJNI.name_from_path(buf, buf_len, name_fmt);
  }

  public static SWIGTYPE_p_fdtype open_fd_from_path(int flags, int mode, String logkey, String name_fmt) {
    return new SWIGTYPE_p_fdtype(zxidjniJNI.open_fd_from_path(flags, mode, logkey, name_fmt), true);
  }

  public static int read_all_fd(SWIGTYPE_p_fdtype fd, String p, int want, SWIGTYPE_p_int got_all) {
    return zxidjniJNI.read_all_fd(SWIGTYPE_p_fdtype.getCPtr(fd), p, want, SWIGTYPE_p_int.getCPtr(got_all));
  }

  public static int write_all_fd(SWIGTYPE_p_fdtype fd, String p, int pending) {
    return zxidjniJNI.write_all_fd(SWIGTYPE_p_fdtype.getCPtr(fd), p, pending);
  }

  public static int write_all_path_fmt(String logkey, int len, String buf, String path_fmt, String prepath, String postpath, String data_fmt) {
    return zxidjniJNI.write_all_path_fmt(logkey, len, buf, path_fmt, prepath, postpath, data_fmt);
  }

  public static int close_file(SWIGTYPE_p_fdtype fd, String logkey) {
    return zxidjniJNI.close_file(SWIGTYPE_p_fdtype.getCPtr(fd), logkey);
  }

  public static void curl_ctx_p_set(SWIGTYPE_p_zxid_curl_ctx self, String value) {
    zxidjniJNI.zxid_curl_ctx_p_set(SWIGTYPE_p_zxid_curl_ctx.getCPtr(self), value);
  }

  public static String curl_ctx_p_get(SWIGTYPE_p_zxid_curl_ctx self) {
    return zxidjniJNI.zxid_curl_ctx_p_get(SWIGTYPE_p_zxid_curl_ctx.getCPtr(self));
  }

  public static void curl_ctx_lim_set(SWIGTYPE_p_zxid_curl_ctx self, String value) {
    zxidjniJNI.zxid_curl_ctx_lim_set(SWIGTYPE_p_zxid_curl_ctx.getCPtr(self), value);
  }

  public static String curl_ctx_lim_get(SWIGTYPE_p_zxid_curl_ctx self) {
    return zxidjniJNI.zxid_curl_ctx_lim_get(SWIGTYPE_p_zxid_curl_ctx.getCPtr(self));
  }

  public static SWIGTYPE_p_zxid_curl_ctx new_zxid_curl_ctx() {
    long cPtr = zxidjniJNI.new_zxid_curl_ctx();
    return (cPtr == 0) ? null : new SWIGTYPE_p_zxid_curl_ctx(cPtr, true);
  }

  public static void delete_zxid_curl_ctx(SWIGTYPE_p_zxid_curl_ctx self) {
    zxidjniJNI.delete_zxid_curl_ctx(SWIGTYPE_p_zxid_curl_ctx.getCPtr(self));
  }

  public static long curl_write_data(SWIGTYPE_p_void buffer, long size, long nmemb, SWIGTYPE_p_void userp) {
    return zxidjniJNI.zxid_curl_write_data(SWIGTYPE_p_void.getCPtr(buffer), size, nmemb, SWIGTYPE_p_void.getCPtr(userp));
  }

  public static long curl_read_data(SWIGTYPE_p_void buffer, long size, long nmemb, SWIGTYPE_p_void userp) {
    return zxidjniJNI.zxid_curl_read_data(SWIGTYPE_p_void.getCPtr(buffer), size, nmemb, SWIGTYPE_p_void.getCPtr(userp));
  }

  public static void zx_ns_tab_set(SWIGTYPE_p_zx_ns_s value) {
    zxidjniJNI.zx_ns_tab_set(SWIGTYPE_p_zx_ns_s.getCPtr(value));
  }

  public static SWIGTYPE_p_zx_ns_s zx_ns_tab_get() {
    long cPtr = zxidjniJNI.zx_ns_tab_get();
    return (cPtr == 0) ? null : new SWIGTYPE_p_zx_ns_s(cPtr, false);
  }

}
